SystemOrganization addCategory: #'Laser-Game-Graphics'!
SystemOrganization addCategory: #'Laser-Game-Model'!

Morph subclass: #LaserGame
	instanceVariableNames: 'grid boardForm activeCellLocation dirty moves'
	classVariableNames: 'FullWorld'
	poolDictionaries: ''
	category: 'Laser-Game-Graphics'!

!LaserGame class methodsFor: 'as yet unclassified' stamp: 'sbw 7/12/2007 21:48'!
addApplication
	"LaserGame addApplication"
	Smalltalk addToStartUpList: LaserGame.
! !

!LaserGame class methodsFor: 'as yet unclassified' stamp: 'sbw 5/26/2007 18:37'!
boardExtentFor: aGrid
	| x y |
	x := CellRenderer cellExtent x * aGrid numberOfColumns.
	y := CellRenderer cellExtent y * aGrid numberOfRows.
	^x@y! !

!LaserGame class methodsFor: 'as yet unclassified' stamp: 'sbw 7/12/2007 21:48'!
clearApplication
	"LaserGame clearApplication"
	Smalltalk removeFromStartUpList: LaserGame.
! !

!LaserGame class methodsFor: 'as yet unclassified' stamp: 'sbw 7/12/2007 21:37'!
closeAllOpenWindowsMessage
	^'Do you really want to close all windows?' translated! !

!LaserGame class methodsFor: 'as yet unclassified' stamp: 'sbw 7/12/2007 21:33'!
closeAllWindows
	"LaserGame closeAllWindows"
	(SystemWindow windowsIn: World satisfying: [:w | w model canDiscardEdits])
		do: [:w | w delete]! !

!LaserGame class methodsFor: 'as yet unclassified' stamp: 'sbw 7/16/2007 12:52'!
disableFeatures
	Preferences disable: #warnIfNoSourcesFile.
	Preferences disable: #warnIfNoChangesFile.
	Preferences disable: #cmdDotEnabled.
	Preferences enable: #eToyFriendly.
	Preferences enable: #noviceMode.
	Preferences compileHardCodedPref: #cmdGesturesEnabled enable: false.
	Preferences compileHardCodedPref: #cmdKeysInText enable: false.
	HaloMorph compileSilently: 'addCircleHandles' classified: 'disable'.
	

! !

!LaserGame class methodsFor: 'as yet unclassified' stamp: 'sbw 7/7/2007 11:34'!
fullWorld
	FullWorld isNil ifTrue: [self fullWorld: false].
	^FullWorld! !

!LaserGame class methodsFor: 'as yet unclassified' stamp: 'sbw 7/12/2007 21:30'!
fullWorld: aBoolean
	"LaserGame fullWorld: false"
	FullWorld := aBoolean
! !

!LaserGame class methodsFor: 'as yet unclassified' stamp: 'sbw 7/12/2007 21:35'!
launchFullWorld
	"LaserGame launchFullWorld"
	| morph |
	self fullWorld: true.
	morph := self new.
	morph openInWorld.
	^morph! !

!LaserGame class methodsFor: 'as yet unclassified' stamp: 'sbw 7/12/2007 21:31'!
launchStandard
	"LaserGame launchStandard"
	| morph |
	self fullWorld: false.
	morph := self new.
	morph openInHand! !

!LaserGame class methodsFor: 'as yet unclassified' stamp: 'sbw 7/12/2007 22:14'!
prepareApplication
	"LaserGame prepareApplication"
	(self confirm: self prepareApplicationWarningMessage) ifTrue: [
		(SelectionMenu confirm: self closeAllOpenWindowsMessage) ifFalse: [^ self].
		self closeAllWindows.
		self launchFullWorld.
		self disableFeatures.
		self addApplication.
		SmalltalkImage current saveAs.
		]
! !

!LaserGame class methodsFor: 'as yet unclassified' stamp: 'sbw 7/12/2007 22:11'!
prepareApplicationWarningMessage
	^'Really make a stand-alone image?
	Any existing Laser Game morpsh should be closed.
A new one will be re-created by this process.
Important developer tools will be disabled.
The image should be saved a new name as the final step of this process.' translated
! !

!LaserGame class methodsFor: 'as yet unclassified' stamp: 'sbw 7/12/2007 21:51'!
purgeAndAnswerSoleInstance
	"LaserGame purgeAndAnswerSoleInstance"
	| coll result |
	coll := self allInstances.
	coll size > 1 ifTrue: [2 to: coll size do: [:index |
			| morph |
			morph := coll at: index.
			morph delete]].
	result := coll isEmpty
		ifTrue: [nil]
		ifFalse: [coll first].
	^result! !

!LaserGame class methodsFor: 'as yet unclassified' stamp: 'sbw 6/27/2007 22:57'!
randomizedGridOfExtent: aPoint
	| model grid |
	model := self basicNew.
	grid := GridFactory randomizedGridOfExtent: aPoint.
	model initializeForGrid: grid.
	^model! !

!LaserGame class methodsFor: 'as yet unclassified' stamp: 'sbw 7/12/2007 22:06'!
startUp
	| soleInstance |
	soleInstance := self purgeAndAnswerSoleInstance.
	soleInstance isNil ifTrue: [soleInstance := self launchFullWorld].
	GridFactory reSeed.
	soleInstance newGame.
	! !

!LaserGame methodsFor: 'accessing' stamp: 'sbw 6/17/2007 11:10'!
activeCellLocation
	^activeCellLocation! !

!LaserGame methodsFor: 'accessing' stamp: 'sbw 6/17/2007 11:11'!
activeCellLocation: aPoint
	activeCellLocation := aPoint! !

!LaserGame methodsFor: 'accessing' stamp: 'sbw 7/1/2007 01:21'!
addButtonsToPanel: panel
	| layout |
	layout := self buttonLayoutFrameForRow: 1 column: 1.
	panel addMorph: self makeQuitGameButton fullFrame: layout.

	layout := self buttonLayoutFrameForRow: 1 column: 2.
	panel addMorph: self makeFireLaserButton fullFrame: layout.

	layout := self buttonLayoutFrameForRow: 2 column: 1.
	panel addMorph: self makeNewGameButton fullFrame: layout.

	layout := self buttonLayoutFrameForRow: 2 column: 2.
	panel addMorph: self makeUndoButton fullFrame: layout.

	layout := self buttonLayoutFrameForRow: 3 column: 1.
	panel addMorph: self makeResetButton fullFrame: layout.

	^panel! !

!LaserGame methodsFor: 'initialization' stamp: 'sbw 6/30/2007 17:12'!
addCountersToPanel: panel
	panel
		addMorph: self makeLaserPathCounterMorph
		fullFrame: (LayoutFrame
				fractions: (0 @ 0 corner: 1 @ 0)
				offsets: (4 @ 4 corner: -8 @ 44));
				
		addMorph: self makeMovesCounterMorph
		fullFrame: (LayoutFrame
				fractions: (0 @ 0 corner: 1 @ 0)
				offsets: (4 @ 48 corner: -8 @ 92));
				
		addMorph: self makeMirrorsCounterMorph
		fullFrame: (LayoutFrame
				fractions: (0 @ 0 corner: 1 @ 0)
				offsets: (4 @ 96 corner: -8 @ 140));

		addMorph: self makeActiveMirrorsCounterMorph
		fullFrame: (LayoutFrame
				fractions: (0 @ 0 corner: 1 @ 0)
				offsets: (4 @ 144 corner: -8 @ 188))! !

!LaserGame methodsFor: 'accessing' stamp: 'sbw 7/5/2007 18:32'!
addDividerBarToPanel: panel
	| layout offset |
	offset := -105.
	layout := LayoutFrame
		fractions: (0 @ 1 corner: 0 @ 1)
		offsets: (10@offset corner: (self panelWidth - 10)@(offset + 5)).
	panel addMorph: self makePanelDividerMorph fullFrame: layout.
	^panel! !

!LaserGame methodsFor: 'accessing' stamp: 'sbw 5/27/2007 09:07'!
boardForm
	"Answer the value of boardForm"

	^ boardForm! !

!LaserGame methodsFor: 'accessing' stamp: 'sbw 5/27/2007 09:07'!
boardForm: anObject
	"Set the value of boardForm"

	boardForm := anObject! !

!LaserGame methodsFor: 'events-processing' stamp: 'sbw 6/26/2007 18:29'!
boardRelativePositionFor: evt
	| evtPosn |
	evtPosn := evt hand position.
	^evtPosn - self position - ((self gameMargin + self panelWidth) @ self gameMargin)! !

!LaserGame methodsFor: 'initialization' stamp: 'sbw 6/27/2007 18:42'!
buttonLayoutFrameForRow: fromBottom column: fromLeft
	| buttonHeight buttonWidth xOffset xOrigin yOrigin xCorner yCorner yOffset |
	buttonHeight := 20.
	buttonWidth := 40.
	xOffset := (self panelWidth - (2 * buttonWidth)) // 3.
	yOffset := 10.

	xOrigin := xOffset * fromLeft.
	xOrigin := xOrigin + ((fromLeft - 1) * buttonWidth).

	yOrigin := yOffset * fromBottom.
	yOrigin := yOrigin + (fromBottom * buttonHeight).
	yOrigin := yOrigin negated.

	xCorner := xOrigin + buttonWidth.
	yCorner := yOrigin + buttonHeight.

	^LayoutFrame
		fractions: (0 @ 1 corner: 0 @ 1)
		offsets: (xOrigin@yOrigin corner: xCorner@yCorner)! !

!LaserGame methodsFor: 'initialization' stamp: 'sbw 6/26/2007 17:57'!
calculatedExtent
	| pt |
	pt := self boardForm extent.
	pt := pt + (self panelWidth@0).
	pt := pt + (2 * self gameMargin).
	^pt! !

!LaserGame methodsFor: 'events-processing' stamp: 'sbw 5/28/2007 23:44'!
cellForEvent: evt
	| posn |
	posn := self cellPositionForEvent: evt.
	^self grid at: posn! !

!LaserGame methodsFor: 'events-processing' stamp: 'sbw 5/28/2007 23:42'!
cellPositionForEvent: evt
	| posn ext counts |
	posn := self boardRelativePositionFor: evt.
	ext := CellRenderer cellExtent.
	counts := posn // ext.
	counts := counts + (1@1).
	^counts! !

!LaserGame methodsFor: 'accessing' stamp: 'sbw 6/27/2007 19:04'!
dirty
	dirty isNil ifTrue: [self initializeDirty].
	^dirty! !

!LaserGame methodsFor: 'accessing' stamp: 'sbw 6/19/2007 23:22'!
dirty: aDictionary
	dirty := aDictionary! !

!LaserGame methodsFor: 'drawing' stamp: 'sbw 5/27/2007 09:56'!
drawGameBoard
	| cell renderer |
	1 to: self grid numberOfColumns do: [:x |
		1 to: self grid numberOfRows do: [:y |
			cell := self grid at: x@y.
			renderer := CellRenderer rendererFor: cell grid: self grid form: self boardForm.
		renderer render]].! !

!LaserGame methodsFor: 'events-processing' stamp: 'sbw 6/17/2007 09:36'!
eventDiagnosticFor: evt tag: aString
	| cell posn |
	cell := self cellForEvent: evt.
	posn := self boardRelativePositionFor: evt.
	Transcript
		show: aString, ' at ', posn asString; cr;
		show: cell asString; cr;
		cr! !

!LaserGame methodsFor: 'initialization' stamp: 'PeterMeadows 10/21/2012 07:35'!
findActiveMirrorsCounter
	^self allMorphs detect: [:m | m externalName = 'activeMirrors'] ifNone: []! !

!LaserGame methodsFor: 'as yet unclassified' stamp: 'PeterMeadows 10/21/2012 07:38'!
findFireButton
	^self allMorphs detect: [:m | m externalName = 'fireButton'] ifNone: []! !

!LaserGame methodsFor: 'initialization' stamp: 'PeterMeadows 10/21/2012 07:34'!
findLaserPathCounter
	^self allMorphs detect: [:m | m externalName = 'laserPath'] ifNone: []! !

!LaserGame methodsFor: 'initialization' stamp: 'PeterMeadows 10/21/2012 07:35'!
findMirrorsCounter
	^self allMorphs detect: [:m | m externalName = 'mirrors'] ifNone: []! !

!LaserGame methodsFor: 'initialization' stamp: 'PeterMeadows 10/21/2012 07:35'!
findMovesCounter
	^self allMorphs detect: [:m | m externalName = 'moves'] ifNone: []! !

!LaserGame methodsFor: 'as yet unclassified' stamp: 'sbw 5/28/2007 12:13'!
fireButtonLabel
	^self laserActive
		ifTrue: ['Stop']
		ifFalse: ['Fire']! !

!LaserGame methodsFor: 'as yet unclassified' stamp: 'sbw 6/27/2007 19:07'!
fireLaser
	self laserActive
		ifTrue: [self grid stopLaser]
		ifFalse: [self grid fireLaser].
	self updateGameBoardAndControls! !

!LaserGame methodsFor: 'initialization' stamp: 'sbw 7/5/2007 17:07'!
gameMargin
	^10! !

!LaserGame methodsFor: 'accessing' stamp: 'sbw 5/26/2007 18:29'!
grid
	"Answer the value of grid"

	^ grid! !

!LaserGame methodsFor: 'accessing' stamp: 'sbw 5/26/2007 18:29'!
grid: anObject
	"Set the value of grid"

	grid := anObject! !

!LaserGame methodsFor: 'events-processing' stamp: 'PeterMeadows 10/21/2012 07:36'!
handleListenEvent: evt
	| pos unders boardMorph |
	((evt isMouse and: [evt isMove]) and: [evt isMouseDown not]) ifFalse: [^self].
	pos := evt hand position.
	unders := self morphsAt: pos.
	unders isEmpty ifTrue: [^self].
	boardMorph := unders detect: [:m | m externalName = 'board'] ifNone: [].
	boardMorph isNil ifTrue: [^self].
	self mouseMoveWhileButtonUp: evt forMorph: boardMorph! !

!LaserGame methodsFor: 'as yet unclassified' stamp: 'sbw 6/27/2007 18:00'!
incrementMoves
	self moves: self moves + 1! !

!LaserGame methodsFor: 'initialization' stamp: 'sbw 7/16/2007 22:58'!
initialize
	self initializeForGrid: GridFactory emptyStandardGrid! !

!LaserGame methodsFor: 'accessing' stamp: 'sbw 6/27/2007 19:04'!
initializeDirty
	self dirty: Dictionary new! !

!LaserGame methodsFor: 'initialization' stamp: 'sbw 7/7/2007 12:14'!
initializeForGrid: aGrid
	super initialize.
	self moves: 0.
	self grid: aGrid.
	self boardForm: (Form extent: (self class boardExtentFor: self grid) depth: Display depth).
	self boardForm fillColor: LaserGameColors gameBoardBackgroundColor.
	self class fullWorld ifTrue: [
		self setToAdhereToEdge: #adjustedCenter.
		self beSticky].
	self setExtent.
	self setupMorphs.
	self drawGameBoard.
	self updateCounters.! !

!LaserGame methodsFor: 'as yet unclassified' stamp: 'sbw 6/19/2007 23:32'!
isDirty: aCell
	^self dirty at: aCell gridLocation ifAbsent: [false]! !

!LaserGame methodsFor: 'as yet unclassified' stamp: 'sbw 5/28/2007 12:12'!
laserActive
	^self grid laserIsActive! !

!LaserGame methodsFor: 'initialization' stamp: 'sbw 6/30/2007 17:08'!
makeActiveMirrorsCounterMorph
	| count |
	count := LedMorph new
				digits: 3;
				extent: 3 * 10 @ 15;
				setBalloonText: ''.
	count color: (Color r: 0.674 g: 0.674 b: 0.96).
	count name: 'activeMirrors'.
	^ self wrapPanel: count label: 'Active Mirrors'! !

!LaserGame methodsFor: 'as yet unclassified' stamp: 'sbw 6/26/2007 18:47'!
makeButton: label action: actionSymbol state: stateSymbol
	| btn labelMorph |
	btn := PluggableButtonMorph
				on: self
				getState: stateSymbol
				action: actionSymbol.
	labelMorph := StringMorph contents: label.
	labelMorph emphasis: 1.
	btn 
		label: labelMorph;
		useRoundedCorners; 
		hResizing: #spaceFill; 
		onColor: Color veryLightGray offColor: Color lightGray; 
		borderWidth: 2; 
		borderColor: #raised.
	btn label color: Color darkGray.
	^ btn! !

!LaserGame methodsFor: 'initialization' stamp: 'sbw 7/5/2007 18:25'!
makeControlPanelMorph
	| panel |
	panel := RectangleMorph new borderWidth: 0;
				 color: Color transparent;
				 layoutPolicy: ProportionalLayout new.
	self addButtonsToPanel: panel.
	self addCountersToPanel: panel.
	self addDividerBarToPanel: panel.
	^panel! !

!LaserGame methodsFor: 'as yet unclassified' stamp: 'sbw 5/28/2007 13:38'!
makeFireLaserButton
	| btn |
	btn := self makeButton: self fireButtonLabel action: #fireLaser state: #laserActive.
	btn name: 'fireButton'.
	^btn! !

!LaserGame methodsFor: 'initialization' stamp: 'sbw 7/5/2007 17:19'!
makeGameBoardMorph
	| boardMorph |
	boardMorph := SketchMorph withForm: self boardForm.
	boardMorph name: 'board'.
	boardMorph
		on: #mouseUp send: #mouseUp:forMorph: to: self;
		on: #mouseDown send: #mouseDown:forMorph: to: self;
		on: #mouseEnter send: #mouseEnter:forMorph: to: self;
		on: #mouseLeave send: #mouseLeave:forMorph: to: self;
		on: #mouseMove send: #mouseMoveWhileButtonDown:forMorph: to: self.
	boardMorph
		hasDropShadow: true;
		shadowOffset: 3@3;
		shadowColor: (Color r: 0.25 g: 0.25 b: 0.254).
	^boardMorph! !

!LaserGame methodsFor: 'initialization' stamp: 'sbw 7/1/2007 19:58'!
makeLaserHomeMorph
	| form |
	form := Form
		extent: CellRenderer cellExtent x @ self gameMargin 
		depth: self boardForm depth.
	form fillColor: LaserGameColors laserBeamSplatterColor.
	^SketchMorph withForm: form! !

!LaserGame methodsFor: 'initialization' stamp: 'sbw 6/26/2007 19:14'!
makeLaserPathCounterMorph
	| count |
	count := LedMorph new
				digits: 3;
				extent: 3 * 10 @ 15;
				setBalloonText: ''.
	count color: (Color r: 0.674 g: 0.674 b: 0.96).
	count name: 'laserPath'.
	^ self wrapPanel: count label: 'Laser Path'! !

!LaserGame methodsFor: 'initialization' stamp: 'sbw 6/30/2007 17:05'!
makeMirrorsCounterMorph
	| count |
	count := LedMorph new
				digits: 3;
				extent: 3 * 10 @ 15;
				setBalloonText: ''.
	count color: (Color r: 0.674 g: 0.674 b: 0.96).
	count name: 'mirrors'.
	^ self wrapPanel: count label: 'Mirrors'! !

!LaserGame methodsFor: 'initialization' stamp: 'sbw 6/27/2007 17:56'!
makeMovesCounterMorph
	| count |
	count := LedMorph new
				digits: 3;
				extent: 3 * 10 @ 15;
				setBalloonText: ''.
	count color: (Color r: 0.674 g: 0.674 b: 0.96).
	count name: 'moves'.
	^ self wrapPanel: count label: 'Moves'! !

!LaserGame methodsFor: 'as yet unclassified' stamp: 'sbw 6/27/2007 18:34'!
makeNewGameButton
	^self makeButton: 'New' action: #newGame state: nil! !

!LaserGame methodsFor: 'initialization' stamp: 'sbw 7/5/2007 18:39'!
makePanelDividerMorph
	| divider |
	divider := RectangleMorph new.
	divider
		layoutPolicy: ProportionalLayout new;
		borderWidth: 2;
		borderStyle: (BorderStyle complexRaised width: 3);
		color: Color gray;
		fillStyle: ((GradientFillStyle ramp: 
					{0.0->(Color r: 0.847 g: 0.847 b: 0.85).
					1.0->(Color r: 0.972 g: 0.972 b: 0.976)})
						origin: 30@400;
						direction: 0@40;
						normal: 50@0;
						radial: false
					).
	^divider! !

!LaserGame methodsFor: 'as yet unclassified' stamp: 'sbw 5/27/2007 23:19'!
makeQuitGameButton
	^self makeButton: 'Quit' action: #quitGame state: nil! !

!LaserGame methodsFor: 'as yet unclassified' stamp: 'sbw 7/1/2007 01:20'!
makeResetButton
	^self makeButton: 'Reset' action: #reset state: nil! !

!LaserGame methodsFor: 'as yet unclassified' stamp: 'sbw 6/30/2007 19:30'!
makeUndoButton
	^self makeButton: 'Undo' action: #undo state: nil! !

!LaserGame methodsFor: 'events-processing' stamp: 'sbw 6/17/2007 11:14'!
mouseDown: evt forMorph: aSketchMorph
	| cell |
	cell := self cellForEvent: evt.
	cell isNil
		ifTrue: [self activeCellLocation: nil]
		ifFalse: [self activeCellLocation: cell gridLocation].! !

!LaserGame methodsFor: 'events-processing' stamp: 'sbw 5/28/2007 23:47'!
mouseEnter: evt forMorph: aSketchMorph
	evt hand addMouseListener: self.
! !

!LaserGame methodsFor: 'events-processing' stamp: 'sbw 6/24/2007 21:51'!
mouseLeave: evt forMorph: aSketchMorph
	evt hand removeMouseListener: self.
	self sweepDirtyCells.
	self changed.
	self currentHand showTemporaryCursor: nil! !

!LaserGame methodsFor: 'events-processing' stamp: 'sbw 6/17/2007 11:09'!
mouseMoveWhileButtonDown: evt forMorph: aSketchMorph
! !

!LaserGame methodsFor: 'events-processing' stamp: 'sbw 6/19/2007 23:41'!
mouseMoveWhileButtonUp: evt forMorph: aSketchMorph
	| cell renderer pixelPositionWithinBoard |
	cell := self cellForEvent: evt.
	renderer := CellRenderer rendererFor: cell grid: self grid form: self boardForm.
	pixelPositionWithinBoard := self boardRelativePositionFor: evt.
	self sweepDirtyCells.
	renderer showPositionHintFromWithinBoardOffset: pixelPositionWithinBoard.
	self setDirty: cell.
	self changed! !

!LaserGame methodsFor: 'events-processing' stamp: 'sbw 6/17/2007 20:30'!
mouseUp: evt forMorph: aSketchMorph
	| cell |
	cell := self cellForEvent: evt.
	cell isNil ifFalse: [
		self activeCellLocation = cell gridLocation ifTrue: [
			self mouseUp: evt forMorph: aSketchMorph cell: cell
			]
		].
	self activeCellLocation: nil! !

!LaserGame methodsFor: 'events-processing' stamp: 'sbw 6/27/2007 18:57'!
mouseUp: evt forMorph: aSketchMorph cell: aCell
	| renderer pixelPositionWithinBoard cellForRedraw |
	renderer := CellRenderer rendererFor: aCell grid: self grid form: self boardForm.
	pixelPositionWithinBoard := self boardRelativePositionFor: evt.
	cellForRedraw := renderer mouseUpWithinBoardOffset: pixelPositionWithinBoard.
	self redrawCell: cellForRedraw.
	self incrementMoves.
	self updateGameBoardAndControls
! !

!LaserGame methodsFor: 'accessing' stamp: 'sbw 6/27/2007 19:48'!
moves
	^moves! !

!LaserGame methodsFor: 'accessing' stamp: 'sbw 6/27/2007 19:48'!
moves: anInteger
	moves := anInteger! !

!LaserGame methodsFor: 'as yet unclassified' stamp: 'sbw 6/27/2007 19:12'!
newGame
	self grid initializeCells.
	self grid stopLaser.
	self moves: 0.
	self activeCellLocation: nil.
	self initializeDirty.
	GridFactory randomizeGrid: self grid.
	self updateGameBoardAndControls! !

!LaserGame methodsFor: 'initialization' stamp: 'sbw 6/30/2007 17:13'!
panelWidth
	^110! !

!LaserGame methodsFor: 'as yet unclassified' stamp: 'sbw 7/12/2007 21:33'!
quitGame
	(self confirm: 'Are you sure you want to quit?') ifTrue: [self quitGameAction]! !

!LaserGame methodsFor: 'as yet unclassified' stamp: 'PeterMeadows 10/21/2012 07:37'!
quitGameAction
	self delete.
	self class fullWorld ifTrue: [self class fullWorld: false].
	"self quitGameExitSqueakCheck"! !

!LaserGame methodsFor: 'as yet unclassified' stamp: 'sbw 7/12/2007 21:32'!
quitGameExitSqueakCheck
	"Use the Preferences cmdDotEnabled as an indicator that we are run-time or not."
	Preferences cmdDotEnabled ifFalse: [Smalltalk quitPrimitive]! !

!LaserGame methodsFor: 'drawing' stamp: 'sbw 6/21/2007 22:53'!
redrawCell: aCell
	| renderer |
	renderer := CellRenderer rendererFor: aCell grid: self grid form: self boardForm.
	renderer redrawCell! !

!LaserGame methodsFor: 'as yet unclassified' stamp: 'sbw 7/1/2007 01:20'!
reset
	self grid reset.
	self grid stopLaser.
	self moves: 0.
	self activeCellLocation: nil.
	self initializeDirty.	
	self updateGameBoardAndControls! !

!LaserGame methodsFor: 'as yet unclassified' stamp: 'sbw 6/19/2007 23:30'!
setClean: aCell
	self dirty removeKey: aCell gridLocation ifAbsent: []! !

!LaserGame methodsFor: 'as yet unclassified' stamp: 'sbw 6/19/2007 23:28'!
setDirty: aCell
	self dirty at: aCell gridLocation put: true! !

!LaserGame methodsFor: 'initialization' stamp: 'sbw 5/27/2007 09:37'!
setExtent
	self extent: self calculatedExtent! !

!LaserGame methodsFor: 'initialization' stamp: 'sbw 7/7/2007 11:51'!
setWindowColors
	| targetForFill |
	self class fullWorld
		ifTrue: [
			self color: Color transparent.
			targetForFill := World
			]
		ifFalse: [
			self color: (Color r: 0.369 g: 0.369 b: 0.505).
			targetForFill := self
			].
	targetForFill fillWithRamp: self windowColorRamp oriented: 0.3@0.8! !

!LaserGame methodsFor: 'initialization' stamp: 'sbw 7/5/2007 17:07'!
setupMorphs
	self layoutPolicy: ProportionalLayout new.
	self setWindowColors.
	self
		addMorph: self makeControlPanelMorph
		fullFrame: (LayoutFrame
				fractions: (0 @ 0 corner: 0 @ 1)
				offsets: (self gameMargin @ self gameMargin
					corner: (self gameMargin + self panelWidth) @ self gameMargin negated)).
	self
		addMorph: self makeGameBoardMorph
		fullFrame: (LayoutFrame
				fractions: (0 @ 0 corner: 1 @ 1)
				offsets: ((self gameMargin + self panelWidth) @ self gameMargin 
					corner: self gameMargin negated @ self gameMargin negated)).
	self
		addMorph: self makeLaserHomeMorph
		fullFrame: (LayoutFrame
				fractions: (0 @ 1 corner: 0 @ 1)
				offsets: ((self gameMargin + self panelWidth + 1)@(self gameMargin negated) 
					corner: (self gameMargin + self panelWidth + CellRenderer cellExtent x - 2)@(self gameMargin negated + 4))).! !

!LaserGame methodsFor: 'drawing' stamp: 'sbw 6/19/2007 23:38'!
sweepDirtyCells
	| cell renderer |
	1 to: self grid numberOfColumns do: [:x |
		1 to: self grid numberOfRows do: [:y |
			cell := self grid at: x@y.
			(self isDirty: cell) ifTrue: [
				renderer := CellRenderer rendererFor: cell grid: self grid form: self boardForm.
				renderer redrawCell.
				self setClean: cell
				]]].! !

!LaserGame methodsFor: 'as yet unclassified' stamp: 'sbw 6/30/2007 19:46'!
undo
	| completed |
	completed := self grid undo.
	completed ifTrue: [
		self incrementMoves.
		self updateGameBoardAndControls]! !

!LaserGame methodsFor: 'initialization' stamp: 'sbw 6/30/2007 17:29'!
updateCounters
	| led |
	led := self findLaserPathCounter.
	led notNil ifTrue: [
		self laserActive
			ifTrue: [led 
				highlighted: true;
				value: self grid laserBeamPath size]
			ifFalse: [led
				highlighted: false;
				value: 0]
			].
	led := self findMovesCounter.
	led notNil ifTrue: [
		led
			highlighted: false;
			value: self moves asString].
	led := self findMirrorsCounter.
	led notNil ifTrue: [
		led
			highlighted: false;
			value: self grid numberOfMirrors asString].
	led := self findActiveMirrorsCounter.
	led notNil ifTrue: [
		led
			highlighted: false;
			value: self grid numberOfActiveMirrors asString].
! !

!LaserGame methodsFor: 'as yet unclassified' stamp: 'sbw 5/28/2007 13:39'!
updateFireButtonLabel
	| btn |
	btn := self findFireButton.
	btn notNil ifTrue: [btn label contents: self fireButtonLabel]! !

!LaserGame methodsFor: 'as yet unclassified' stamp: 'sbw 6/27/2007 19:07'!
updateGameBoardAndControls
	self drawGameBoard.
	self updateFireButtonLabel.
	self updateCounters.
	self changed! !

!LaserGame methodsFor: 'initialization' stamp: 'sbw 6/26/2007 18:43'!
windowColorRamp
	^ {0.0 -> (Color r: 0.3 g: 0.8 b: 0.9).
                        1.0 -> (Color r: 0.2 g: 0.1 b: 0.7)}! !

!LaserGame methodsFor: 'initialization' stamp: 'sbw 6/26/2007 19:13'!
wrapPanel: aPanel label: aLabel 
	"wrap a panel in an alignmentMorph and put a label above it"
	| column strM |
	column := AlignmentMorph newColumn 
				wrapCentering: #topLeft;
				cellPositioning: #topLeft;
				hResizing: #spaceFill;
				vResizing: #shrinkWrap;
				borderWidth: 2;
				layoutInset: 5;
				color: Color transparent;
				useRoundedCorners;
				borderStyle: (BorderStyle complexAltInset width: 2).
	column addMorph: aPanel.
	strM := StringMorph contents: aLabel.
	strM color: Color veryVeryLightGray.
	column addMorph: strM.
	^ column! !

Morph subclass: #LedCharacterMorph
	instanceVariableNames: 'char highlighted'
	classVariableNames: 'BSegments CHSegmentOrigins CHSegments CVSegmentOrigins CVSegments DSegments TSegments'
	poolDictionaries: ''
	category: 'Laser-Game-Graphics'!

!LedCharacterMorph commentStamp: 'cbr 7/27/2010 18:47' prior: 0!
I represent a character to be displayed on an LedMorph; I am a peer to LedDigitMorph. The char 36 is SPACE.

I can live outside of LedMorphs, however. If you'd like to play with me, evaluate the following line:


LedCharacterMorph new char: $e; openInWorld!

!LedCharacterMorph class methodsFor: 'new-morph participation' stamp: 'kfr 5/26/2000 19:03'!
includeInNewMorphMenu

	^false! !

!LedCharacterMorph class methodsFor: 'class initialization' stamp: 'kfr 6/3/2000 21:32'!
initialize

	CHSegmentOrigins := {0.2@0.1. 0.2@0.45. 0.2@0.8}.
	CVSegmentOrigins := {0.1@0.2. 0.1@0.55. 0.8@0.2. 0.8@0.55}.
	TSegments := { 0.25@0.25. 0.45@0.25. 0.55@0.25. 0.75@0.25. 0.25@0.6. 0.45@0.6. 0.55@0.6. 0.75@0.6. }.
	BSegments := { 0.45@0.4. 0.25@0.4. 0.75@0.4. 0.55@0.4. 0.45@0.76. 0.25@0.76. 0.75@0.76. 0.55@0.76. }.

	DSegments  := {
	{false. false. false. false. false. false. false. false. }."0"
	{false. false. false. false. false. false. false. false. }."1"
	{false. false. false. false. false. false. false. false. }."2"
	{false. false. false. false. false. false. false. false. }."3"
	{false. false. false. false. false. false. false. false. }."4"
	{false. false. false. false. false. false. false. false. }."5"
	{false. false. false. false. false. false. false. false. }."6"
	{false. false. false. false. false. false. false. false. }."7"
	{false. false. false. false. false. false. false. false. }."8"
	{false. false. false. false. false. false. false. false. }."9"
	{false. false. false. false. false. false. false. false. }."A"
	{false. false. false. false. false. false. false. false. }."B"
	{false. false. false. false. false. false. false. false. }."C"
	{false. false. false. false. false. false. false. false. }."D"
	{false. false. false. false. false. false. false. false. }."E"
	{false. false. false. false. false. false. false. false. }."F"
	{false. false. false. false. false. false. false. false. }."G"
	{false. false. false. false. false. false. false. false. }."H"
	{false. false. false. false. false. false. false. false. }."I"
	{false. false. false. false. false. false. false. false. }."J"
	{false. false. false. true. false. false. false. false. }."K"
	{false. false. false. false. false. false. false. false. }."L"
	{true. false. false. true. false. false. false. false. }."M"
	{true. false. false. false. false. false. true. false. }."N"
	{false. true. true. false. true. false. false. true.  }."O"
	{false. false. false. false. false. false. false. false. }."P"
	{false. false. false. false. false. false. true. false. }."Q"
	{false. false. false. false. false. false. true. false. }."R"
	{false. false. false. false. false. false. false. false. }."S"
	{false. false. false. false. false. false. false. false. }."T"
	{false. false. false. false. false. false. false. false. }."U"
	{false. false. false. false. true. false. false. true. }."V"
	{false. false. false. false. false. true. true. false. }."W"
	{true. false. false. true. false. true. true. false. }."X"
	{false. false. false. false. false. false. false. false. }."Y"
	{false. false. false. true. false. true. false. false. }."Z"
	{false. false. false. false. false. false. false. false. }}."SPACE"

	CHSegments := {
		{true. false. true}."0"
		{false. false. false}."1"
		{true. true. true}."2"
		{true. true. true}."3"
		{false. true. false}."4"
		{true. true. true}."5"
		{true. true. true}."6"
		{true. false. false}."7"
		{true. true. true}."8"
		{true. true. true}."9"
		{true. true. false}."A"
		{true. true. true}."B"
		{true. false. true}."C"
		{true. false. true}."D"
		{true. true. true}."E"
		{true. true. false}."F"
		{true. true. true}."G"
		{false. true. false}."H"
		{false. false. false}."I"
		{false. false. true}."J"
		{false. true. false}."K"
		{false. false. true}."L"
		{false. false. false}."M"
		{false. false. false}."N"
		{false. false. false}."O"
		{true. true. false}."P"
		{true. false. true}."Q"
		{true. true. false}."R"
		{true. true. true}."S"
		{false. true. true}."t"
		{false. false. true}."U"
		{false. false. false}."V"
		{false. false. false}."W"
		{false. false. false}."X"
		{false. true. true}."Y"
		{true. false. true}."Z"
		{false. false. false.}}."SPACE"
	CVSegments := {
		{true. true.  true. true}."0"
		{false. false. true. true}."1"
		{false. true. true. false}."2"
		{false. false. true. true}."3"
		{true. false. true. true}."4"
		{true. false. false. true}."5"
		{true. true. false. true}."6"
		{false. false. true. true}."7"
		{true. true. true. true}."8"
		{true. false. true. true}."9"
		{true. true. true. true}."A"
		{true. true. true. true}."B"
		{true. true. false. false}."C"
		{true. true. true. true}."D"
		{true. true. false. false}."E"
		{true. true. false. false}."F"
		{true. true. false. true}."G"
		{true. true. true. true}."H"
		{true. true. false. false}."I"
		{false. true. true. true}."J"
		{true. true. false. true}."K"
		{true. true. false. false}."L"
		{true. true.  true. true}."N"
		{true. true. true. true}."N"
		{false. false. false. false}."O"
		{true. true. true. false}."P"
		{true. true.  true. true}."q"
		{true. true. true. false}."R"
		{true. false. false. true}."S"
		{true. true. false. false}."t"
		{true. true. true. true}."U"
		{true. false. true. false}."V"
		{true. true.  true. true}."w"
		{false. false. false. false}."x"
		{true. false. true. true}."y"
		{false. false. false. false}."z"
		{false. false. false. false}}."SPACE"! !

!LedCharacterMorph methodsFor: 'accessing' stamp: 'kfr 5/26/2000 20:02'!
char

	 ^ char ! !

!LedCharacterMorph methodsFor: 'accessing' stamp: 'kfr 6/12/2000 15:13'!
char: aCharacter 
	char := aCharacter digitValue.
	char >= 0 & (char <= 35) ifFalse: [char := 36]! !

!LedCharacterMorph methodsFor: 'initialization' stamp: 'dgd 2/14/2003 22:27'!
defaultColor
	"answer the default color/fill style for the receiver"
	^ Color green! !

!LedCharacterMorph methodsFor: 'drawing' stamp: 'nice 12/27/2009 03:11'!
drawOn: aCanvas 
	| foregroundColor backgroundColor thickness hThickness vThickness hOffset vOffset i |
	i := 0.
	foregroundColor := highlighted
				ifTrue: [Color white]
				ifFalse: [color].
	backgroundColor := color darker darker darker.
	hThickness := self height * 0.1.
	vThickness := self width * 0.1.
	thickness := hThickness min: vThickness.
	vOffset := hThickness - thickness // 2 max: 0.
	hOffset := vThickness - thickness // 2 max: 0.
	aCanvas fillRectangle: self bounds color: backgroundColor.
	CHSegmentOrigins with: (CHSegments at: char + 1)
		do: [:o :isLit | aCanvas fillRectangle: (Rectangle origin: (self position + (0 @ vOffset) + (o * self extent)) rounded extent: (self width * 0.6 @ thickness) rounded)
				color: (isLit
						ifTrue: [foregroundColor]
						ifFalse: [backgroundColor])].
	CVSegmentOrigins with: (CVSegments at: char + 1)
		do: [:o :isLit | aCanvas fillRectangle: (Rectangle origin: (self position + (hOffset @ 0) + (o * self extent)) rounded extent: (thickness @ (self height * 0.25)) rounded)
				color: (isLit
						ifTrue: [foregroundColor]
						ifFalse: [backgroundColor])].
	TSegments with: (DSegments at: char + 1)
		do: 
			[:tOrigin :isLit | | bOrigin | 
			i := i + 1.
			bOrigin := BSegments at: i.
			aCanvas
				line: self position x - hOffset + (self width * tOrigin x) @ (self position y - vOffset + (self height * tOrigin y))
				to: self position x + hOffset + (self width * bOrigin x) @ (self position y + vOffset + (self height * bOrigin y))
				width: thickness + 1 // 1.25
				color: (isLit
						ifTrue: [foregroundColor]
						ifFalse: [Color transparent])]! !

!LedCharacterMorph methodsFor: 'drawing' stamp: 'kfr 5/26/2000 19:03'!
drawOnFills: aRectangle

	^ true! !

!LedCharacterMorph methodsFor: 'accessing' stamp: 'kfr 5/26/2000 19:03'!
highlighted

	^ highlighted! !

!LedCharacterMorph methodsFor: 'accessing' stamp: 'kfr 5/26/2000 19:03'!
highlighted: aBoolean

	highlighted := aBoolean.
	self changed.! !

!LedCharacterMorph methodsFor: 'initialization' stamp: 'dgd 2/14/2003 21:55'!
initialize
	"initialize the state of the receiver"
	super initialize.
	""
	
	highlighted := false.
	char := 0! !

Morph subclass: #LedDigitMorph
	instanceVariableNames: 'digit highlighted'
	classVariableNames: 'HSegmentOrigins HSegments VSegmentOrigins VSegments'
	poolDictionaries: ''
	category: 'Laser-Game-Graphics'!

!LedDigitMorph commentStamp: '<historical>' prior: 0!
I am a 7-segment LED that can display a decimal digit!

!LedDigitMorph class methodsFor: 'new-morph participation' stamp: 'di 1/16/2000 10:39'!
includeInNewMorphMenu

	^false! !

!LedDigitMorph class methodsFor: 'class initialization' stamp: 'rjf 5/25/2000 00:16'!
initialize

	HSegmentOrigins := {0.2@0.1. 0.2@0.45. 0.2@0.8}.
	VSegmentOrigins := {0.1@0.2. 0.1@0.55. 0.8@0.2. 0.8@0.55}.
	HSegments := {
		{true. false. true}.
		{false. false. false}.
		{true. true. true}.
		{true. true. true}.
		{false. true. false}.
		{true. true. true}.
		{true. true. true}.
		{true. false. false}.
		{true. true. true}.
		{true. true. true}.
		{false. true. false}}.
	VSegments := {
		{true. true. true. true}.
		{false. false. true. true}.
		{false. true. true. false}.
		{false. false. true. true}.
		{true. false. true. true}.
		{true. false. false. true}.
		{true. true. false. true}.
		{false. false. true. true}.
		{true. true. true. true}.
		{true. false. true. true}.
		{false. false. false. false}}.! !

!LedDigitMorph methodsFor: 'initialization' stamp: 'dgd 2/14/2003 22:28'!
defaultColor
	"answer the default color/fill style for the receiver"
	^ Color green! !

!LedDigitMorph methodsFor: 'accessing' stamp: 'tao 5/18/1998 13:00'!
digit

	^ digit! !

!LedDigitMorph methodsFor: 'accessing' stamp: 'tao 5/18/1998 13:00'!
digit: anInteger

	digit := anInteger \\ 10	"make sure it stays between 0 and 9"! !

!LedDigitMorph methodsFor: 'drawing' stamp: 'dew 1/16/2002 20:44'!
drawOn: aCanvas

	| foregroundColor backgroundColor thickness hThickness vThickness hOffset vOffset |
	foregroundColor := highlighted ifTrue: [Color white] ifFalse: [color].
	backgroundColor := color muchDarker.
	hThickness := self height * 0.1.
	vThickness := self width * 0.1.
	thickness := hThickness min: vThickness.
	vOffset := ((hThickness - thickness) // 2) max: 0.
	hOffset := ((vThickness - thickness) // 2) max: 0.
	aCanvas fillRectangle: self bounds color: backgroundColor.
	"added to show the minus sign"
	(digit asString = '-') ifTrue: [digit := 10].
	HSegmentOrigins with: (HSegments at: digit+1) do:
		[:o :isLit |
		aCanvas
			fillRectangle: (Rectangle
				origin: (self position + (0@vOffset) + (o * self extent)) rounded
				extent: ((self width * 0.6) @ thickness) rounded)
			color: (isLit ifTrue: [foregroundColor] ifFalse: [backgroundColor])].
	VSegmentOrigins with: (VSegments at: digit+1) do:
		[:o :isLit |
		aCanvas
			fillRectangle: (Rectangle
				origin: (self position + (hOffset@0) + (o * self extent)) rounded
				extent: (thickness @ (self height * 0.25)) rounded)
			color: (isLit ifTrue: [foregroundColor] ifFalse: [backgroundColor])].
! !

!LedDigitMorph methodsFor: 'drawing' stamp: 'tao 5/18/1998 13:58'!
drawOnFills: aRectangle

	^ true! !

!LedDigitMorph methodsFor: 'accessing' stamp: 'tao 5/18/1998 17:00'!
highlighted

	^ highlighted! !

!LedDigitMorph methodsFor: 'accessing' stamp: 'tao 5/18/1998 18:43'!
highlighted: aBoolean

	highlighted := aBoolean.
	self changed.! !

!LedDigitMorph methodsFor: 'initialization' stamp: 'dgd 2/14/2003 20:34'!
initialize
	"initialize the state of the receiver"
	super initialize.
	""
	highlighted := false.
	digit := 0 ! !

Morph subclass: #LedMorph
	instanceVariableNames: 'digits chars value flashing flash string scroller scrollLoop'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Laser-Game-Graphics'!

!LedMorph commentStamp: '<historical>' prior: 0!
I am a collection of LED digits that can display a decimal value.  The display can be set to flash by sending flash: true.

LedMorph can now display characters:

LedMorph new  string:'0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ'; openInWorld

Lowercase letters will be converted to Uppercase. Carachters not in the examle
above will be shown as SPACE which is char 36 in LedCharacterMorph.

LedMorph new  chars: 10; string:'           I must get a life';flash:true;scrollLoop:true; openInWorld

The number of letters is set by chars. 
If chars is not specified it will be set to the string size. 
When the string size is bigger than chars
the string will scroll across the led. WOW!!
scrollLoop let's you set the scrolling to start over once its finished.

Enjoy.

!

!LedMorph class methodsFor: 'new-morph participation' stamp: 'di 1/16/2000 10:39'!
includeInNewMorphMenu

	^false! !

!LedMorph methodsFor: 'accessing' stamp: 'kfr 5/26/2000 20:16'!
chars

	 ^ chars! !

!LedMorph methodsFor: 'accessing' stamp: 'kfr 6/3/2000 21:27'!
chars: aNumber 
	chars := aNumber.
	self removeAllMorphs.
	1 to: chars do: [:i | self addMorph: (LedCharacterMorph new color: color)].
	self layoutChanged.
	self changed! !

!LedMorph methodsFor: 'accessing' stamp: 'dgd 2/14/2003 22:46'!
color: aColor 
	"set the receiver's color and the submorphs color"
	super color: aColor.
	self
		submorphsDo: [:m | m color: aColor]! !

!LedMorph methodsFor: 'initialization' stamp: 'dgd 3/7/2003 14:36'!
defaultColor
"answer the default color/fill style for the receiver"
	^ Color green! !

!LedMorph methodsFor: 'accessing' stamp: 'tao 5/18/1998 13:42'!
digits

	^ digits! !

!LedMorph methodsFor: 'accessing' stamp: 'tao 5/18/1998 13:46'!
digits: aNumber

	digits := aNumber.
	self removeAllMorphs.
	1 to: digits do: [:i | self addMorph: (LedDigitMorph new color: color)].
	self layoutChanged.
	self changed.! !

!LedMorph methodsFor: 'drawing' stamp: 'tao 5/18/1998 14:00'!
drawOn: aCanvas

	aCanvas fillRectangle: self bounds color: color darker darker.
! !

!LedMorph methodsFor: 'macpal' stamp: 'tao 5/18/1998 18:26'!
flash

	^ flash! !

!LedMorph methodsFor: 'accessing' stamp: 'tao 5/18/1998 18:26'!
flash: aBoolean

	flash := aBoolean.! !

!LedMorph methodsFor: 'accessing' stamp: 'djp 11/29/1999 17:27'!
highlighted: aBoolean

	self submorphsDo: [:m | m highlighted: aBoolean]! !

!LedMorph methodsFor: 'initialization' stamp: 'dgd 3/7/2003 14:36'!
initialize
"initialize the state of the receiver"
	super initialize.
""
	flashing := false.
	flash := false.
	self scrollInit.
	self digits: 2.
	self value: 0! !

!LedMorph methodsFor: 'layout' stamp: 'tao 5/18/1998 13:53'!
layoutChanged

	super layoutChanged.
	submorphs withIndexDo:
		[:m :i |
		m
			position: self position + (((i-1) * self width / digits) rounded @ 0);
			extent: (self width / digits) rounded @ self height]! !

!LedMorph methodsFor: 'initialization' stamp: 'di 3/8/2001 23:44'!
scrollInit

	chars := 0.
	scroller := 1.
	string := ''.
	scrollLoop := false.
! !

!LedMorph methodsFor: 'accessing' stamp: 'kfr 6/1/2000 18:50'!
scrollLoop	

	^ scrollLoop! !

!LedMorph methodsFor: 'accessing' stamp: 'kfr 6/1/2000 18:50'!
scrollLoop: aBoolean

	scrollLoop := aBoolean.! !

!LedMorph methodsFor: 'stepping and presenter' stamp: 'tk 4/19/2001 17:02'!
step
	(flash or: [flashing])
		ifTrue: 
			[flashing := flashing not.
			self highlighted: flashing].
	scroller ifNil: [scroller := 1].
	chars ifNil: [^ self].
	scroller + chars < (string size + 1)
		ifTrue: 
			[scroller := scroller + 1.
			self stringToLed]
		ifFalse: [scrollLoop ifTrue: [scroller := 1]]! !

!LedMorph methodsFor: 'testing' stamp: 'tao 5/18/1998 18:44'!
stepTime

	^ 500! !

!LedMorph methodsFor: 'accessing' stamp: 'kfr 5/26/2000 20:25'!
string

	^ string! !

!LedMorph methodsFor: 'accessing' stamp: 'kfr 6/12/2000 15:29'!
string: aString 
	string := aString.
	chars = 0
		ifTrue: 
			[chars := string size.
			self chars: chars].
	self stringToLed! !

!LedMorph methodsFor: 'accessing' stamp: 'tk 4/19/2001 16:55'!
stringToLed
	| i k actualString |
	i := scroller ifNil: [1].
	k := 1.
	actualString := String new: chars.
	actualString do: 
		[:m | 
		i > string size ifFalse: [actualString at: k put: (string at: i) asUppercase asCharacter].
		i := i + 1.
		k := k + 1].
	i := 1.
	submorphs do: 
		[:m | 
		m char: (actualString at: i).
		i := i + 1].
	self changed! !

!LedMorph methodsFor: 'accessing' stamp: 'tao 5/18/1998 13:42'!
value

	^ value! !

!LedMorph methodsFor: 'accessing' stamp: 'tao 5/18/1998 13:47'!
value: aNumber

	| val |
	value := aNumber.
	val := value.
	submorphs reverseDo:
		[:m |
		m digit: val \\ 10.
		val := val // 10].
	self changed.! !

Morph subclass: #SketchMorph
	instanceVariableNames: 'originalForm rotationStyle scalePoint framesToDwell rotatedForm'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Laser-Game-Graphics'!

!SketchMorph commentStamp: '<historical>' prior: 0!
The morph that results when the user draws a color bitmap using the PaintBox (SketchEditorMorph and PaintBoxMorph).  

forwardDirection is the angle at which the object will go forward.  When the rotationStyle is not #normal, then forwardDirection is any angle, while the rotation is highly restricted.  If flexed, this is remembered by the Transform morph.  For non-normal rotationStyle, it is rotationDegrees.

setupAngle (a property) is where the user put the green arrow to indicate which direction on the picture is forward.  When #normal, draw the morph initially at (0.0 - setupAngle).  The enclosing TransformationMorph then rotates it to the true angle.
 
rotationDegrees  In a #normal object, rotationDegrees is constant an equal to setupAngle.
	For non-normal, it is the direction the object is going.

When repainting, set it back to its original state. The green arrow is set to setupAngle, and the sketch is shown as drawn originally (rotationDegrees = 0). 

rotationStyle = normal (turns), leftRight, upDown, fixed.  
When leftRight upDown or fixed, bit map has severe restrictions.
!

!SketchMorph class methodsFor: 'scripting' stamp: 'dgd 8/26/2004 12:11'!
defaultNameStemForInstances
	^ 'Sketch'! !

!SketchMorph class methodsFor: 'instance creation' stamp: 'ar 3/4/2001 20:59'!
fromFile: aFileName
	^self fromStream: (FileStream readOnlyFileNamed: aFileName)! !

!SketchMorph class methodsFor: 'instance creation' stamp: 'ar 3/4/2001 21:00'!
fromStream: aStream
	^self withForm: (ImageReadWriter formFromStream: aStream)! !

!SketchMorph class methodsFor: 'new-morph participation' stamp: 'sw 9/28/1998 17:15'!
includeInNewMorphMenu
	"Not to be instantiated from the menu"
	^ false! !

!SketchMorph class methodsFor: 'testing' stamp: 'nk 6/12/2004 09:16'!
isSketchMorphClass
	^true! !

!SketchMorph class methodsFor: 'instance creation' stamp: 'nk 11/9/2003 08:11'!
openEditor
	"Create a new SketchMorph and open a SketchMorphEditor on it. 
	Answers the painted SketchMorph."
	"SketchMorph openEditor"
	| newSketch |
	newSketch := (self
				withForm: (Form extent: 100 @ 100 depth: Display depth)) center: self currentWorld center;
				 openInWorld;
				 editDrawing.
	^ newSketch! !

!SketchMorph class methodsFor: 'instance creation' stamp: 'di 2/17/2000 20:21'!
withForm: aForm
	"Note: 'SketchMorph withForm: zz' is MUCH faster
	than 'SketchMorph new form: zz'."

	^ self basicNew initializeWith: aForm! !

!SketchMorph methodsFor: 'menu' stamp: 'ar 8/6/2009 20:45'!
addBorderToShape: evt
	| str borderWidth borderedForm r |
	str := UIManager default
		request: 'Please enter the desired border width' translated
		initialAnswer: '0'.
	borderWidth := Integer readFrom: (ReadStream on: str).
	(borderWidth between: 1 and: 10) ifFalse: [^ self].

	"Take care of growing appropriately.  Does this lose the reg point?"
	borderedForm := originalForm shapeBorder: Color black width: borderWidth.
	r := borderedForm rectangleEnclosingPixelsNotOfColor: Color transparent.
	self form: (borderedForm copy: r).
! !

!SketchMorph methodsFor: 'menu' stamp: 'dgd 8/30/2003 22:16'!
addCustomMenuItems: aCustomMenu hand: aHandMorph
	"Add custom menu items"

	super addCustomMenuItems: aCustomMenu hand: aHandMorph.
	aCustomMenu add: 'restore base graphic' translated target: self action: #restoreBaseGraphicFromMenu.
	aCustomMenu add: 'call this my base graphic' translated target: self action: #callThisBaseGraphic.
	aCustomMenu add: 'choose new graphic...' translated target: self action: #chooseNewGraphic.
	aCustomMenu addLine.
	aCustomMenu add: 'set as background' translated target: rotatedForm action: #setAsBackground.
	self addPaintingItemsTo: aCustomMenu hand: aHandMorph! !

!SketchMorph methodsFor: 'menus' stamp: 'ar 6/18/1999 06:40'!
addFillStyleMenuItems: aMenu hand: aHand
	"Do nothing here - we do not allow changing the fill style of a SketchMorph yet."! !

!SketchMorph methodsFor: 'menus' stamp: 'dgd 9/18/2004 19:56'!
addToggleItemsToHaloMenu: aCustomMenu 
	"Add toggle-items to the halo menu"
	super addToggleItemsToHaloMenu: aCustomMenu.
	Preferences noviceMode
		ifFalse: [""aCustomMenu
				addUpdating: #useInterpolationString
				target: self
				action: #toggleInterpolation]! !

!SketchMorph methodsFor: 'e-toy support' stamp: 'sw 12/12/2001 13:10'!
baseGraphic
	"Answer my base graphic"

	^ self valueOfProperty: #baseGraphic ifAbsent:
		[self setProperty: #baseGraphic toValue: originalForm.
		^ originalForm]! !

!SketchMorph methodsFor: 'e-toy support' stamp: 'sw 12/12/2001 13:15'!
baseGraphic: aForm
	"Remember the given form as the receiver's base graphic"

	^ self setProperty: #baseGraphic toValue: aForm! !

!SketchMorph methodsFor: 'menu' stamp: 'yo 3/15/2005 12:04'!
callThisBaseGraphic
	"Set my baseGraphic to be the current form"

	| aGraphic |
	self isInWorld ifFalse: [^ self inform: 

'oops, this menu is a for a morph that
has been replaced, probably because a
"look like" script was run.  Please dismiss
the menu and get a new one!!.  Sorry!!' translated].

	((aGraphic := self valueOfProperty: #baseGraphic)
				notNil and: [aGraphic ~= originalForm])
		ifTrue:
			[self setProperty: #baseGraphic toValue: originalForm]
		ifFalse:
			[self inform: 'this already *was* your baseGraphic' translated]! !

!SketchMorph methodsFor: 'drawing' stamp: 'nice 12/26/2009 21:35'!
canBeEnlargedWithB3D
	^self 
		valueOfProperty: #canBeEnlargedWithB3D
		ifAbsent: [
			| answer |
			answer := self rotatedForm colorsUsed allSatisfy: [ :c | c isTranslucent not].
			self setProperty: #canBeEnlargedWithB3D toValue: answer.
			answer
		]! !

!SketchMorph methodsFor: 'menus' stamp: 'nk 3/27/2001 17:57'!
changePixelsOfColor: c toColor: newColor

	| r |
	originalForm mapColor: c to: newColor.
	r := originalForm rectangleEnclosingPixelsNotOfColor: Color transparent.
	self form: (originalForm copy: r).

! !

!SketchMorph methodsFor: 'pen support' stamp: 'jm 4/22/1998 17:14'!
clearExtent: aPoint fillColor: aColor
	"Make this sketch have the given pixel dimensions and fill it with given color. Its previous contents are replaced."

	self form:
		((Form extent: aPoint depth: Display depth) fillColor: aColor).
! !

!SketchMorph methodsFor: 'menus' stamp: 'RAA 11/14/2000 13:44'!
collapse
	
	| priorPosition w collapsedVersion a |

	(w := self world) ifNil: [^self].
	collapsedVersion := (self imageForm scaledToSize: 50@50) asMorph.
	collapsedVersion setProperty: #uncollapsedMorph toValue: self.
	collapsedVersion on: #mouseUp send: #uncollapseSketch to: collapsedVersion.
	collapsedVersion setBalloonText: 'A collapsed version of ',self name.
			
	self delete.
	w addMorphFront: (
		a := AlignmentMorph newRow
			hResizing: #shrinkWrap;
			vResizing: #shrinkWrap;
			borderWidth: 4;
			borderColor: Color white;
			addMorph: collapsedVersion
	).
	collapsedVersion setProperty: #collapsedMorphCarrier toValue: a.

	(priorPosition := self valueOfProperty: #collapsedPosition ifAbsent: [nil])
	ifNotNil:
		[a position: priorPosition].
! !

!SketchMorph methodsFor: 'geometry testing' stamp: ''!
containsPoint: aPoint

	^ (self bounds containsPoint: aPoint) and:
	  [(self rotatedForm isTransparentAt: aPoint - bounds origin) not]
! !

!SketchMorph methodsFor: 'objects from disk' stamp: 'RAA 12/20/2000 17:49'!
convertToCurrentVersion: varDict refStream: smartRefStrm
	
	scalePoint ifNil: [scalePoint := 1.0@1.0].
	^super convertToCurrentVersion: varDict refStream: smartRefStrm.

! !

!SketchMorph methodsFor: 'drawing' stamp: 'RAA 12/17/2000 14:24'!
drawHighResolutionOn: aCanvas in: aRectangle

	| r finalClipRect scale sourceOrigin sourceExtent sourceRect biggerSource biggerDestExtent interForm offsetInBigger |

	r := aRectangle translateBy: aCanvas origin.
	finalClipRect := r intersect: (aCanvas clipRect translateBy: aCanvas origin).
	self canBeEnlargedWithB3D ifTrue: [
		(WarpBlt toForm: aCanvas form)
			clipRect: finalClipRect;
			sourceForm: originalForm;
			cellSize: 2;  "installs a colormap"
			combinationRule: Form paint;

			copyQuad: originalForm boundingBox innerCorners 
			toRect: r.
		^self
	].
	scale := aRectangle extent / originalForm extent.
	sourceOrigin := originalForm offset + (aCanvas clipRect origin - aRectangle origin / scale).
	sourceExtent := aCanvas clipRect extent / scale.
	sourceRect := sourceOrigin rounded extent: sourceExtent rounded.
	biggerSource := sourceRect expandBy: 1.
	biggerDestExtent := (biggerSource extent * scale) rounded.
	offsetInBigger := (sourceOrigin - biggerSource origin * scale) rounded.

	interForm := Form extent: biggerDestExtent depth: aCanvas depth.
	(originalForm copy: biggerSource)
		displayInterpolatedIn: interForm boundingBox
		on: interForm.
	aCanvas 
		drawImage: interForm 
		at: aCanvas clipRect origin 
		sourceRect: (offsetInBigger extent: aCanvas clipRect extent).


! !

!SketchMorph methodsFor: 'drawing' stamp: 'ar 7/28/2005 16:51'!
drawInterpolatedImage: aForm on: aCanvas
	"Draw the given form onto the canvas using the Balloon 3D engine"
	| engine |
	engine := Smalltalk at: #B3DRenderEngine 
		ifPresent:[:b3d | b3d defaultForPlatformOn: aCanvas form].
	engine == nil ifTrue:[
		self useInterpolation: false.
		^self generateRotatedForm].
	"Setup the engine"
	engine viewport: aCanvas form boundingBox.
	"Install the material to be used (using a plain white emission color)"
	engine material: ((Smalltalk at: #B3DMaterial) new emission: Color white).
	"Install the texture"
	engine texture: aForm.
	"Draw the mesh"
	engine render: ((Smalltalk at: #B3DIndexedQuadMesh) new plainTextureRect).
	"and finish"
	engine finish.! !

!SketchMorph methodsFor: 'drawing' stamp: 'tk 10/9/2002 09:15'!
drawOn: aCanvas
	aCanvas translucentImage: self rotatedForm at: bounds origin
! !

!SketchMorph methodsFor: 'menu' stamp: 'tk 7/6/1998 15:31'!
editDrawing
	self flag: #deferred.  "Don't allow this if the user is already in paint mode, because it creates a very strange situation."
	"costumee ifNotNil: [self forwardDirection: costumee direction]."  "how say this?"
	self editDrawingIn: self pasteUpMorph forBackground: false
! !

!SketchMorph methodsFor: 'menu' stamp: 'nice 12/27/2009 03:11'!
editDrawingIn: aPasteUpMorph forBackground: forBackground
	"Edit an existing sketch."

	| w bnds sketchEditor rotCenter aPaintTab aWorld aPaintBox |
	self world assureNotPaintingElse: [^self].
	w := aPasteUpMorph world.
	w prepareToPaint.
	w displayWorld.
	self visible: false.
	bnds := forBackground 
				ifTrue: [aPasteUpMorph boundsInWorld]
				ifFalse: 
					[bnds := self boundsInWorld expandBy: 60 @ 60.
					(aPasteUpMorph paintingBoundsAround: bnds center) merge: bnds]. 
	sketchEditor := SketchEditorMorph new.
	forBackground 
		ifTrue: [sketchEditor setProperty: #background toValue: true].
	w addMorphFront: sketchEditor.
	sketchEditor 
		initializeFor: self
		inBounds: bnds
		pasteUpMorph: aPasteUpMorph.
	rotCenter := self rotationCenter.

	sketchEditor afterNewPicDo: 
			[:aForm :aRect | | tfx | 
			self visible: true.
			self form: aForm.
			tfx := aPasteUpMorph transformFrom: aPasteUpMorph world.
			self topRendererOrSelf position: (tfx globalPointToLocal: aRect origin).
			self rotationStyle: sketchEditor rotationStyle.
			self forwardDirection: sketchEditor forwardDirection.
			(rotCenter notNil and: [(rotCenter = (0.5 @ 0.5)) not]) ifTrue:
				[self rotationCenter: rotCenter].
			(aPaintTab := (aWorld := self world) paintingFlapTab) 
				ifNotNil: [aPaintTab hideFlap]
				ifNil: [(aPaintBox := aWorld paintBox) ifNotNil: [aPaintBox delete]].
			self presenter drawingJustCompleted: self.

			forBackground ifTrue: [self goBehind	"shouldn't be necessary"]]
		ifNoBits: 
			[ | pal |"If no bits drawn.  Must keep old pic.  Can't have no picture"

			self visible: true.
			aWorld := self currentWorld.
			"sometimes by now I'm no longer in a world myself, but we still need
				 to get ahold of the world so that we can deal with the palette"
			((pal := aPasteUpMorph standardPalette) notNil and: [pal isInWorld]) 
				ifTrue: 
					[(aPaintBox := aWorld paintBox) ifNotNil: [aPaintBox delete].
					pal viewMorph: self]
				ifFalse: 
					[(aPaintTab := (aWorld := self world) paintingFlapTab) 
						ifNotNil: [aPaintTab hideFlap]
						ifNil: [(aPaintBox := aWorld paintBox) ifNotNil: [aPaintBox delete]]]]! !

!SketchMorph methodsFor: 'menu' stamp: 'cmm 8/2/2010 18:09'!
erasePixelsOfColor: aColor 
	"Let the user specifiy a color such that all pixels of that color should be erased; then do the erasure"
	| newBounds |
	originalForm
		mapColor: aColor
		to: Color transparent.
	newBounds := originalForm rectangleEnclosingPixelsNotOfColor: Color transparent.
	self form: (originalForm copy: newBounds)! !

!SketchMorph methodsFor: 'menu' stamp: 'cmm 8/2/2010 18:19'!
erasePixelsUsing: evt 
	"Let the user specifiy a color such that all pixels of that color should be erased; then do the erasure"
	self
		changeColorTarget: self
		selector: #rememberedColor:
		originalColor: nil
		hand: evt hand.
	self rememberedColor "color to erase"
		ifNil: [ ^ self ]
		ifNotNilDo:
			[ : chosenColor | self erasePixelsOfColor: chosenColor ]! !

!SketchMorph methodsFor: 'geometry' stamp: 'nk 1/10/2004 14:51'!
extent: newExtent
	"Change my scale to fit myself into the given extent.
	Avoid extents where X or Y is zero."
	(newExtent y = 0 or: [ newExtent x = 0 ]) ifTrue: [ ^self ].
	self extent = newExtent ifTrue:[^self].
	scalePoint := newExtent asFloatPoint / (originalForm extent max: 1@1).
	self layoutChanged.
! !

!SketchMorph methodsFor: 'geometry' stamp: 'nk 6/21/2003 14:00'!
firstIntersectionWithLineFrom: start to: end
	| intersections last |
	intersections := self fullBounds extrapolatedIntersectionsWithLineFrom: start to: end.
	intersections size = 1 ifTrue: [ ^intersections anyOne ].
	intersections isEmpty ifTrue: [ ^nil ].
	intersections := intersections asSortedCollection: [ :a :b | (start dist: a) < (start dist: b) ].
	last := intersections first rounded.
	last pointsTo: intersections last rounded do: [ :pt |
		(self rotatedForm isTransparentAt: (pt - bounds origin)) ifFalse: [ ^last ].
		last := pt.
	].
	^intersections first rounded! !

!SketchMorph methodsFor: 'e-toy support' stamp: 'mga 11/18/2003 09:54'!
flipHorizontal

	self form: (self form flipBy: #horizontal centerAt: self form center)! !

!SketchMorph methodsFor: 'e-toy support' stamp: 'mga 11/18/2003 09:54'!
flipVertical

	self form: (self form flipBy: #vertical centerAt: self form center)! !

!SketchMorph methodsFor: 'accessing' stamp: ''!
form

	^ originalForm
! !

!SketchMorph methodsFor: 'accessing' stamp: 'sw 12/13/2001 12:10'!
form: aForm
	"Set the receiver's form"

	| oldForm topRenderer |
	oldForm := originalForm.
	(self hasProperty: #baseGraphic) ifFalse: [self setProperty: #baseGraphic toValue: aForm].
	originalForm := aForm.
	self rotationCenter: 0.5@0.5.
	self layoutChanged.
	topRenderer := self topRendererOrSelf.

	oldForm ifNotNil: [topRenderer position: topRenderer position + (oldForm extent - aForm extent // 2)].
! !

!SketchMorph methodsFor: 'geometry eToy' stamp: 'ar 9/22/2000 22:31'!
forwardDirection: degrees
	"If not rotating normally, update my rotatedForm"
	super forwardDirection: degrees.
	rotationStyle == #normal ifFalse:[self layoutChanged].! !

!SketchMorph methodsFor: 'accessing' stamp: ''!
framesToDwell

	^ framesToDwell
! !

!SketchMorph methodsFor: 'accessing' stamp: 'jm 7/24/97 15:06'!
framesToDwell: anInteger

	framesToDwell := anInteger.
! !

!SketchMorph methodsFor: 'drawing' stamp: 'nk 8/18/2004 19:07'!
generateInterpolatedForm
	"Draw the given form onto the canvas using the Balloon 3D engine"
	| aCanvas extent |
	extent := (originalForm extent * scalePoint) asIntegerPoint.
	rotatedForm := Form extent: extent asIntegerPoint depth: originalForm depth.
	aCanvas := rotatedForm getCanvas.
	^self drawInterpolatedImage: originalForm on: aCanvas! !

!SketchMorph methodsFor: 'drawing' stamp: 'gm 2/28/2003 00:27'!
generateRotatedForm
	"Compute my rotatedForm and offsetWhenRotated."

	| scalePt smoothPix pair |
	scalePoint ifNil: [scalePoint := 1 @ 1].
	scalePt := scalePoint x abs @ scalePoint y abs.
	rotationStyle == #none ifTrue: [scalePt := 1 @ 1].
	smoothPix := (scalePt x < 1.0 or: [scalePt y < 1.0]) 
		ifTrue: [2]
		ifFalse: [1].
	rotationStyle = #leftRight 
		ifTrue: 
			[self heading asSmallAngleDegrees < 0.0 
				ifTrue: [scalePt := scalePt x negated @ scalePt y]].
	rotationStyle = #upDown 
		ifTrue: 
			[self heading asSmallAngleDegrees abs > 90.0 
				ifTrue: [scalePt := scalePt x @ scalePt y negated]].
	rotatedForm := scalePt = (1 @ 1) 
				ifTrue: [originalForm]
				ifFalse: 
					["ar 11/19/2001: I am uncertain what happens in the case of rotationStyle ~~ normal"

					(rotationStyle == #normal and: [self useInterpolation]) 
						ifTrue: [^self generateInterpolatedForm].
					pair := WarpBlt current 
								rotate: originalForm
								degrees: 0
								center: originalForm boundingBox center
								scaleBy: scalePt
								smoothing: smoothPix.
					pair first]! !

!SketchMorph methodsFor: 'initialization' stamp: 'dgd 2/14/2003 21:51'!
initialize
"initialize the state of the receiver"
	^ self initializeWith: (ScriptingSystem formAtKey: 'Painting') deepCopy! !

!SketchMorph methodsFor: 'parts bin' stamp: 'sw 6/28/2001 11:33'!
initializeToStandAlone
	super initializeToStandAlone.
	self initializeWith: (ScriptingSystem formAtKey: 'Painting') deepCopy

! !

!SketchMorph methodsFor: 'initialization' stamp: 'ar 9/22/2000 20:38'!
initializeWith: aForm

	super initialize.
	originalForm := aForm.
	self rotationCenter: 0.5@0.5.		"relative to the top-left corner of the Form"
	rotationStyle := #normal.		"styles: #normal, #leftRight, #upDown, or #none"
	scalePoint := 1.0@1.0.
	framesToDwell := 1.
	rotatedForm := originalForm.	"cached rotation of originalForm"
	self extent: originalForm extent.
! !

!SketchMorph methodsFor: 'menu' stamp: 'wiz 12/4/2006 00:32'!
insertIntoMovie: evt

	| movies aTarget |
	movies :=
		(self world rootMorphsAt: evt hand targetPoint)
			select: [:m | ((m isKindOf: MovieMorph) or:
						 [m isSketchMorph]) and: [m ~= self]].
	movies isEmpty ifTrue: [^ self].
	aTarget := movies first.
	(aTarget isSketchMorph) ifTrue: [
		aTarget := aTarget replaceSelfWithMovie].
	aTarget insertFrames: (Array with: self).
	self delete.
! !

!SketchMorph methodsFor: 'halos and balloon help' stamp: 'sw 7/3/1999 20:06'!
isLikelyRecipientForMouseOverHalos
	^ true! !

!SketchMorph methodsFor: 'layout' stamp: 'ar 9/22/2000 14:00'!
layoutChanged
	"Update rotatedForm and compute new bounds."
	self changed.
	self generateRotatedForm.
	bounds := bounds origin extent: rotatedForm extent.
	super layoutChanged.
	self changed.
! !

!SketchMorph methodsFor: 'other' stamp: 'sw 12/1/1998 18:16'!
newForm: aForm
	self originalForm: aForm.
	self layoutChanged! !

!SketchMorph methodsFor: 'accessing' stamp: 'sw 12/12/2001 10:49'!
nominalForm: aForm
	"Ascribe the blank nominal form"

	originalForm := aForm.
	self rotationCenter: 0.5@0.5.
	self layoutChanged
! !

!SketchMorph methodsFor: 'accessing' stamp: 'sw 9/9/1998 13:15'!
originalForm: aForm
	originalForm := aForm! !

!SketchMorph methodsFor: 'pen support' stamp: 'jm 4/22/1998 09:26'!
penOnMyForm
	"Support for experiments with drawing under program control. To get started, make a new SketchMorph in a morphic world. In an inspector, give it the desired pixel dimensions with clearExtent:fillColor:. Then use this method to get a pen to which you can send normal pen commands. Reveal the resulting drawing with revealPenStrokes."

	^ Pen newOnForm: originalForm
! !

!SketchMorph methodsFor: 'menu' stamp: 'cmm 8/2/2010 18:15'!
recolorPixelsOfColor: originalColor with: newColor
	"Let the user select a color to be remapped, and then a color to map that color to, then carry it out."
	| d newForm map |
	d := originalForm depth.
	newForm := Form extent: originalForm extent depth: d.
	map := (Color cachedColormapFrom: d to: d) copy.
	map at: (originalColor indexInMap: map) put: (newColor pixelValueForDepth: d).
	newForm copyBits: newForm boundingBox
		from: originalForm at: 0@0
		colorMap: map.
	self form: newForm.
! !

!SketchMorph methodsFor: 'menu' stamp: 'cmm 8/2/2010 18:18'!
recolorPixelsUsing: evt 
	"Let the user select a color to be remapped, and then a color to map that color to, then carry it out."
	| originalColor newColor |
	self inform: 'choose the color you want to replace' translated.
	self
		changeColorTarget: self
		selector: #rememberedColor:
		originalColor: nil
		hand: evt hand.
	"color to replace"
	originalColor := self rememberedColor ifNil: [ ^ self ].
	self inform: 'now choose the color you want to replace it with' translated.
	self
		changeColorTarget: self
		selector: #rememberedColor:
		originalColor: originalColor
		hand: evt hand.
	"new color"
	newColor := self rememberedColor ifNil: [ ^ self ].
	self
		recolorPixelsOfColor: originalColor
		with: newColor! !

!SketchMorph methodsFor: 'menu' stamp: 'ar 8/6/2009 20:45'!
reduceColorPalette: evt
	"Let the user ask for a reduced number of colors in this sketch"

	| str nColors |
	str := UIManager default
		request: 'Please enter a number greater than one.
(note: this cannot be undone, so answer zero
to abort if you need to make a backup first)' translated
		initialAnswer: '256'.
	nColors := Integer readFrom: (ReadStream on: str).
	(nColors between: 2 and: 256) ifFalse: [^ self].

	originalForm := originalForm copyWithColorsReducedTo: nColors.
	rotatedForm := nil.
	self changed! !

!SketchMorph methodsFor: 'caching' stamp: 'di 3/2/98 14:14'!
releaseCachedState
	"Clear cache of rotated, scaled Form."

	super releaseCachedState.
	rotatedForm := nil.
	originalForm hibernate! !

!SketchMorph methodsFor: 'other' stamp: 'jm 7/24/97 15:06'!
replaceSelfWithMovie
	"Replace this SketchMorph in its owner with a MovieMorph containing this sketch as its only frame. This allows a SketchMorph to be turned into a MovieMorph by just insering additional frames."

	| o movie |
	self changed.
	o := self owner.
	movie := MovieMorph new position: self referencePosition.
	movie insertFrames: (Array with: self).
	o ifNil: [^ movie].
	o addMorphFront: movie.
	^ movie
! !

!SketchMorph methodsFor: 'menu' stamp: 'sw 12/12/2001 13:14'!
restoreBaseGraphic
	"Restore the receiver's base graphic"

	| aGraphic |
	((aGraphic := self baseGraphic) notNil and:
				[aGraphic ~= originalForm])
		ifTrue:
			[self form: aGraphic]! !

!SketchMorph methodsFor: 'menu' stamp: 'yo 3/15/2005 13:57'!
restoreBaseGraphicFromMenu
	"Restore the base graphic -- invoked from a menu, so give interactive feedback if appropriate"

	self isInWorld ifFalse: [^ self inform: 

'oops, this menu is a for a morph that
has been replaced, probably because a
"look like" script was run.  Please dismiss
the menu and get a new one!!.  Sorry!!' translated].

	 self baseGraphic = originalForm ifTrue: [^ self inform: 'This object is *already* showing its baseGraphic' translated].
	self restoreBaseGraphic! !

!SketchMorph methodsFor: 'pen support' stamp: 'jm 4/22/1998 09:08'!
revealPenStrokes
	"This message must be sent after a sequence of pen strokes to make the resulting changes visible."

	rotatedForm := nil.
	self changed.
! !

!SketchMorph methodsFor: 'accessing' stamp: ''!
rotatedForm

	rotatedForm ifNil: [self layoutChanged].
	^ rotatedForm
! !

!SketchMorph methodsFor: 'e-toy support' stamp: ''!
rotationStyle

	^ rotationStyle
! !

!SketchMorph methodsFor: 'e-toy support' stamp: 'jm 7/24/97 15:06'!
rotationStyle: aSymbol
	"Set my rotation style to #normal, #leftRight, #upDown, or #none. Styles mean:
		#normal		-- continuous 360 degree rotation
		#leftRight		-- quantize angle to left or right facing
		#upDown		-- quantize angle to up or down facing
		#none			-- do not rotate"

	rotationStyle := aSymbol.
	self layoutChanged.
! !

!SketchMorph methodsFor: 'accessing' stamp: 'gm 2/22/2003 13:14'!
scaleFactor
	"Answer the number representing my scaleFactor, assuming the receiver to be unflexed (if flexed, the renderer's scaleFactor is called instead"

	| qty |
	((qty := self scalePoint) isPoint) ifTrue: [^1.0].
	^qty! !

!SketchMorph methodsFor: 'accessing' stamp: 'jm 7/24/97 15:06'!
scalePoint

	scalePoint ifNil: [scalePoint := 1.0@1.0].
	^ scalePoint
! !

!SketchMorph methodsFor: 'accessing' stamp: 'jm 7/24/97 15:06'!
scalePoint: aPoint

	scalePoint := aPoint.
	self layoutChanged.
! !

!SketchMorph methodsFor: 'accessing' stamp: 'sw 10/24/2000 05:55'!
setNewFormFrom: formOrNil
	"Set the receiver's form as indicated.   If nil is provided, then a default form will be used, possibly retrieved from the receiver's defaultValue property"

	| defaultImage |
	formOrNil ifNotNil: [^ self form: formOrNil].
	defaultImage := self defaultValueOrNil ifNil: [ScriptingSystem squeakyMouseForm].
	self form: defaultImage
! !

!SketchMorph methodsFor: 'menu' stamp: 'ar 8/6/2009 19:09'!
setRotationStyle
	| selections labels sel reply |
	selections := #(normal leftRight upDown none).
	labels := #('rotate smoothly' 'left-right flip only' 'top-down flip only' 'don''t rotate').
	sel := labels at: (selections indexOf: self rotationStyle ifAbsent:[1]).
	labels := labels collect:[:lbl| sel = lbl ifTrue:['<on>', lbl translated] ifFalse:['<off>', lbl translated]].
	reply := UIManager default chooseFrom: labels values: selections.
	reply ifNotNil: [self rotationStyle: reply].
! !

!SketchMorph methodsFor: 'menu' stamp: 'ar 11/19/2001 22:38'!
toggleInterpolation
	^self useInterpolation: self useInterpolation not! !

!SketchMorph methodsFor: 'accessing' stamp: 'ar 11/16/2002 19:22'!
useInterpolation
	^(self valueOfProperty: #useInterpolation ifAbsent:[false]) 
		and:[Smalltalk includesKey: #B3DRenderEngine]! !

!SketchMorph methodsFor: 'accessing' stamp: 'nk 1/24/2004 23:46'!
useInterpolation: aBool
	(aBool == true and: [ Smalltalk includesKey: #B3DRenderEngine ])
		ifTrue:[self setProperty: #useInterpolation toValue: aBool]
		ifFalse:[self removeProperty: #useInterpolation].
	self layoutChanged. "to regenerate the form"
! !

!SketchMorph methodsFor: 'menu' stamp: 'dgd 9/6/2003 18:27'!
useInterpolationString
	^ (self useInterpolation
		ifTrue: ['<yes>']
		ifFalse: ['<no>'])
		, 'smooth image' translated! !

!SketchMorph methodsFor: 'halos and balloon help' stamp: 'ar 11/29/2001 19:51'!
wantsDirectionHandles
	^self valueOfProperty: #wantsDirectionHandles ifAbsent:[
		Preferences showDirectionHandles or:[Preferences showDirectionForSketches]]! !

!SketchMorph methodsFor: 'halos and balloon help' stamp: 'ar 11/29/2001 19:52'!
wantsDirectionHandles: aBool
	aBool == (Preferences showDirectionHandles or:[Preferences showDirectionForSketches])
		ifTrue:[self removeProperty: #wantsDirectionHandles]
		ifFalse:[self setProperty: #wantsDirectionHandles toValue: aBool].! !

!SketchMorph methodsFor: 'e-toy support' stamp: 'dgd 8/29/2004 11:05'!
wantsRecolorHandle
	"Answer whether the receiver would like a recolor handle to be  
	put up for it. We'd want to disable this but for the moment  
	that would cut off access to the button part of the properties  
	sheet. So this remains a loose end."
	^ false! !

!SketchMorph methodsFor: 'accessing' stamp: 'nk 6/12/2004 09:32'!
wantsSimpleSketchMorphHandles
	"Answer true if my halo's simple handles should include the simple sketch morph handles."
	^self isMemberOf: SketchMorph! !

DisplayObject subclass: #PathFromMorphic
	instanceVariableNames: 'form collectionOfPoints'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Laser-Game-Graphics'!

!PathFromMorphic commentStamp: '<historical>' prior: 0!
I am the abstract superclass of the Graphic spatial primitives. I represent an ordered sequence of Points. Spatial primitives are used to generate "trajectories" such as lines and circles.!

PathFromMorphic subclass: #Arc
	instanceVariableNames: 'quadrant radius center'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Laser-Game-Graphics'!

!Arc commentStamp: '<historical>' prior: 0!
Arcs are an unusual implementation of splines due to Ted Kaehler.  Imagine two lines that meet at a corner. Now imagine two moving points; one moves from the corner to the end on one line, the other moves from the end of the other line in to the corner.  Now imagine a series of lines drawn between those moving points at each step along the way (they form a sort of spider web pattern).  By connecting segments of the intersecting lines, a smooth curve is achieved that is tangent to both of the original lines.  Voila.!

!Arc class methodsFor: 'examples' stamp: ''!
example
	"Click the button somewhere on the screen. The designated point will
	be the center of an Arc with radius 50 in the 4th quadrant."

	| anArc aForm |
	aForm := Form extent: 1 @ 30.	"make a long thin Form for display"
	aForm fillBlack.						"turn it black"
	anArc := Arc new.
	anArc form: aForm.					"set the form for display"
	anArc radius: 50.0.
	anArc center: Sensor waitButton.
	anArc quadrant: 4.
	anArc displayOn: Display.
	Sensor waitButton

	"Arc example"! !

!Arc methodsFor: 'accessing' stamp: ''!
center
	"Answer the point at the center of the receiver."

	^center! !

!Arc methodsFor: 'accessing' stamp: ''!
center: aPoint 
	"Set aPoint to be the receiver's center."

	center := aPoint! !

!Arc methodsFor: 'accessing' stamp: ''!
center: aPoint radius: anInteger 
	"The receiver is defined by a point at the center and a radius. The 
	quadrant is not reset."

	center := aPoint.
	radius := anInteger! !

!Arc methodsFor: 'accessing' stamp: ''!
center: aPoint radius: anInteger quadrant: section 
	"Set the receiver's quadrant to be the argument, section. The size of the 
	receiver is defined by the center and its radius."

	center := aPoint.
	radius := anInteger.
	quadrant := section! !

!Arc methodsFor: 'display box access' stamp: ''!
computeBoundingBox
	| aRectangle aPoint |
	aRectangle := center - radius + form offset extent: form extent + (radius * 2) asPoint.
	aPoint := center + form extent.
	quadrant = 1 ifTrue: [^ aRectangle encompass: center x @ aPoint y].
	quadrant = 2 ifTrue: [^ aRectangle encompass: aPoint x @ aPoint y].
	quadrant = 3 ifTrue: [^ aRectangle encompass: aPoint x @ center y].
	quadrant = 4 ifTrue: [^ aRectangle encompass: center x @ center y]! !

!Arc methodsFor: 'displaying' stamp: 'nice 12/27/2009 04:00'!
displayOn: aDisplayMedium at: aPoint clippingBox: clipRect rule: anInteger fillColor: aForm

	| nSegments line angle sin cos xn yn |
	nSegments := 12.0.
	line := Line new.
	line form: self form.
	angle := 90.0 / nSegments.
	sin := (angle * (2 * Float pi / 360.0)) sin.
	cos := (angle * (2 * Float pi / 360.0)) cos.
	quadrant = 1
		ifTrue: 
			[xn := radius asFloat.
			yn := 0.0].
	quadrant = 2
		ifTrue: 
			[xn := 0.0.
			yn := 0.0 - radius asFloat].
	quadrant = 3
		ifTrue: 
			[xn := 0.0 - radius asFloat.
			yn := 0.0].
	quadrant = 4
		ifTrue: 
			[xn := 0.0.
			yn := radius asFloat].
	nSegments asInteger
		timesRepeat: 
			[ | xn1 yn1 |
			xn1 := xn * cos + (yn * sin).
			yn1 := yn * cos - (xn * sin).
			line beginPoint: center + (xn asInteger @ yn asInteger).
			line endPoint: center + (xn1 asInteger @ yn1 asInteger).
			line
				displayOn: aDisplayMedium
				at: aPoint
				clippingBox: clipRect
				rule: anInteger
				fillColor: aForm.
			xn := xn1.
			yn := yn1]! !

!Arc methodsFor: 'displaying' stamp: ''!
displayOn: aDisplayMedium transformation: aTransformation clippingBox: clipRect rule: anInteger fillColor: aForm

	| newArc tempCenter |
	newArc := Arc new.
	tempCenter := aTransformation applyTo: self center.
	newArc center: tempCenter x asInteger @ tempCenter y asInteger.
	newArc quadrant: self quadrant.
	newArc radius: (self radius * aTransformation scale x) asInteger.
	newArc form: self form.
	newArc
		displayOn: aDisplayMedium
		at: 0 @ 0
		clippingBox: clipRect
		rule: anInteger
		fillColor: aForm! !

!Arc methodsFor: 'accessing' stamp: ''!
quadrant
	"Answer the part of the circle represented by the receiver."
	^quadrant! !

!Arc methodsFor: 'accessing' stamp: ''!
quadrant: section 
	"Set the part of the circle represented by the receiver to be the argument, 
	section."

	quadrant := section! !

!Arc methodsFor: 'accessing' stamp: ''!
radius
	"Answer the receiver's radius."

	^radius! !

!Arc methodsFor: 'accessing' stamp: ''!
radius: anInteger 
	"Set the receiver's radius to be the argument, anInteger."

	radius := anInteger! !

Arc subclass: #Circle
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Laser-Game-Graphics'!

!Circle commentStamp: '<historical>' prior: 0!
I represent a full circle. I am made from four Arcs.!

!Circle class methodsFor: 'examples' stamp: ''!
exampleOne 
	"Click any button somewhere on the screen. The point will be the center
	of the circcle of radius 150."

	| aCircle aForm |
	aForm := Form extent: 1@30.
	aForm fillBlack.
	aCircle := Circle new.
	aCircle form: aForm.
	aCircle radius: 150.
	aCircle center: Sensor waitButton.
	aCircle displayOn: Display
	
	"Circle exampleOne"! !

!Circle class methodsFor: 'examples' stamp: ''!
exampleTwo
	"Designate a rectangular area that should be used as the brush for
	displaying the circle. Click any button at a point on the screen which
	will be the center location for the circle. The curve will be displayed
	with a long black form."

	| aCircle aForm |
	aForm := Form fromUser.
	aCircle := Circle new.
	aCircle form: aForm.
	aCircle radius: 150.
	aCircle center: Sensor waitButton.
	aCircle displayOn: Display at: 0 @ 0 rule: Form reverse
 
	 "Circle exampleTwo"! !

!Circle methodsFor: 'display box access' stamp: ''!
computeBoundingBox

	^center - radius + form offset extent: form extent + (radius * 2) asPoint! !

!Circle methodsFor: 'displaying' stamp: ''!
displayOn: aDisplayMedium at: aPoint clippingBox: clipRect rule: anInteger fillColor: aForm

	1 to: 4 do:
		[:i |
		super quadrant: i.
		super displayOn: aDisplayMedium
			at: aPoint
			clippingBox: clipRect
			rule: anInteger
			fillColor: aForm]! !

!Circle methodsFor: 'displaying' stamp: ''!
displayOn: aDisplayMedium transformation: aTransformation clippingBox: clipRect rule: anInteger fillColor: aForm

	1 to: 4 do:
		[:i |
		super quadrant: i.
		super displayOn: aDisplayMedium
			transformation: aTransformation
			clippingBox: clipRect
			rule: anInteger
			fillColor: aForm]! !

PathFromMorphic subclass: #Line
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Laser-Game-Graphics'!

!Line commentStamp: '<historical>' prior: 0!
I represent the line segment specified by two points.!

!Line class methodsFor: 'examples' stamp: ''!
example
	"Designate two places on the screen by clicking any mouse button. A
	straight path with a square black form will be displayed connecting the
	two selected points."

	| aLine aForm |  
	aForm := Form extent: 20@20.		"make a form one quarter of inch square"
	aForm fillBlack.							"turn it black"
	aLine := Line new.
	aLine form: aForm.						"use the black form for display"
	aLine beginPoint: Sensor waitButton. Sensor waitNoButton.
	aForm displayOn: Display at: aLine beginPoint.	
	aLine endPoint: Sensor waitButton.
	aLine displayOn: Display.				"display the line"

	"Line example"! !

!Line class methodsFor: 'instance creation' stamp: ''!
from: beginPoint to: endPoint withForm: aForm 
	"Answer an instance of me with end points begingPoint and endPoint; 
	the source form for displaying the line is aForm."

	| newSelf | 
	newSelf := super new: 2.
	newSelf add: beginPoint.
	newSelf add: endPoint.
	newSelf form: aForm.
	^newSelf! !

!Line class methodsFor: 'instance creation' stamp: ''!
new

	| newSelf | 
	newSelf := super new: 2.
	newSelf add: 0@0.
	newSelf add: 0@0.
	^newSelf! !

!Line methodsFor: 'accessing' stamp: ''!
beginPoint
	"Answer the first end point of the receiver."

	^self first! !

!Line methodsFor: 'accessing' stamp: ''!
beginPoint: aPoint 
	"Set the first end point of the receiver to be the argument, aPoint. 
	Answer aPoint."

	self at: 1 put: aPoint.
	^aPoint! !

!Line methodsFor: 'displaying' stamp: ''!
displayOn: aDisplayMedium at: aPoint clippingBox: clipRect rule: anInteger fillColor: aForm 
	"The form associated with this Path will be displayed, according  
	to one of the sixteen functions of two logical variables (rule), at  
	each point on the Line. Also the source form will be first anded  
	with aForm as a mask. Does not effect the state of the Path."

	collectionOfPoints size < 2 ifTrue: [self error: 'a line must have two points'].
	aDisplayMedium
		drawLine: self form
		from: self beginPoint + aPoint
		to: self endPoint + aPoint
		clippingBox: clipRect
		rule: anInteger
		fillColor: aForm! !

!Line methodsFor: 'displaying' stamp: ''!
displayOn: aDisplayMedium transformation: aTransformation clippingBox: clipRect rule: anInteger fillColor: aForm

	| newPath newLine |
	newPath := aTransformation applyTo: self.
	newLine := Line new.
	newLine beginPoint: newPath firstPoint.
	newLine endPoint: newPath secondPoint.
	newLine form: self form.
	newLine
		displayOn: aDisplayMedium
		at: 0 @ 0
		clippingBox: clipRect
		rule: anInteger
		fillColor: aForm! !

!Line methodsFor: 'displaying' stamp: ''!
displayOnPort: aPort at: aPoint 
	aPort sourceForm: self form; combinationRule: Form under; fillColor: nil.
	aPort drawFrom: collectionOfPoints first + aPoint
		to: collectionOfPoints last + aPoint! !

!Line methodsFor: 'accessing' stamp: ''!
endPoint
	"Answer the last end point of the receiver."

	^self last! !

!Line methodsFor: 'accessing' stamp: ''!
endPoint: aPoint 
	"Set the first end point of the receiver to be the argument, aPoint. 
	Answer aPoint."

	self at: 2 put: aPoint.
	^aPoint! !

!PathFromMorphic class methodsFor: 'examples' stamp: 'phm 10/21/2012 04:48'!
example
	"Creates a Path from mousePoints and displays it several ways on the display screen. Messes up the display. For learning about class Path, just select the code below and execute it to create a path and see it redisplayed in another place on the screen. Each path displays using a different form. A path is indicated by pressing the red mouse button in a sequence; press any other mouse button to terminate. "

	| aPath aForm pl fl flag |
	aForm := Form extent: 2 @ 40.		"creates a form one inch long"
	aForm fillBlack.							"turns it black"
	aPath := PathFromMorphic new.
	aPath form: aForm.						"use the long black form for displaying"
	flag := true.
	[flag]
		whileTrue: 
			[Sensor waitButton.
			Sensor redButtonPressed
				ifTrue: 
					[aPath add: Sensor waitButton.
					Sensor waitNoButton.
					aForm displayOn: Display at: aPath last]
				ifFalse: [flag := false]].
	Display fillWhite.
	aPath displayOn: Display.			"the original path"
	pl := aPath translateBy: 0 @ 100.
	fl := Form extent: 40 @ 40.
	fl fillGray.
	pl form: fl.
	pl displayOn: Display.				"the translated path"
	Sensor waitNoButton

	"Path example"! !

!PathFromMorphic class methodsFor: 'instance creation' stamp: ''!
new

	^self basicNew initializeCollectionOfPoints! !

!PathFromMorphic class methodsFor: 'instance creation' stamp: ''!
new: anInteger

	^self basicNew initializeCollectionOfPoints: anInteger! !

!PathFromMorphic methodsFor: 'adding' stamp: 'nice 3/20/2010 08:02'!
add: aPoint 
	"Include aPoint as one of the receiver's elements."

	^collectionOfPoints add: aPoint! !

!PathFromMorphic methodsFor: 'accessing' stamp: ''!
at: index 
	"Answer the point on the receiver's path at position index."

	^collectionOfPoints at: index! !

!PathFromMorphic methodsFor: 'accessing' stamp: ''!
at: index put: aPoint 
	"Store the argument, aPoint, as the point on the receiver's path at position
	index."

	^collectionOfPoints at: index put: aPoint! !

!PathFromMorphic methodsFor: 'enumerating' stamp: ''!
collect: aBlock 
	"Evaluate aBlock with each of the receiver's elements as the argument. 
	Collect the resulting values into a path that is like the receiver. Answer 
	the new path."

	| newCollection |
	newCollection := collectionOfPoints collect: aBlock.
	newCollection form: self form.
	^newCollection! !

!PathFromMorphic methodsFor: 'display box access' stamp: 'nice 12/27/2009 22:38'!
computeBoundingBox 
	"Refer to the comment in DisplayObject|computeBoundingBox."

	| box |
	box := Rectangle origin: (self at: 1) extent: 0 @ 0.
	collectionOfPoints do: 
		[:aPoint | box swallow: (Rectangle origin: aPoint extent: 0 @ 0)].
	^box! !

!PathFromMorphic methodsFor: 'displaying' stamp: ''!
displayOn: aDisplayMedium at: aDisplayPoint clippingBox: clipRectangle rule: ruleInteger fillColor: aForm 
	"Display this Path--offset by aPoint, clipped by clipRect and the form 
	associated with this Path will be displayedr according to one of the sixteen 
	functions of two logical variables (rule). Also the source form will be first 
	anded with aForm as a mask. Does not effect the state of the Path"

	collectionOfPoints do: 
		[:element | 
		self form
			displayOn: aDisplayMedium
			at: element + aDisplayPoint
			clippingBox: clipRectangle
			rule: ruleInteger
			fillColor: aForm]! !

!PathFromMorphic methodsFor: 'displaying' stamp: 'phm 10/21/2012 04:48'!
displayOn: aDisplayMedium transformation: displayTransformation clippingBox: clipRectangle rule: ruleInteger fillColor: aForm 
	"Displays this path, translated and scaled by aTransformation. Get the
	scaled and translated Path."

	| newPath transformedPath |
	transformedPath := displayTransformation applyTo: self.
	newPath := PathFromMorphic new.
	transformedPath do: [:point | newPath add: point].
	newPath form: self form.
	newPath
		displayOn: aDisplayMedium
		at: 0 @ 0
		clippingBox: clipRectangle
		rule: ruleInteger
		fillColor: aForm! !

!PathFromMorphic methodsFor: 'accessing' stamp: ''!
first
	"Answer the first point on the receiver's path; included to correspond to 
	OrderedCollection protocol."

	^collectionOfPoints first! !

!PathFromMorphic methodsFor: 'accessing' stamp: ''!
firstPoint
	"Answer the first point on the receiver's path."

	^collectionOfPoints first! !

!PathFromMorphic methodsFor: 'accessing' stamp: ''!
firstPoint: aPoint 
	"Replace the first element of the receiver with the new value aPoint. 
	Answer the argument aPoint."

	collectionOfPoints at: 1 put: aPoint.
	^aPoint! !

!PathFromMorphic methodsFor: 'accessing' stamp: ''!
form
	"Answer the receiver's form, or, if form is nil, then answer a 1 x 1 black 
	form (a black dot)."

	| aForm |
	form == nil
		ifTrue: 
			[aForm := Form extent: 1 @ 1.
			aForm fillBlack.
			^aForm]
		ifFalse: 
			[^form]! !

!PathFromMorphic methodsFor: 'accessing' stamp: ''!
form: aForm 
	"Make the argument, aForm, be the receiver's form."

	form := aForm! !

!PathFromMorphic methodsFor: 'private' stamp: ''!
initializeCollectionOfPoints

	collectionOfPoints := OrderedCollection new! !

!PathFromMorphic methodsFor: 'private' stamp: ''!
initializeCollectionOfPoints: anInteger

	collectionOfPoints := OrderedCollection new: anInteger! !

!PathFromMorphic methodsFor: 'testing' stamp: ''!
isEmpty

	^collectionOfPoints isEmpty! !

!PathFromMorphic methodsFor: 'accessing' stamp: ''!
last
	"Answer the last point on the receiver's path; included to correspond to 
	OrderedCollection protocol."

	^collectionOfPoints last! !

!PathFromMorphic methodsFor: 'accessing' stamp: ''!
offset
	"There are basically two kinds of display objects in the system: those
	that, when asked to transform themselves, create a new object; and those
	that side effect themselves by maintaining a record of the transformation
	request (typically an offset). Path, like Rectangle and Point, is a display
	object of the first kind."

	self shouldNotImplement! !

!PathFromMorphic methodsFor: 'removing' stamp: 'di 4/4/2000 12:33'!
removeAllSuchThat: aBlock 
	"Evaluate aBlock for each element of the receiver.
	Remove each element for which aBlock evaluates to true."

	collectionOfPoints removeAllSuchThat: aBlock.
! !

!PathFromMorphic methodsFor: 'transforming' stamp: 'jrm 9/1/1999 21:26'!
scaleBy: aPoint 
	"Answers a new Path scaled by aPoint. Does not affect the current data in 
	this Path."

	| newPath | 
	newPath := self species new: self size. 
	newPath form: self form.
	collectionOfPoints do: [:element | newPath add: (element scaleBy: aPoint)].
	^newPath! !

!PathFromMorphic methodsFor: 'accessing' stamp: ''!
secondPoint
	"Answer the second element of the receiver."

	^collectionOfPoints at: 2! !

!PathFromMorphic methodsFor: 'accessing' stamp: ''!
secondPoint: aPoint 
	"Replace the second element of the receiver with the new value aPoint. 
	Answer the argument aPoint."

	collectionOfPoints at: 2 put: aPoint.
	^aPoint! !

!PathFromMorphic methodsFor: 'enumerating' stamp: ''!
select: aBlock 
	"Evaluate aBlock with each of the receiver's elements as the argument. 
	Collect into a new path like the receiver only those elements for which 
	aBlock evaluates to true. Answer the new path."

	| newCollection |
	newCollection := collectionOfPoints select: aBlock.
	newCollection form: self form.
	^newCollection! !

!PathFromMorphic methodsFor: 'accessing' stamp: ''!
size
	"Answer the length of the receiver."

	^collectionOfPoints size! !

!PathFromMorphic methodsFor: 'accessing' stamp: ''!
thirdPoint
	"Answer the third element of the receiver."

	^collectionOfPoints at: 3! !

!PathFromMorphic methodsFor: 'accessing' stamp: ''!
thirdPoint: aPoint 
	"Replace the third element of the receiver with the new value aPoint. 
	Answer the argument aPoint."

	collectionOfPoints at: 3 put: aPoint.
	^aPoint! !

!PathFromMorphic methodsFor: 'transforming' stamp: 'jrm 9/1/1999 21:28'!
translateBy: aPoint 
	"Answers a new Path whose elements are translated by aPoint. Does not
	affect the elements of this Path."

	| newPath |
	newPath := self species new: self size.
	newPath form: self form.
	collectionOfPoints do: [:element | newPath add: (element translateBy: aPoint)].
	^newPath! !

!Form methodsFor: '*Laser-Game' stamp: 'sbw 7/3/2007 16:37'!
anyOfColor: aColor inColumn: int
	| color |
	1 to: self height do: [:row |
		color := self colorAt: int@row.
		color = aColor ifTrue: [^true]].
	^false! !

!Form methodsFor: '*Laser-Game' stamp: 'sbw 7/3/2007 16:43'!
anyOfColor: aColor inRow: int
	| color |
	1 to: self width do: [:column |
		color := self colorAt: column@int.
		color = aColor ifTrue: [^true]].
	^false! !

!Form methodsFor: '*Laser-Game' stamp: 'sbw 7/3/2007 16:40'!
firstColumnOfColorFromLeft: aColor
	| x |
	x := 1.
	[self anyOfColor: aColor inColumn: x] whileFalse: [
		x := x + 1.
		x >= self width ifTrue: [^nil]].
	^x! !

!Form methodsFor: '*Laser-Game' stamp: 'sbw 7/3/2007 16:41'!
firstColumnOfColorFromRight: aColor
	| x |
	x := self width.
	[self anyOfColor: aColor inColumn: x] whileFalse: [
		x := x - 1.
		x <= 1 ifTrue: [^nil]].
	^x! !

!Form methodsFor: '*Laser-Game' stamp: 'sbw 7/3/2007 16:44'!
firstRowOfColorFromBottom: aColor
	| y |
	y := height.
	[self anyOfColor: aColor inRow: y] whileFalse: [
		y := y - 1.
		y <= 1 ifTrue: [^nil]].
	^y! !

!Form methodsFor: '*Laser-Game' stamp: 'sbw 7/3/2007 16:44'!
firstRowOfColorFromTop: aColor
	| y |
	y := 1.
	[self anyOfColor: aColor inRow: y] whileFalse: [
		y := y + 1.
		y >= self height ifTrue: [^nil]].
	^y! !

!Form methodsFor: '*Laser-Game' stamp: 'sbw 7/3/2007 16:46'!
tightRectangleAroundColor: aColor
	| left right top bottom |
	left := self firstColumnOfColorFromLeft: aColor.
	right := self firstColumnOfColorFromRight: aColor.
	top := self firstRowOfColorFromTop: aColor.
	bottom := self firstRowOfColorFromBottom: aColor.
	^left@top corner: right@bottom! !

Object subclass: #Cell
	instanceVariableNames: 'activeSegments exitSides gridLocation'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Laser-Game-Model'!

Cell subclass: #BlankCell
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Laser-Game-Model'!

!BlankCell methodsFor: 'initialize-release' stamp: 'sbw 5/19/2007 22:06'!
initialize
	super initialize.
	self initializeExitSides.
	! !

!BlankCell methodsFor: 'initialize-release' stamp: 'sbw 5/19/2007 22:06'!
initializeExitSides
	self exitSides: Dictionary new.
	self exitSides at: #north put: #south.
	self exitSides at: #east put: #west.
	self exitSides at: #south put: #north.
	self exitSides at: #west put: #east.
	! !

!Cell methodsFor: 'accessing' stamp: 'sbw 5/19/2007 21:56'!
activeSegments
	"Answer the value of activeSegments"

	^ activeSegments! !

!Cell methodsFor: 'accessing' stamp: 'sbw 5/19/2007 22:04'!
activeSegments: aDictionary
	"Set the value of activeSegments"

	activeSegments := aDictionary! !

!Cell methodsFor: 'accessing' stamp: 'sbw 5/28/2007 14:45'!
clearCell
	self initializeActiveSegments! !

!Cell methodsFor: 'accessing' stamp: 'sbw 5/19/2007 22:39'!
exitSideFor: aSymbol
	^self exitSides at: aSymbol! !

!Cell methodsFor: 'accessing' stamp: 'sbw 5/19/2007 22:04'!
exitSides
	"Answer the value of exitSides"

	^ exitSides! !

!Cell methodsFor: 'accessing' stamp: 'sbw 5/19/2007 22:04'!
exitSides: aDictionary
	"Set the value of exitSides"

	exitSides := aDictionary! !

!Cell methodsFor: 'accessing' stamp: 'sbw 5/20/2007 21:30'!
gridLocation
	"Answer the value of gridLocation"

	^ gridLocation! !

!Cell methodsFor: 'accessing' stamp: 'sbw 5/20/2007 21:30'!
gridLocation: anObject
	"Set the value of gridLocation"

	gridLocation := anObject! !

!Cell methodsFor: 'initialize-release' stamp: 'sbw 5/19/2007 22:06'!
initialize
	super initialize.
	self initializeActiveSegments.
! !

!Cell methodsFor: 'initialize-release' stamp: 'sbw 5/19/2007 22:05'!
initializeActiveSegments
	self activeSegments: Dictionary new.
	self activeSegments at: #north put: false.
	self activeSegments at: #east put: false.
	self activeSegments at: #south put: false.
	self activeSegments at: #west put: false.
	! !

!Cell methodsFor: 'testing' stamp: 'sbw 5/19/2007 22:40'!
isOff
	^self isOn not! !

!Cell methodsFor: 'testing' stamp: 'sbw 5/19/2007 22:40'!
isOn
	^self activeSegments values anySatisfy: [:each | each = true]! !

!Cell methodsFor: 'testing' stamp: 'sbw 5/19/2007 22:42'!
isSegmentOnFor: aSymbol
	^self activeSegments at: aSymbol! !

!Cell methodsFor: 'accessing' stamp: 'sbw 5/19/2007 22:42'!
laserEntersFrom: aSymbol
	| exit |
	self activeSegments at: aSymbol put: true.
	exit := self exitSideFor: aSymbol.
	self activeSegments at: exit put: true.! !

!Cell methodsFor: 'printing' stamp: 'sbw 6/14/2007 20:34'!
printOn: aStream
	super printOn: aStream.
	aStream
		cr;
		nextPutAll: '  location = ', self gridLocation asString;
		cr;
		nextPutAll: '  ';
		nextPutAll: (self isOn ifTrue: ['ON'] ifFalse: ['OFF'])! !

!Cell methodsFor: 'actions' stamp: 'sbw 6/20/2007 17:58'!
rotateClockwise! !

!Cell methodsFor: 'actions' stamp: 'sbw 6/20/2007 17:59'!
rotateCounterClockwise! !

Cell subclass: #MirrorCell
	instanceVariableNames: 'leansLeft'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Laser-Game-Model'!

!MirrorCell class methodsFor: 'instance creation' stamp: 'sbw 5/20/2007 07:49'!
leanLeft
	^super new leanLeft! !

!MirrorCell class methodsFor: 'instance creation' stamp: 'sbw 5/20/2007 07:49'!
leanRight
	^super new leanRight! !

!MirrorCell methodsFor: 'initialize-release' stamp: 'sbw 5/19/2007 22:36'!
initialize
	super initialize.
	self initializeExitSides.
	self leanLeft! !

!MirrorCell methodsFor: 'initialize-release' stamp: 'sbw 5/19/2007 22:26'!
initializeExitSides
	self exitSides: Dictionary new.
	! !

!MirrorCell methodsFor: 'testing' stamp: 'sbw 5/19/2007 21:37'!
isLeft
	^self leansLeft! !

!MirrorCell methodsFor: 'testing' stamp: 'sbw 5/19/2007 21:37'!
isRight
	^self isLeft not! !

!MirrorCell methodsFor: 'accessing' stamp: 'sbw 5/19/2007 22:32'!
leanLeft
	self leansLeft: true.
	self exitSides at: #north put: #east.
	self exitSides at: #east put: #north.
	self exitSides at: #south put: #west.
	self exitSides at: #west put: #south.
	! !

!MirrorCell methodsFor: 'accessing' stamp: 'sbw 5/19/2007 22:32'!
leanRight
	self leansLeft: false.
	self exitSides at: #north put: #west.
	self exitSides at: #east put: #south.
	self exitSides at: #south put: #east.
	self exitSides at: #west put: #north.
	! !

!MirrorCell methodsFor: 'accessing' stamp: 'sbw 5/19/2007 21:34'!
leansLeft
	"Answer the value of leansLeft"

	^ leansLeft! !

!MirrorCell methodsFor: 'accessing' stamp: 'sbw 5/19/2007 21:34'!
leansLeft: anObject
	"Set the value of leansLeft"

	leansLeft := anObject! !

!MirrorCell methodsFor: 'actions' stamp: 'sbw 6/14/2007 21:14'!
rotate
	self isLeft
		ifTrue: [self leanRight]
		ifFalse: [self leanLeft]
! !

!MirrorCell methodsFor: 'actions' stamp: 'sbw 6/13/2007 18:27'!
rotateClockwise
	self rotate! !

!MirrorCell methodsFor: 'actions' stamp: 'sbw 6/13/2007 18:27'!
rotateCounterClockwise
	self rotate! !

Cell subclass: #TargetCell
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Laser-Game-Model'!

!TargetCell methodsFor: 'initialize-release' stamp: 'sbw 5/20/2007 08:06'!
initialize
	super initialize.
	self initializeExitSides.
	! !

!TargetCell methodsFor: 'initialize-release' stamp: 'sbw 5/20/2007 08:02'!
initializeExitSides
	self exitSides: Dictionary new.
	self exitSides at: #north put: nil.
	self exitSides at: #east put: nil.
	self exitSides at: #south put: nil.
	self exitSides at: #west put: nil.
	! !

Object subclass: #CellClickRegion
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Laser-Game-Graphics'!

!CellClickRegion class methodsFor: 'as yet unclassified' stamp: 'sbw 6/2/2007 21:03'!
clickRegionForPoint: aPoint
	^self sortedSubclasses detect: [:cls | cls regionRectangle containsPoint: aPoint]! !

!CellClickRegion class methodsFor: 'as yet unclassified' stamp: 'sbw 6/21/2007 22:36'!
mouseUpWithinCellAtPoint: aPoint cell: aCell withinGrid: aGrid
	^aCell! !

!CellClickRegion class methodsFor: 'as yet unclassified' stamp: 'sbw 6/13/2007 17:46'!
scaledHintArrowAndOffsetFromWithinCell: aPoint
	^nil! !

!CellClickRegion class methodsFor: 'as yet unclassified' stamp: 'sbw 6/2/2007 21:03'!
sortedSubclasses
	^self subclasses asSortedCollection: [:a :b | a sortIndex < b sortIndex]! !

CellClickRegion subclass: #CellClickRegionIgnore
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Laser-Game-Graphics'!

!CellClickRegionIgnore class methodsFor: 'as yet unclassified' stamp: 'sbw 5/28/2007 17:31'!
regionRectangle
	^0@0 extent: CellRenderer cellExtent! !

!CellClickRegionIgnore class methodsFor: 'as yet unclassified' stamp: 'sbw 6/2/2007 21:02'!
sortIndex
	^3! !

CellClickRegion subclass: #CellClickRegionInside
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Laser-Game-Graphics'!

!CellClickRegionInside class methodsFor: 'as yet unclassified' stamp: 'sbw 6/23/2007 13:24'!
canActOnCellAtPoint: aPoint cell: aCell withinGrid: aGrid
	| pushRegion |
	pushRegion := self pushRegionForPoint: aPoint.
	^pushRegion canPushCell: aCell withinGrid: aGrid! !

!CellClickRegionInside class methodsFor: 'as yet unclassified' stamp: 'sbw 6/21/2007 22:38'!
mouseUpWithinCellAtPoint: aPoint cell: aCell withinGrid: aGrid
	| pushRegion |
	pushRegion := self pushRegionForPoint: aPoint.
	^pushRegion mouseUpForCell: aCell withinGrid: aGrid! !

!CellClickRegionInside class methodsFor: 'as yet unclassified' stamp: 'sbw 6/3/2007 22:32'!
pointIsUnderHeadingDownLine: aPoint
	| realX realY lineY |
	realX := aPoint x.
	realY := aPoint y.
	lineY := self yForHeadingDownLineWith: realX.
	^realY < lineY! !

!CellClickRegionInside class methodsFor: 'as yet unclassified' stamp: 'sbw 6/3/2007 22:33'!
pointIsUnderHeadingUpLine: aPoint
	| realX realY lineY |
	realX := aPoint x.
	realY := aPoint y.
	lineY := self yForHeadingUpLineWith: realX.
	^realY < lineY! !

!CellClickRegionInside class methodsFor: 'as yet unclassified' stamp: 'sbw 6/2/2007 21:23'!
pushRegionForPoint: aPoint
	^self subclasses detect: [:cls | cls containsPoint: aPoint]! !

!CellClickRegionInside class methodsFor: 'as yet unclassified' stamp: 'sbw 6/2/2007 22:13'!
regionRectangle
	"CellClickRegionInside regionRectangle"
	| outer delta |
	outer := 0@0 extent: CellRenderer cellExtent.
	delta := CellRenderer cellExtent - CellRenderer insideRegionExtent.
	^outer insetBy: (delta // 2)! !

!CellClickRegionInside class methodsFor: 'as yet unclassified' stamp: 'sbw 7/3/2007 16:53'!
scaledHintArrowAndOffsetFromWithinCell: aPoint
	| pushRegion arrow tinyArrow offset |
	pushRegion := self pushRegionForPoint: aPoint.
	arrow := pushRegion arrowForm.
	tinyArrow := arrow scaledToSize: CellRenderer cellExtent - 2.
	offset := (CellRenderer cellExtent - tinyArrow extent) // 2.
	^offset->tinyArrow! !

!CellClickRegionInside class methodsFor: 'as yet unclassified' stamp: 'sbw 6/2/2007 21:02'!
sortIndex
	^1! !

!CellClickRegionInside class methodsFor: 'as yet unclassified' stamp: 'sbw 6/26/2007 12:02'!
yForHeadingDownLineWith: x
	^CellRenderer cellExtent x - x! !

!CellClickRegionInside class methodsFor: 'as yet unclassified' stamp: 'sbw 6/3/2007 22:25'!
yForHeadingUpLineWith: x
	^x! !

CellClickRegionInside subclass: #CellClickRegionPushEast
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Laser-Game-Graphics'!

!CellClickRegionPushEast class methodsFor: 'as yet unclassified' stamp: 'sbw 6/8/2007 00:05'!
arrowForm
	^LaserGameForms eastArrow! !

!CellClickRegionPushEast class methodsFor: 'as yet unclassified' stamp: 'sbw 6/23/2007 13:20'!
canPushCell: aCell withinGrid: aGrid
	^aGrid canPushCellEastFromLocation: aCell gridLocation! !

!CellClickRegionPushEast class methodsFor: 'as yet unclassified' stamp: 'sbw 6/3/2007 22:39'!
containsPoint: aPoint
	| underHeadingDown underHeadingUp |
	underHeadingDown := self pointIsUnderHeadingDownLine: aPoint.
	underHeadingUp := self pointIsUnderHeadingUpLine: aPoint.
	^underHeadingDown and: [underHeadingUp not]! !

!CellClickRegionPushEast class methodsFor: 'as yet unclassified' stamp: 'sbw 6/21/2007 22:45'!
mouseUpForCell: aCell withinGrid: aGrid
	^aGrid pushCellEastFromLocation: aCell gridLocation! !

CellClickRegionInside subclass: #CellClickRegionPushNorth
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Laser-Game-Graphics'!

!CellClickRegionPushNorth class methodsFor: 'as yet unclassified' stamp: 'sbw 6/8/2007 00:05'!
arrowForm
	^LaserGameForms northArrow! !

!CellClickRegionPushNorth class methodsFor: 'as yet unclassified' stamp: 'sbw 6/23/2007 13:20'!
canPushCell: aCell withinGrid: aGrid
	^aGrid canPushCellNorthFromLocation: aCell gridLocation! !

!CellClickRegionPushNorth class methodsFor: 'as yet unclassified' stamp: 'sbw 6/3/2007 22:40'!
containsPoint: aPoint
	| underHeadingDown underHeadingUp |
	underHeadingDown := self pointIsUnderHeadingDownLine: aPoint.
	underHeadingUp := self pointIsUnderHeadingUpLine: aPoint.
	^underHeadingDown not and: [underHeadingUp not]! !

!CellClickRegionPushNorth class methodsFor: 'as yet unclassified' stamp: 'sbw 6/21/2007 22:56'!
mouseUpForCell: aCell withinGrid: aGrid
	^aGrid pushCellNorthFromLocation: aCell gridLocation! !

CellClickRegionInside subclass: #CellClickRegionPushSouth
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Laser-Game-Graphics'!

!CellClickRegionPushSouth class methodsFor: 'as yet unclassified' stamp: 'sbw 6/8/2007 00:05'!
arrowForm
	^LaserGameForms southArrow! !

!CellClickRegionPushSouth class methodsFor: 'as yet unclassified' stamp: 'sbw 6/23/2007 13:21'!
canPushCell: aCell withinGrid: aGrid
	^aGrid canPushCellSouthFromLocation: aCell gridLocation! !

!CellClickRegionPushSouth class methodsFor: 'as yet unclassified' stamp: 'sbw 6/3/2007 22:44'!
containsPoint: aPoint
	| underHeadingDown underHeadingUp |
	underHeadingDown := self pointIsUnderHeadingDownLine: aPoint.
	underHeadingUp := self pointIsUnderHeadingUpLine: aPoint.
	^underHeadingDown and: [underHeadingUp]! !

!CellClickRegionPushSouth class methodsFor: 'as yet unclassified' stamp: 'sbw 6/21/2007 22:45'!
mouseUpForCell: aCell withinGrid: aGrid
	^aGrid pushCellSouthFromLocation: aCell gridLocation! !

CellClickRegionInside subclass: #CellClickRegionPushWest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Laser-Game-Graphics'!

!CellClickRegionPushWest class methodsFor: 'as yet unclassified' stamp: 'sbw 6/8/2007 00:05'!
arrowForm
	^LaserGameForms westArrow! !

!CellClickRegionPushWest class methodsFor: 'as yet unclassified' stamp: 'sbw 6/23/2007 13:21'!
canPushCell: aCell withinGrid: aGrid
	^aGrid canPushCellWestFromLocation: aCell gridLocation! !

!CellClickRegionPushWest class methodsFor: 'as yet unclassified' stamp: 'sbw 6/3/2007 22:42'!
containsPoint: aPoint
	| underHeadingDown underHeadingUp |
	underHeadingDown := self pointIsUnderHeadingDownLine: aPoint.
	underHeadingUp := self pointIsUnderHeadingUpLine: aPoint.
	^underHeadingDown not and: [underHeadingUp]! !

!CellClickRegionPushWest class methodsFor: 'as yet unclassified' stamp: 'sbw 6/21/2007 22:45'!
mouseUpForCell: aCell withinGrid: aGrid
	^aGrid pushCellWestFromLocation: aCell gridLocation! !

CellClickRegion subclass: #CellClickRegionOutside
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Laser-Game-Graphics'!

!CellClickRegionOutside class methodsFor: 'as yet unclassified' stamp: 'sbw 6/23/2007 13:24'!
canActOnCellAtPoint: aPoint cell: aCell withinGrid: aGrid
	^true! !

!CellClickRegionOutside class methodsFor: 'as yet unclassified' stamp: 'sbw 6/21/2007 22:39'!
mouseUpWithinCellAtPoint: aPoint cell: aCell withinGrid: aGrid
	| rotateRegion |
	rotateRegion := self rotateRegionForPoint: aPoint.
	^rotateRegion mouseUpForCell: aCell withinGrid: aGrid! !

!CellClickRegionOutside class methodsFor: 'as yet unclassified' stamp: 'sbw 6/13/2007 06:56'!
regionRectangle
	"CellClickRegionOutside regionRectangle"
	| outer delta |
	outer := 0@0 extent: CellRenderer cellExtent.
	delta := CellRenderer cellExtent - CellRenderer outsideRegionExtent.
	^outer insetBy: (delta // 2)! !

!CellClickRegionOutside class methodsFor: 'as yet unclassified' stamp: 'sbw 6/11/2007 22:01'!
rotateRegionForPoint: aPoint
	^self subclasses detect: [:cls | cls containsPoint: aPoint]! !

!CellClickRegionOutside class methodsFor: 'as yet unclassified' stamp: 'sbw 6/13/2007 18:03'!
scaledHintArrowAndOffsetFromWithinCell: aPoint
	| arrow tinyArrow offset rotateRegion |
	rotateRegion := self rotateRegionForPoint: aPoint.
	arrow := rotateRegion arrowForm.
	tinyArrow := arrow scaledToSize: CellRenderer cellExtent.
	offset := 0.
	^offset->tinyArrow! !

!CellClickRegionOutside class methodsFor: 'as yet unclassified' stamp: 'sbw 6/2/2007 21:02'!
sortIndex
	^2! !

CellClickRegionOutside subclass: #CellClickRegionRotateClockwise
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Laser-Game-Graphics'!

!CellClickRegionRotateClockwise class methodsFor: 'as yet unclassified' stamp: 'sbw 6/11/2007 21:53'!
arrowForm
	^LaserGameForms clockwiseArrow! !

!CellClickRegionRotateClockwise class methodsFor: 'as yet unclassified' stamp: 'sbw 6/30/2007 15:50'!
containsPoint: aPoint
	^aPoint y <= (CellRenderer cellExtent y // 2)! !

!CellClickRegionRotateClockwise class methodsFor: 'as yet unclassified' stamp: 'sbw 6/21/2007 22:49'!
mouseUpForCell: aCell withinGrid: aGrid
	aGrid rotateCellClockwiseAt: aCell gridLocation.
	^aCell! !

CellClickRegionOutside subclass: #CellClickRegionRotateCounterClockwise
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Laser-Game-Graphics'!

!CellClickRegionRotateCounterClockwise class methodsFor: 'as yet unclassified' stamp: 'sbw 6/11/2007 21:54'!
arrowForm
	^LaserGameForms counterClockwiseArrow! !

!CellClickRegionRotateCounterClockwise class methodsFor: 'as yet unclassified' stamp: 'sbw 6/30/2007 15:51'!
containsPoint: aPoint
	^aPoint y > (CellRenderer cellExtent y // 2)! !

!CellClickRegionRotateCounterClockwise class methodsFor: 'as yet unclassified' stamp: 'sbw 6/21/2007 22:50'!
mouseUpForCell: aCell withinGrid: aGrid
	aGrid rotateCellCounterClockwiseAt: aCell gridLocation.
	^aCell! !

Object subclass: #CellRenderer
	instanceVariableNames: 'cellLocation grid targetForm'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Laser-Game-Graphics'!

CellRenderer subclass: #BlankCellRenderer
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Laser-Game-Graphics'!

!BlankCellRenderer class methodsFor: 'as yet unclassified' stamp: 'sbw 5/26/2007 10:18'!
modelClass
	^BlankCell! !

!BlankCellRenderer methodsFor: 'drawing' stamp: 'sbw 6/30/2007 08:15'!
maskOffHorizontalOn: aMask
	^aMask! !

!BlankCellRenderer methodsFor: 'drawing' stamp: 'sbw 6/30/2007 08:19'!
maskOffVerticalOn: aMask
	^aMask! !

!BlankCellRenderer methodsFor: 'drawing' stamp: 'sbw 6/27/2007 19:11'!
renderContents
	self fillBackground
! !

!BlankCellRenderer methodsFor: 'drawing' stamp: 'sbw 6/30/2007 12:05'!
renderLaser
	self cell isOff ifTrue: [^self].
	(self cell activeSegments at: #north) ifTrue: [self renderLaserVertical].
	(self cell activeSegments at: #west) ifTrue: [self renderLaserHorizontal].
	((self cell activeSegments at: #north) and: [self cell activeSegments at: #west]) ifTrue: [
		self renderLaserVerticalCenter]! !

!CellRenderer class methodsFor: 'constants' stamp: 'sbw 7/2/2007 22:37'!
cellExtent
	^50@50! !

!CellRenderer class methodsFor: 'constants' stamp: 'sbw 5/28/2007 16:51'!
ignoreRegionOffset
	^4! !

!CellRenderer class methodsFor: 'constants' stamp: 'sbw 6/26/2007 12:06'!
insideRegionExtent
	^self cellExtent - 20! !

!CellRenderer class methodsFor: 'constants' stamp: 'sbw 5/28/2007 16:53'!
outsideRegionExtent
	^self cellExtent - (2 * self ignoreRegionOffset)! !

!CellRenderer class methodsFor: 'as yet unclassified' stamp: 'sbw 5/26/2007 10:26'!
rendererFor: aCell
	^self subclasses detect: [:cls | cls modelClass = aCell class]! !

!CellRenderer class methodsFor: 'as yet unclassified' stamp: 'sbw 5/26/2007 21:18'!
rendererFor: aCell grid: aGrid form: aForm
	| cls model |
	cls := self rendererFor: aCell.
	model := cls new.
	model
		cellLocation: aCell gridLocation;
		grid: aGrid;
		targetForm: aForm.
	^model! !

!CellRenderer methodsFor: 'drawing' stamp: 'sbw 7/3/2007 16:55'!
backgroundRectangle
	| offset |
	offset := self offsetWithinGridForm + 1.
	^offset extent: CellRenderer cellExtent - 2! !

!CellRenderer methodsFor: 'accessing' stamp: 'sbw 6/17/2007 20:35'!
cell
	^self grid at: self cellLocation.
! !

!CellRenderer methodsFor: 'accessing' stamp: 'sbw 5/26/2007 17:23'!
cellLocation
	"Answer the value of cellLocation"

	^ cellLocation! !

!CellRenderer methodsFor: 'accessing' stamp: 'sbw 5/26/2007 17:23'!
cellLocation: anObject
	"Set the value of cellLocation"

	cellLocation := anObject! !

!CellRenderer methodsFor: 'drawing' stamp: 'sbw 7/3/2007 16:56'!
fillBackground
	| backgroundRect |
	backgroundRect := self backgroundRectangle.
	self targetForm fill: backgroundRect fillColor: LaserGameColors gameBoardBackgroundColor.
! !

!CellRenderer methodsFor: 'accessing' stamp: 'sbw 5/26/2007 10:14'!
grid
	"Answer the value of grid"

	^ grid! !

!CellRenderer methodsFor: 'accessing' stamp: 'sbw 5/26/2007 10:14'!
grid: anObject
	"Set the value of grid"

	grid := anObject! !

!CellRenderer methodsFor: 'drawing' stamp: 'sbw 6/21/2007 22:22'!
mouseUpWithinBoardOffset: aPoint 
	^self cell! !

!CellRenderer methodsFor: 'accessing' stamp: 'sbw 5/26/2007 21:13'!
offsetWithinGridForm
	| delta xCount yCount offset |
	delta := CellRenderer cellExtent.
	xCount := (self cellLocation x) - 1.
	yCount := (self cellLocation y) - 1.
	offset := delta * (xCount@yCount).
	^offset! !

!CellRenderer methodsFor: 'drawing' stamp: 'sbw 6/27/2007 19:10'!
redrawCell
	self fillBackground.
	self render
! !

!CellRenderer methodsFor: 'drawing' stamp: 'sbw 6/28/2007 21:41'!
render
	self
		renderBorder;
		renderContents.
	self grid laserIsActive ifTrue: [self renderLaser]! !

!CellRenderer methodsFor: 'drawing' stamp: 'sbw 5/26/2007 21:45'!
renderBorder
	self
		renderBorderTop;
		renderBorderRight;
		renderBorderBottom;
		renderBorderLeft! !

!CellRenderer methodsFor: 'drawing' stamp: 'sbw 5/26/2007 23:15'!
renderBorderBottom
	| line delta offset x1 x2 y1 y2 fillForm |
	delta := CellRenderer cellExtent - 1.
	offset := self offsetWithinGridForm.
	x1 := offset x.
	x2 := x1 + delta x.
	y1 := offset y + delta y.
	y2 := y1.
	fillForm := Form extent: 1@1 depth: 8.
	fillForm fillColor: LaserGameColors cellBorderColor.
	line := Line
			from: x1@y1 
			to: x2@y2
			withForm: fillForm.
	line displayOn: self targetForm! !

!CellRenderer methodsFor: 'drawing' stamp: 'sbw 5/26/2007 23:15'!
renderBorderLeft
	| line delta offset x1 x2 y1 y2 fillForm |
	delta := CellRenderer cellExtent.
	offset := self offsetWithinGridForm.
	x1 := offset x.
	x2 := x1.
	y1 := offset y.
	y2 := y1 + delta y.
	fillForm := Form extent: 1@1 depth: 8.
	fillForm fillColor: LaserGameColors cellBorderColor.
	line := Line
			from: x1@y1 
			to: x2@y2
			withForm: fillForm.
	line displayOn: self targetForm! !

!CellRenderer methodsFor: 'drawing' stamp: 'sbw 5/26/2007 23:15'!
renderBorderRight
	| line delta offset x1 x2 y1 y2 fillForm |
	delta := CellRenderer cellExtent - 1.
	offset := self offsetWithinGridForm.
	x1 := offset x + delta x.
	x2 := x1.
	y1 := offset y.
	y2 := y1 + delta y.
	fillForm := Form extent: 1@1 depth: 8.
	fillForm fillColor: LaserGameColors cellBorderColor.
	line := Line
			from: x1@y1 
			to: x2@y2
			withForm: fillForm.
	line displayOn: self targetForm! !

!CellRenderer methodsFor: 'drawing' stamp: 'sbw 5/26/2007 23:16'!
renderBorderTop
	| line delta offset x1 x2 y1 y2 fillForm |
	delta := CellRenderer cellExtent.
	offset := self offsetWithinGridForm.
	x1 := offset x.
	x2 := x1 + delta x.
	y1 := offset y.
	y2 := y1.
	fillForm := Form extent: 1@1 depth: 8.
	fillForm fillColor: LaserGameColors cellBorderColor.
	line := Line
			from: x1@y1 
			to: x2@y2
			withForm: fillForm.
	line displayOn: self targetForm! !

!CellRenderer methodsFor: 'drawing' stamp: 'sbw 5/26/2007 18:08'!
renderContents! !

!CellRenderer methodsFor: 'drawing' stamp: 'sbw 6/28/2007 21:40'!
renderLaser! !

!CellRenderer methodsFor: 'drawing' stamp: 'sbw 6/30/2007 07:58'!
renderLaserHorizontal
	self renderLaserHorizontalSplatter.
	self renderLaserHorizontalCenter.
	! !

!CellRenderer methodsFor: 'drawing' stamp: 'sbw 6/30/2007 08:03'!
renderLaserHorizontalCenter
	self
		renderLaserHorizontalMask: LaserGameForms centerBeamMask 
		color: LaserGameColors laserBeamCenterColor! !

!CellRenderer methodsFor: 'drawing' stamp: 'sbw 6/30/2007 10:28'!
renderLaserHorizontalMask: aMaskForm color: aColor
	| cellPosn scaledBeam scale trimmedBeam offset masked |
	cellPosn := self offsetWithinGridForm.
	scale := CellRenderer cellExtent * 6.
	scaledBeam := aMaskForm scaledToSize: scale.
	trimmedBeam := Form extent: (CellRenderer cellExtent x)@(scaledBeam height) depth: scaledBeam depth.
	scaledBeam
		displayOn: trimmedBeam
		at: 0@0
		clippingBox: trimmedBeam boundingBox
		rule: Form paint
		fillColor: nil.
	offset := 0@(5 + (CellRenderer cellExtent y - trimmedBeam height) // 2).
	masked := self maskOffHorizontalOn: trimmedBeam.
	masked
		displayOn: self targetForm
		at: (cellPosn + offset)
		clippingBox: self targetForm boundingBox
		rule: Form oldPaint
		fillColor: aColor! !

!CellRenderer methodsFor: 'drawing' stamp: 'sbw 6/30/2007 08:03'!
renderLaserHorizontalSplatter
	self
		renderLaserHorizontalMask: LaserGameForms splatterBeamMask 
		color: LaserGameColors laserBeamSplatterColor! !

!CellRenderer methodsFor: 'drawing' stamp: 'sbw 6/30/2007 07:59'!
renderLaserVertical
	self renderLaserVerticalSplatter.
	self renderLaserVerticalCenter.
	! !

!CellRenderer methodsFor: 'drawing' stamp: 'sbw 6/30/2007 08:04'!
renderLaserVerticalCenter
	self
		renderLaserVerticalMask: LaserGameForms centerBeamMask 
		color: LaserGameColors laserBeamCenterColor! !

!CellRenderer methodsFor: 'drawing' stamp: 'sbw 6/30/2007 10:42'!
renderLaserVerticalMask: aMaskForm color: aColor
	| cellPosn scaledBeam scale trimmedBeam offset rotatedBeam masked |
	cellPosn := self offsetWithinGridForm.
	scale := CellRenderer cellExtent * 6.
	scaledBeam := aMaskForm scaledToSize: scale.
	trimmedBeam := Form extent: (CellRenderer cellExtent x)@(scaledBeam height) depth: scaledBeam depth.
	scaledBeam
		displayOn: trimmedBeam
		at: 0@0
		clippingBox: trimmedBeam boundingBox
		rule: Form paint
		fillColor: nil.
	rotatedBeam := trimmedBeam rotateBy: 90.
	offset := (-3 + (CellRenderer cellExtent x - rotatedBeam width) // 2)@(3 + (CellRenderer cellExtent y // 2) negated).
	masked := self maskOffVerticalOn: rotatedBeam.
	masked
		displayOn: self targetForm
		at: (cellPosn + offset)
		clippingBox: self targetForm boundingBox
		rule: Form oldPaint
		fillColor: aColor! !

!CellRenderer methodsFor: 'drawing' stamp: 'sbw 6/30/2007 08:04'!
renderLaserVerticalSplatter
	self
		renderLaserVerticalMask: LaserGameForms splatterBeamMask 
		color: LaserGameColors laserBeamSplatterColor! !

!CellRenderer methodsFor: 'drawing' stamp: 'sbw 5/29/2007 23:07'!
showPositionHintFromWithinBoardOffset: aPoint ! !

!CellRenderer methodsFor: 'accessing' stamp: 'sbw 5/26/2007 10:14'!
targetForm
	"Answer the value of targetForm"

	^ targetForm! !

!CellRenderer methodsFor: 'accessing' stamp: 'sbw 5/26/2007 10:14'!
targetForm: anObject
	"Set the value of targetForm"

	targetForm := anObject! !

CellRenderer subclass: #MirrorCellRenderer
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Laser-Game-Graphics'!

!MirrorCellRenderer class methodsFor: 'as yet unclassified' stamp: 'sbw 5/26/2007 10:22'!
modelClass
	^MirrorCell! !

!MirrorCellRenderer methodsFor: 'drawing' stamp: 'sbw 5/26/2007 22:39'!
cornerInset
	^8@8! !

!MirrorCellRenderer methodsFor: 'drawing' stamp: 'sbw 7/3/2007 16:16'!
hintArrowColorFor: regionClass offset: offsetWithinCell
	| permissionToActOnCell arrowColor |
	permissionToActOnCell := regionClass
								canActOnCellAtPoint: offsetWithinCell 
								cell: self cell 
								withinGrid: self grid.
	arrowColor := permissionToActOnCell
		ifTrue: [LaserGameColors allowActionArrowColor]
		ifFalse: [LaserGameColors denyActionArrowColor].
	^arrowColor! !

!MirrorCellRenderer methodsFor: 'drawing' stamp: 'PeterMeadows 10/21/2012 07:57'!
maskForNorthEast
	| mask pen line cellPosn |
	mask := Form extent: CellRenderer cellExtent depth: 1.
	mask fillColor: Color white.
	pen := Form extent: 1@1 depth: 1.
	pen fillColor: Color black.
	line := Line
			from: 0@0
			to: mask extent
			withForm: pen.
	line displayOn: mask.
	mask floodFill2: Color black at: 5@1.
	cellPosn := self offsetWithinGridForm.
	mask
		displayOn: self targetForm
		at: cellPosn
		clippingBox: self targetForm boundingBox
		rule: Form oldPaint
		fillColor: LaserGameColors gameBoardBackgroundColor.
	self renderBorderTop.
	self renderBorderRight! !

!MirrorCellRenderer methodsFor: 'drawing' stamp: 'PeterMeadows 10/21/2012 07:32'!
maskForNorthWest
	| mask pen line cellPosn |
	mask := Form extent: CellRenderer cellExtent depth: 1.
	mask fillColor: Color white.
	pen := Form extent: 1@1 depth: 1.
	pen fillColor: Color black.
	line := Line
			from: (mask width)@0
			to: 0@(mask height)
			withForm: pen.
	line displayOn: mask.
	mask floodFill2: Color black at: 5@5.
	cellPosn := self offsetWithinGridForm.
	mask
		displayOn: self targetForm
		at: cellPosn
		clippingBox: self targetForm boundingBox
		rule: Form oldPaint
		fillColor: LaserGameColors gameBoardBackgroundColor.
	self renderBorderTop.
	self renderBorderLeft! !

!MirrorCellRenderer methodsFor: 'drawing' stamp: 'PeterMeadows 10/21/2012 07:32'!
maskForSouthEast
	| mask pen line cellPosn |
	mask := Form extent: CellRenderer cellExtent depth: 1.
	mask fillColor: Color white.
	pen := Form extent: 1@1 depth: 1.
	pen fillColor: Color black.
	line := Line
			from: (mask width)@0
			to: 0@(mask height)
			withForm: pen.
	line displayOn: mask.
	mask floodFill2: Color black at: (mask width - 5)@(mask height - 5).
	cellPosn := self offsetWithinGridForm.
	mask
		displayOn: self targetForm
		at: cellPosn
		clippingBox: self targetForm boundingBox
		rule: Form oldPaint
		fillColor: LaserGameColors gameBoardBackgroundColor.
	self renderBorderBottom.
	self renderBorderRight! !

!MirrorCellRenderer methodsFor: 'drawing' stamp: 'PeterMeadows 10/21/2012 07:32'!
maskForSouthWest
	| mask pen line cellPosn |
	mask := Form extent: CellRenderer cellExtent depth: 1.
	mask fillColor: Color white.
	pen := Form extent: 1@1 depth: 1.
	pen fillColor: Color black.
	line := Line
			from: 0@0
			to: mask extent
			withForm: pen.
	line displayOn: mask.
	mask floodFill2: Color black at: 1@5.
	cellPosn := self offsetWithinGridForm.
	mask
		displayOn: self targetForm
		at: cellPosn
		clippingBox: self targetForm boundingBox
		rule: Form oldPaint
		fillColor: LaserGameColors gameBoardBackgroundColor.
	self renderBorderBottom.
	self renderBorderLeft! !

!MirrorCellRenderer methodsFor: 'drawing' stamp: 'sbw 6/30/2007 10:02'!
maskOffHorizontalOn: aMask
	^aMask! !

!MirrorCellRenderer methodsFor: 'drawing' stamp: 'sbw 6/30/2007 10:03'!
maskOffVerticalOn: aMask
	^aMask! !

!MirrorCellRenderer methodsFor: 'drawing' stamp: 'sbw 6/21/2007 22:23'!
mouseUpWithinBoardOffset: aPoint
	| cellPosn offsetWithinCell regionClass |
	cellPosn := self offsetWithinGridForm.
	offsetWithinCell := aPoint - cellPosn.
	regionClass := CellClickRegion clickRegionForPoint: offsetWithinCell. 
	^regionClass mouseUpWithinCellAtPoint: offsetWithinCell cell: self cell withinGrid: self grid.
! !

!MirrorCellRenderer methodsFor: 'drawing' stamp: 'sbw 6/30/2007 11:39'!
removeLaserFromInactiveLeftSide
	(self cell activeSegments at: #west) ifFalse: [self maskForSouthWest].
	(self cell activeSegments at: #east) ifFalse: [self maskForNorthEast].
	! !

!MirrorCellRenderer methodsFor: 'drawing' stamp: 'sbw 6/30/2007 11:41'!
removeLaserFromInactiveRightSide
	(self cell activeSegments at: #west) ifFalse: [self maskForNorthWest].
	(self cell activeSegments at: #east) ifFalse: [self maskForSouthEast].
	! !

!MirrorCellRenderer methodsFor: 'drawing' stamp: 'sbw 6/30/2007 11:21'!
removeLaserFromInactiveSide
	self cell isLeft
		ifTrue: [self removeLaserFromInactiveLeftSide]
		ifFalse: [self removeLaserFromInactiveRightSide]! !

!MirrorCellRenderer methodsFor: 'drawing' stamp: 'sbw 6/30/2007 10:07'!
renderContents
	self fillBackground.
	self renderMirror! !

!MirrorCellRenderer methodsFor: 'drawing' stamp: 'sbw 5/26/2007 23:14'!
renderContentsLeanLeft
	| offset delta x1 x2 y1 y2 line fillForm |
	offset := self offsetWithinGridForm.
	delta := CellRenderer cellExtent - 1.
	x1 := offset x + (self cornerInset x).
	x2 := offset x + delta x - (self cornerInset x).
	y1 := offset y + (self cornerInset y).
	y2 := offset y + delta y - (self cornerInset y).
	fillForm := Form extent: 2@2 depth: 8.
	fillForm fillColor: LaserGameColors mirrorColor.
	line := Line
			from: x1@y1 
			to: x2@y2
			withForm: fillForm.
	line displayOn: self targetForm! !

!MirrorCellRenderer methodsFor: 'drawing' stamp: 'sbw 5/26/2007 23:14'!
renderContentsLeanRight
	| offset delta x1 x2 y1 y2 line fillForm |
	offset := self offsetWithinGridForm.
	delta := CellRenderer cellExtent - 1.
	x1 := offset x + delta x - self cornerInset x.
	x2 := offset x + self cornerInset x.
	y1 := offset y + (self cornerInset y).
	y2 := offset y + delta y - (self cornerInset y).
	fillForm := Form extent: 2@2 depth: 8.
	fillForm fillColor: LaserGameColors mirrorColor.
	line := Line
			from: x1@y1 
			to: x2@y2
			withForm: fillForm.
	line displayOn: self targetForm! !

!MirrorCellRenderer methodsFor: 'drawing' stamp: 'sbw 6/30/2007 11:11'!
renderLaser
	self cell isOff ifTrue: [^self].
	self renderLaserVertical.
	self renderLaserHorizontal.
	self renderLaserVerticalCenter.
	self removeLaserFromInactiveSide.
	self renderMirror.
! !

!MirrorCellRenderer methodsFor: 'drawing' stamp: 'sbw 6/30/2007 10:07'!
renderMirror
	self cell isLeft
		ifTrue: [self renderContentsLeanLeft]
		ifFalse: [self renderContentsLeanRight]! !

!MirrorCellRenderer methodsFor: 'drawing' stamp: 'sbw 7/3/2007 16:58'!
showPositionHintFromWithinBoardOffset: aPoint
	| cellPosn offsetWithinCell regionClass arrowAndOffset |
	cellPosn := self offsetWithinGridForm.
	offsetWithinCell := aPoint - cellPosn.
	regionClass := CellClickRegion clickRegionForPoint: offsetWithinCell. 
	arrowAndOffset := regionClass scaledHintArrowAndOffsetFromWithinCell: offsetWithinCell.
	arrowAndOffset isNil
		ifTrue: [self currentHand showTemporaryCursor: nil]
		ifFalse: [
			| arrowColor arrow offset |
			arrowColor := self hintArrowColorFor: regionClass offset: offsetWithinCell.
			arrow := arrowAndOffset value.
			offset := arrowAndOffset key.
			offset := self offsetWithinGridForm + offset.
			arrow
				displayOn: self targetForm
				at: offset
				clippingBox: self backgroundRectangle
				rule: Form oldPaint
				fillColor: arrowColor.
			self currentHand
				showTemporaryCursor: LaserGameForms crossHair
				hotSpotOffset: (LaserGameForms crossHair extent // 2)]! !

CellRenderer subclass: #TargetCellRenderer
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Laser-Game-Graphics'!

!TargetCellRenderer class methodsFor: 'as yet unclassified' stamp: 'sbw 5/26/2007 10:22'!
modelClass
	^TargetCell! !

!TargetCellRenderer methodsFor: 'drawing' stamp: 'sbw 6/29/2007 22:45'!
drawCircleOutline
	self drawCircleOutlineOn: self targetForm color: LaserGameColors targetCenterColor! !

!TargetCellRenderer methodsFor: 'drawing' stamp: 'sbw 6/29/2007 22:59'!
drawCircleOutlineOn: aForm color: aColor
	| offset |
	offset := self offsetWithinGridForm.
	self drawCircleOutlineOn: aForm color: aColor offset: offset! !

!TargetCellRenderer methodsFor: 'drawing' stamp: 'sbw 6/29/2007 22:58'!
drawCircleOutlineOn: aForm color: aColor offset: offset
	| delta fillForm circle |
	delta := self class cellExtent - 1.
	circle := Circle new.
	fillForm := Form extent: 2@2 depth: 8.
	fillForm fillColor: aColor.
	circle form: fillForm.
	circle radius: self radius.
	circle center: (offset + (delta // 2)).
	circle displayOn: aForm! !

!TargetCellRenderer methodsFor: 'drawing' stamp: 'sbw 5/26/2007 23:55'!
drawCrossHairsOutlines
	| inset delta offset x1 x2 y1 y2 fillForm line |
	inset := 6@6.
	delta := CellRenderer cellExtent - 1.
	offset := self offsetWithinGridForm.
	x1 := offset x + inset x.
	x2 := offset x + delta x - inset x.
	y1 := offset y + (delta y // 2).
	y2 := y1.
	fillForm := Form extent: 2@2 depth: 8.
	fillForm fillColor: LaserGameColors targetCenterColor.
	line := Line
			from: x1@y1 
			to: x2@y2
			withForm: fillForm.
	line displayOn: self targetForm.
	x1 := offset x + (delta x // 2).
	x2 := x1.
	y1 := offset y + inset y.
	y2 := offset y + delta y - inset y.
	fillForm := Form extent: 2@2 depth: 8.
	fillForm fillColor: LaserGameColors targetCenterColor.
	line := Line
			from: x1@y1 
			to: x2@y2
			withForm: fillForm.
	line displayOn: self targetForm.
! !

!TargetCellRenderer methodsFor: 'drawing' stamp: 'sbw 5/26/2007 23:55'!
drawTargetOutlines
	self drawCrossHairsOutlines.
	self drawCircleOutline! !

!TargetCellRenderer methodsFor: 'drawing' stamp: 'sbw 6/29/2007 23:14'!
maskOffHorizontalOn: aMask
	| newMask halfExtent halfRect offset |
	halfExtent := (aMask width // 2)@(aMask height).
	newMask := Form extent: aMask extent depth: aMask depth.
	newMask fillColor: Color white.
	(self cell activeSegments at: #west)
		ifTrue: [offset := 0]
		ifFalse: [offset := halfExtent x].
	halfRect := (aMask boundingBox origin + (offset@0)) extent: halfExtent.
	aMask
		displayOn: newMask
		at: offset@0
		clippingBox: halfRect
		rule: Form paint
		fillColor: Color black.
	^newMask! !

!TargetCellRenderer methodsFor: 'drawing' stamp: 'sbw 6/30/2007 06:36'!
maskOffVerticalOn: aMask
	| newMask halfExtent halfRect offset |
	newMask := Form extent: aMask extent depth: aMask depth.
	newMask fillColor: Color white.
	halfExtent := (aMask width)@(aMask height // 2).
	(self cell activeSegments at: #south)
		ifTrue: [offset := halfExtent y]
		ifFalse: [offset := 0].
	halfRect := (0@offset) extent: halfExtent.
	aMask
		displayOn: newMask
		at: 0@0
		clippingBox: halfRect
		rule: Form paint
		fillColor: Color black.
	^newMask! !

!TargetCellRenderer methodsFor: 'drawing' stamp: 'sbw 6/26/2007 11:54'!
radius
	^(self class cellExtent x // 2 - 8) min: 10! !

!TargetCellRenderer methodsFor: 'drawing' stamp: 'sbw 6/27/2007 19:12'!
renderContents
	self fillBackground.
	self drawTargetOutlines.
	self cell isOn
		ifTrue: [self renderContentsOn]
		ifFalse: [self renderContentsOff]! !

!TargetCellRenderer methodsFor: 'drawing' stamp: 'sbw 5/26/2007 23:53'!
renderContentsOff
	self renderInnerCircleColor: LaserGameColors targetCenterColorIdle.
! !

!TargetCellRenderer methodsFor: 'drawing' stamp: 'sbw 5/26/2007 23:53'!
renderContentsOn
	self renderInnerCircleColor: LaserGameColors targetCenterColorActive.
! !

!TargetCellRenderer methodsFor: 'drawing' stamp: 'sbw 6/26/2007 11:55'!
renderInnerCircleColor: aColor
	| circle fillForm offset delta |
	delta := CellRenderer cellExtent - 1.
	offset := self offsetWithinGridForm.
	circle := Circle new.
	fillForm := Form extent: 4@4 depth: 8.
	fillForm fillColor: aColor.
	circle form: fillForm.
	circle radius: self radius - 4.
	circle center: (offset + (delta // 2) - 1).
	circle displayOn: self targetForm.! !

!TargetCellRenderer methodsFor: 'drawing' stamp: 'sbw 6/29/2007 23:03'!
renderLaser
	| horizontal |
	self cell isOff ifTrue: [^self].
	horizontal := (self cell activeSegments at: #east) or: [self cell activeSegments at: #west].
	horizontal
		ifTrue: [self renderLaserHorizontal]
		ifFalse: [self renderLaserVertical].
	self drawTargetOutlines.
	self renderContentsOn.
	! !

Object subclass: #Grid
	instanceVariableNames: 'cells laserIsActive numberOfColumns numberOfRows laserBeamPath movesStack'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Laser-Game-Model'!

!Grid class methodsFor: 'instance creation' stamp: 'sbw 5/20/2007 15:12'!
newOfSize: aPoint
	| model |
	model := self basicNew.
	model
		numberOfRows: aPoint y;
		numberOfColumns: aPoint x.
	model initialize.
	^model! !

!Grid methodsFor: 'action' stamp: 'sbw 5/21/2007 21:17'!
activateCellsInPath
	self calculatePath.
	self laserBeamPath do: [:pe |
		pe activateCell]! !

!Grid methodsFor: 'accessing' stamp: 'sbw 6/7/2007 20:15'!
at: aPoint
	self revisit: 'sbw 05/21/2007 - We should add a more meaningful accessing technique here.  x@y is confusing.'.
	^self cells at: aPoint ifAbsent: []! !

!Grid methodsFor: 'accessing' stamp: 'sbw 6/7/2007 20:17'!
at: aPoint put: aCell
	self revisit: 'sbw 05/21/2007 - We should add a more meaningful accessing technique here.  x@y is confusing.'.
	aCell gridLocation: aPoint.
	self cells at: aPoint put: aCell! !

!Grid methodsFor: 'accessing' stamp: 'sbw 5/21/2007 21:13'!
calculatePath
	| cell dirSym element next |
	self laserBeamPath: OrderedCollection new.
	cell := self startingCell.
	dirSym := #south.
	element := LaserPathElement cell: cell entrySide: dirSym.
	[self laserBeamPath addLast: element.
	next := element nextElementIn: self.
	next isNil] whileFalse: [
		element := next]! !

!Grid methodsFor: 'action' stamp: 'sbw 6/23/2007 13:18'!
canPushCell: aGridDirection fromLocation: aPoint
	| cell vector swapLoc swapCell |
	cell := self at: aPoint.
	cell class = MirrorCell ifFalse: [^false].
	vector := aGridDirection vector.
	swapLoc := aPoint + vector.
	swapCell := self at: swapLoc.
	swapCell isNil ifTrue: [^false].
	swapCell class = BlankCell ifFalse: [^false].
	^true
! !

!Grid methodsFor: 'action' stamp: 'sbw 6/23/2007 13:18'!
canPushCellEastFromLocation: aPoint
	| direction |
	direction := GridDirection directionFor: #east.
	^self canPushCell: direction fromLocation: aPoint.! !

!Grid methodsFor: 'action' stamp: 'sbw 6/23/2007 13:18'!
canPushCellNorthFromLocation: aPoint
	| direction |
	direction := GridDirection directionFor: #north.
	^self canPushCell: direction fromLocation: aPoint.! !

!Grid methodsFor: 'action' stamp: 'sbw 6/23/2007 13:19'!
canPushCellSouthFromLocation: aPoint
	| direction |
	direction := GridDirection directionFor: #south.
	^self canPushCell: direction fromLocation: aPoint.
! !

!Grid methodsFor: 'action' stamp: 'sbw 6/23/2007 13:19'!
canPushCellWestFromLocation: aPoint
	| direction |
	direction := GridDirection directionFor: #west.
	^self canPushCell: direction fromLocation: aPoint.! !

!Grid methodsFor: 'accessing' stamp: 'sbw 5/20/2007 14:04'!
cells
	"Answer the value of cells"

	^ cells! !

!Grid methodsFor: 'accessing' stamp: 'sbw 5/20/2007 14:04'!
cells: anObject
	"Set the value of cells"

	cells := anObject! !

!Grid methodsFor: 'action' stamp: 'sbw 5/28/2007 14:49'!
clearCellsInPath
	self calculatePath.
	self laserBeamPath do: [:pe |
		pe clearCell]! !

!Grid methodsFor: 'action' stamp: 'sbw 5/28/2007 11:34'!
fireLaser
	self laserIsActive: true.
	self activateCellsInPath.
	! !

!Grid methodsFor: 'initialize-release' stamp: 'sbw 5/20/2007 15:05'!
initialize
	super initialize.
	self laserIsActive: false.
	self initializeCells.
	! !

!Grid methodsFor: 'initialize-release' stamp: 'sbw 5/21/2007 21:47'!
initializeCells
	self cells: Dictionary new.
	1 to: self numberOfColumns do: [:x |
		1 to: self numberOfRows do: [:y |
			| pt cell |
			pt := x@y.
			cell := BlankCell new.
			self at: pt put: cell]]! !

!Grid methodsFor: 'accessing' stamp: 'sbw 5/20/2007 21:22'!
laserBeamPath
	"Answer the value of laserBeamPath"

	^ laserBeamPath! !

!Grid methodsFor: 'accessing' stamp: 'sbw 5/20/2007 21:22'!
laserBeamPath: anObject
	"Set the value of laserBeamPath"

	laserBeamPath := anObject! !

!Grid methodsFor: 'accessing' stamp: 'sbw 5/20/2007 14:04'!
laserIsActive
	"Answer the value of laserIsActive"

	^ laserIsActive! !

!Grid methodsFor: 'accessing' stamp: 'sbw 5/20/2007 14:04'!
laserIsActive: anObject
	"Set the value of laserIsActive"

	laserIsActive := anObject! !

!Grid methodsFor: 'accessing' stamp: 'sbw 6/30/2007 19:27'!
movesStack
	movesStack isNil ifTrue: [self movesStack: OrderedCollection new].
	^movesStack! !

!Grid methodsFor: 'accessing' stamp: 'sbw 6/30/2007 19:26'!
movesStack: aCollection
	movesStack := aCollection! !

!Grid methodsFor: 'accessing' stamp: 'sbw 6/30/2007 16:59'!
numberOfActiveMirrors
	^(self cells select: [:each | (each class = MirrorCell) and: [each isOn]]) size! !

!Grid methodsFor: 'accessing' stamp: 'sbw 5/20/2007 14:17'!
numberOfColumns
	numberOfColumns isNil ifTrue: [self numberOfColumns: 1].
	^ numberOfColumns! !

!Grid methodsFor: 'accessing' stamp: 'sbw 5/20/2007 14:06'!
numberOfColumns: anObject
	"Set the value of numberOfColumns"

	numberOfColumns := anObject! !

!Grid methodsFor: 'accessing' stamp: 'sbw 6/30/2007 16:56'!
numberOfMirrors
	^(self cells select: [:each | each class = MirrorCell]) size! !

!Grid methodsFor: 'accessing' stamp: 'sbw 5/20/2007 14:18'!
numberOfRows
	numberOfRows isNil ifTrue: [self numberOfRows: 1].
	^ numberOfRows! !

!Grid methodsFor: 'accessing' stamp: 'sbw 5/20/2007 14:06'!
numberOfRows: anObject
	"Set the value of numberOfRows"

	numberOfRows := anObject! !

!Grid methodsFor: 'action' stamp: 'sbw 6/22/2007 06:29'!
pushCell: aGridDirection fromLocation: aPoint
	| cell vector swapLoc swapCell |
	cell := self at: aPoint.
	cell class = MirrorCell ifFalse: [^cell].
	vector := aGridDirection vector.
	swapLoc := aPoint + vector.
	swapCell := self at: swapLoc.
	swapCell isNil ifTrue: [^cell].
	swapCell class = BlankCell ifFalse: [^cell].
	self clearCellsInPath.
	self swapCell: cell with: swapCell.
	self laserIsActive ifTrue: [self activateCellsInPath].
	^swapCell
! !

!Grid methodsFor: 'action' stamp: 'sbw 6/30/2007 19:21'!
pushCellAction: aDirectionSymbol fromLocation: aPoint
	| direction cell swappedCell |
	cell := self at: aPoint.
	direction := GridDirection directionFor: aDirectionSymbol.
	swappedCell := self pushCell: direction fromLocation: aPoint.
	swappedCell gridLocation = cell gridLocation ifFalse: [
		self stackAction: aDirectionSymbol forCell: cell].
	^swappedCell ! !

!Grid methodsFor: 'action' stamp: 'sbw 6/30/2007 19:01'!
pushCellEastFromLocation: aPoint
	^self pushCellAction: #east fromLocation: aPoint
! !

!Grid methodsFor: 'action' stamp: 'sbw 6/30/2007 19:02'!
pushCellNorthFromLocation: aPoint
	^self pushCellAction: #north fromLocation: aPoint
! !

!Grid methodsFor: 'action' stamp: 'sbw 6/30/2007 19:03'!
pushCellSouthFromLocation: aPoint
	^self pushCellAction: #south fromLocation: aPoint
! !

!Grid methodsFor: 'action' stamp: 'sbw 6/30/2007 19:03'!
pushCellWestFromLocation: aPoint
	^self pushCellAction: #west fromLocation: aPoint
! !

!Grid methodsFor: 'action' stamp: 'sbw 7/1/2007 01:18'!
reset
	[self undo] whileTrue: []! !

!Grid methodsFor: 'action' stamp: 'sbw 6/30/2007 19:23'!
rotateCellClockwiseAt: aPoint
	| cell |
	cell := self at: aPoint.
	self clearCellsInPath.
	(self at: aPoint) rotateClockwise.
	self laserIsActive ifTrue: [self activateCellsInPath].
	self stackAction: #clockwise forCell: cell
! !

!Grid methodsFor: 'action' stamp: 'sbw 6/30/2007 19:22'!
rotateCellCounterClockwiseAt: aPoint
	| cell |
	cell := self at: aPoint.
	self clearCellsInPath.
	(self at: aPoint) rotateCounterClockwise.
	self laserIsActive ifTrue: [self activateCellsInPath].
	self stackAction: #counterClockwise forCell: cell
! !

!Grid methodsFor: 'action' stamp: 'sbw 6/30/2007 19:28'!
stackAction: aSymbol forCell: aCell
	self movesStack add: aSymbol->(aCell gridLocation)! !

!Grid methodsFor: 'accessing' stamp: 'sbw 5/20/2007 21:25'!
startingCell
	| pt |
	pt := 1@(self numberOfRows).
	^self at: pt! !

!Grid methodsFor: 'action' stamp: 'sbw 5/28/2007 11:58'!
stopLaser
	self laserIsActive: false.
	self clearCellsInPath.
	! !

!Grid methodsFor: 'action' stamp: 'sbw 6/21/2007 21:48'!
swapCell: aCell with: anotherCell
	| oldLocation newLocation |
	oldLocation := aCell gridLocation copy.
	newLocation := anotherCell gridLocation copy.
	self at: newLocation put: aCell.
	self at: oldLocation put: anotherCell! !

!Grid methodsFor: 'action' stamp: 'sbw 6/30/2007 19:45'!
undo
	| actionAssociation symbol location reverseAction arguments |
	self movesStack isEmpty ifTrue: [^false].
	actionAssociation := self movesStack removeLast.
	symbol := actionAssociation key.
	location := actionAssociation value.
	reverseAction := ReverseLaserGameAction reverseActionSymbolFor: symbol.
	arguments := Array with: location.
	self perform: reverseAction withArguments: arguments.
	self movesStack removeLast.
	^true! !

Object subclass: #GridDirection
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Laser-Game-Model'!

!GridDirection class methodsFor: 'as yet unclassified' stamp: 'sbw 5/20/2007 21:52'!
directionFor: aSymbol
	^self subclasses detect: [:cls | cls directionSymbol = aSymbol]! !

GridDirection subclass: #GridDirectionEast
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Laser-Game-Model'!

!GridDirectionEast class methodsFor: 'as yet unclassified' stamp: 'sbw 5/22/2007 23:17'!
adjacentInversionSymbol
	^#west! !

!GridDirectionEast class methodsFor: 'as yet unclassified' stamp: 'sbw 5/20/2007 21:42'!
directionSymbol
	^#east! !

!GridDirectionEast class methodsFor: 'as yet unclassified' stamp: 'sbw 5/20/2007 21:42'!
vector
	^1@0! !

GridDirection subclass: #GridDirectionNorth
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Laser-Game-Model'!

!GridDirectionNorth class methodsFor: 'as yet unclassified' stamp: 'sbw 5/22/2007 23:17'!
adjacentInversionSymbol
	^#south! !

!GridDirectionNorth class methodsFor: 'as yet unclassified' stamp: 'sbw 5/20/2007 21:43'!
directionSymbol
	^#north! !

!GridDirectionNorth class methodsFor: 'as yet unclassified' stamp: 'PeterMeadows 10/21/2012 07:38'!
vector
	^0 @ -1! !

GridDirection subclass: #GridDirectionSouth
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Laser-Game-Model'!

!GridDirectionSouth class methodsFor: 'as yet unclassified' stamp: 'sbw 5/22/2007 23:17'!
adjacentInversionSymbol
	^#north! !

!GridDirectionSouth class methodsFor: 'as yet unclassified' stamp: 'sbw 5/20/2007 21:43'!
directionSymbol
	^#south! !

!GridDirectionSouth class methodsFor: 'as yet unclassified' stamp: 'sbw 5/20/2007 21:44'!
vector
	^0@1! !

GridDirection subclass: #GridDirectionWest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Laser-Game-Model'!

!GridDirectionWest class methodsFor: 'as yet unclassified' stamp: 'sbw 5/22/2007 23:17'!
adjacentInversionSymbol
	^#east! !

!GridDirectionWest class methodsFor: 'as yet unclassified' stamp: 'sbw 5/20/2007 21:43'!
directionSymbol
	^#west! !

!GridDirectionWest class methodsFor: 'as yet unclassified' stamp: 'sbw 5/20/2007 21:44'!
vector
	^-1@0! !

Object subclass: #GridFactory
	instanceVariableNames: ''
	classVariableNames: 'RandomNumberGenerator'
	poolDictionaries: ''
	category: 'Laser-Game-Model'!

!GridFactory class methodsFor: 'as yet unclassified' stamp: 'sbw 7/6/2007 17:59'!
defaultGrid
	^self randomizedGridOfExtent: 8@10! !

!GridFactory class methodsFor: 'as yet unclassified' stamp: 'sbw 5/26/2007 20:18'!
demoGrid
	| grid |
	grid := Grid newOfSize: 5@5.
	grid at: 4@1 put: MirrorCell leanRight.
	grid at: 5@1 put: TargetCell new.
	grid at: 1@2 put: MirrorCell leanRight.
	grid at: 5@2 put: MirrorCell leanLeft.
	grid at: 2@3 put: MirrorCell leanLeft.
	grid at: 3@3 put: MirrorCell leanRight.
	grid at: 5@3 put: MirrorCell leanLeft.
	grid at: 2@4 put: MirrorCell leanLeft.
	grid at: 3@4 put: MirrorCell leanLeft.
	grid at: 1@5 put: MirrorCell leanRight.
	grid at: 4@5 put: MirrorCell leanRight.
	^grid! !

!GridFactory class methodsFor: 'as yet unclassified' stamp: 'sbw 6/27/2007 23:07'!
emptyRandomLocationsFor: aGrid
	| dict |
	dict := Dictionary new.
	1 to: aGrid numberOfColumns do: [:x |
		1 to: aGrid numberOfRows do: [:y |
			| pt |
			pt := x@y.
			dict at: pt put: false]].
	dict at: (aGrid numberOfColumns)@1 put: true.  "Target Cell"
	^dict! !

!GridFactory class methodsFor: 'as yet unclassified' stamp: 'sbw 7/16/2007 22:49'!
emptyStandardGrid
	^Grid newOfSize: 8@10! !

!GridFactory class methodsFor: 'as yet unclassified' stamp: 'sbw 6/27/2007 19:18'!
randomBoolean
	| int |
	int := self randomNumberGenerator nextInt: 2.
	^int > 1! !

!GridFactory class methodsFor: 'as yet unclassified' stamp: 'sbw 6/27/2007 18:48'!
randomNumberGenerator
	RandomNumberGenerator isNil ifTrue: [
		RandomNumberGenerator := Random new.
		RandomNumberGenerator seed: Time totalSeconds].
	^RandomNumberGenerator! !

!GridFactory class methodsFor: 'as yet unclassified' stamp: 'sbw 6/27/2007 23:05'!
randomizeGrid: aGrid
	self randomizeGrid: aGrid targetAt: (aGrid numberOfColumns@1)! !

!GridFactory class methodsFor: 'as yet unclassified' stamp: 'sbw 6/27/2007 23:10'!
randomizeGrid: aGrid targetAt: pt
	| emptyList loc howMany |
	emptyList := self emptyRandomLocationsFor: aGrid.
	aGrid at: pt put: TargetCell new.
	howMany := ((aGrid numberOfColumns * aGrid numberOfRows) / 2.5) rounded.
	howMany timesRepeat: [
		loc := self unusedRandomLocationIn: emptyList forGrid: aGrid.
		aGrid at: loc put: self randomizedMirrorCell]! !

!GridFactory class methodsFor: 'as yet unclassified' stamp: 'sbw 6/27/2007 22:52'!
randomizedGridOfExtent: ext
	| grid |
	grid := Grid newOfSize: ext.
	self randomizeGrid: grid targetAt: ((ext x)@1).
	^grid! !

!GridFactory class methodsFor: 'as yet unclassified' stamp: 'sbw 6/27/2007 19:18'!
randomizedMirrorCell
	^self randomBoolean
		ifTrue: [MirrorCell leanLeft]
		ifFalse: [MirrorCell leanRight]! !

!GridFactory class methodsFor: 'as yet unclassified' stamp: 'sbw 6/27/2007 18:49'!
reSeed
	self randomNumberGenerator seed: Time totalSeconds! !

!GridFactory class methodsFor: 'as yet unclassified' stamp: 'sbw 6/27/2007 19:29'!
unusedRandomLocationIn: list forGrid: aGrid
	| x y pt |
	[
	x := self randomNumberGenerator nextInt: aGrid numberOfColumns.
	y := self randomNumberGenerator nextInt: aGrid numberOfRows.
	pt := x@y.
	list at: pt
	] whileTrue: [].
	list at: pt put: true.
	^pt! !

Object subclass: #LaserGameColors
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Laser-Game-Graphics'!

!LaserGameColors class methodsFor: 'as yet unclassified' stamp: 'sbw 6/23/2007 13:30'!
allowActionArrowColor
	^Color green! !

!LaserGameColors class methodsFor: 'as yet unclassified' stamp: 'sbw 6/26/2007 18:08'!
cellBorderColor
	^Color white! !

!LaserGameColors class methodsFor: 'as yet unclassified' stamp: 'sbw 6/23/2007 13:32'!
denyActionArrowColor
	^Color red! !

!LaserGameColors class methodsFor: 'as yet unclassified' stamp: 'sbw 5/26/2007 23:08'!
gameBoardBackgroundColor
	^Color r: 0.860 g: 0.860 b: 0.860! !

!LaserGameColors class methodsFor: 'as yet unclassified' stamp: 'sbw 6/29/2007 20:58'!
laserBeamCenterColor
	^Color r: 0.909 g: 1.0 b: 0.27! !

!LaserGameColors class methodsFor: 'as yet unclassified' stamp: 'sbw 6/29/2007 20:58'!
laserBeamSplatterColor
	^Color r: 1.0 g: 1.0 b: 0.71! !

!LaserGameColors class methodsFor: 'as yet unclassified' stamp: 'sbw 5/26/2007 23:08'!
mirrorColor
	^Color blue! !

!LaserGameColors class methodsFor: 'as yet unclassified' stamp: 'sbw 5/26/2007 23:46'!
targetCenterColor
	^Color r: 0.0 g: 0.0 b: 0.92! !

!LaserGameColors class methodsFor: 'as yet unclassified' stamp: 'sbw 5/26/2007 23:33'!
targetCenterColorActive
	^Color r: 1.0 g: 1.0 b: 0.634! !

!LaserGameColors class methodsFor: 'as yet unclassified' stamp: 'sbw 5/26/2007 23:29'!
targetCenterColorIdle
	^Color r: 0.313 g: 0.753 b: 0.976! !

Object subclass: #LaserGameForms
	instanceVariableNames: ''
	classVariableNames: 'CachedForms'
	poolDictionaries: ''
	category: 'Laser-Game-Graphics'!

!LaserGameForms class methodsFor: 'as yet unclassified' stamp: 'PeterMeadows 10/21/2012 07:27'!
arrowFormFromPointsArray: pts
	"LaserGameForms initializeCachedForms"
	| form fillForm index startPoint nextIndex endPoint line offset |
	offset := 2@2.
	form := Form extent: 330@330 depth: 1.
	form fillColor: Color white.
	fillForm := Form extent: 1@1 depth: 1.
	fillForm fillColor: Color black.
	index := 1.
	[index <= pts size] whileTrue: [
		startPoint := pts at: index.
		nextIndex := index = pts size
			ifTrue: [1]
			ifFalse: [index + 1].
		endPoint := pts at: nextIndex.
		startPoint := startPoint + offset.
		endPoint := endPoint + offset.
		line := Line from: startPoint to: endPoint withForm: fillForm.
		line displayOn: form.
		index := index + 1].
	form floodFill2: Color black at: 1@1.
	form reverse.
	^form copy: (form tightRectangleAroundColor: Color black)! !

!LaserGameForms class methodsFor: 'as yet unclassified' stamp: 'sbw 6/29/2007 19:50'!
centerBeamMask
	CachedForms isNil ifTrue: [self initializeCachedForms].
	^CachedForms at: #centerBeamMask! !

!LaserGameForms class methodsFor: 'as yet unclassified' stamp: 'sbw 6/10/2007 09:27'!
clockwiseArrow
	CachedForms isNil ifTrue: [self initializeCachedForms].
	^CachedForms at: #clockwise! !

!LaserGameForms class methodsFor: 'as yet unclassified' stamp: 'sbw 6/10/2007 09:28'!
counterClockwiseArrow
	CachedForms isNil ifTrue: [self initializeCachedForms].
	^CachedForms at: #counterClockwise! !

!LaserGameForms class methodsFor: 'as yet unclassified' stamp: 'sbw 6/24/2007 21:50'!
crossHair
	CachedForms isNil ifTrue: [self initializeCachedForms].
	^CachedForms at: #crossHair
! !

!LaserGameForms class methodsFor: 'as yet unclassified' stamp: 'sbw 6/29/2007 17:58'!
drawCenterLaserBeamMask
    ^(Form
	extent: 736@196
	depth: 1
	fromArray: #( 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 3670016 1073741820 7168 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 16744449 4294967295 2147614464 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 7 4286578688 4294967295 4294967295 4294967295 511 3758096384 0 0 0 0 0 0 0 0 0 0 0 0 0 0 16776192 0 127 4294967295 4294967295 4294967295 4294967295 4294967295 4261412864 0 4194048 0 0 0 0 0 0 0 0 0 0 4095 4160749568 1073741823 4294901760 4095 4294967295 4294967295 4294967295 4294967295 4294967295 4293918720 65535 4294967292 31 4293918720 0 0 0 0 2181038079 3766222848 0 33550336 16383 4278190083 4294967295 4294959104 16383 4294967295 4294967295 4261412991 4294967295 4294967295 4294705152 524287 4294967295 3221225727 4294705152 1048448 0 15879 4294967169 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967040 8388607 4294967295 4294967295 3758096391 4294967295 4294967295 4294966784 16777215 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 2147483649 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294966799 2147483649 4034920447 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294966784 16777215 4294967295 4294737727 4287102751 4261511295 4177519103 4244520959 4294967295 4294967040 8388607 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294707199 4294967295 4294967295 4294967295 4294966784 134217727 4294959104 2097151 4294963231 4294443011 4278255615 4294967295 4294902015 3221233663 4161798143 4294965248 524287 4294967264 8388607 4294967295 4294967295 4294967295 4292886527 4286578695 4294965503 4294967295 3221226495 4294836224 504 2147450880 4095 4294950919 4292870144 4088 4294967295 535822336 2047 3758358527 4293918720 131070 528482304 32767 4290772995 4294967295 4280287231 3758096895 0 0 0 0 0 0 0 0 0 0 224 67108800 117440512 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0)
	offset: 0@0)! !

!LaserGameForms class methodsFor: 'as yet unclassified' stamp: 'sbw 6/10/2007 09:32'!
drawClockwiseArrow
	^self drawCounterClockwiseArrow flipBy: #horizontal centerAt: 0@0! !

!LaserGameForms class methodsFor: 'as yet unclassified' stamp: 'PeterMeadows 10/21/2012 07:31'!
drawCounterClockwiseArcsOn: form withPen: penForm
	| center outsideCircle insideCircle line bigPen |
	center := 282@240.
	outsideCircle := Arc new.
	outsideCircle quadrant: 2.
	outsideCircle form: penForm.
	outsideCircle radius: 200.
	outsideCircle center: center.
	outsideCircle displayOn: form.
	outsideCircle quadrant: 1.
	outsideCircle displayOn: form.
	insideCircle := Arc new.
	insideCircle quadrant: 2.
	insideCircle form: penForm.
	insideCircle radius: 160.
	insideCircle center: center.
	insideCircle displayOn: form.
	insideCircle quadrant: 1.
	insideCircle displayOn: form.
	line := Line from: center to: (form extent x@0) withForm: penForm.
	line displayOn: form.
	form floodFill2: Color black at: 100@235.
	bigPen := Form extent: 100@100 depth: 1.
	bigPen fillColor: Color white.
	line form: bigPen.
	line displayOn: form.
! !

!LaserGameForms class methodsFor: 'as yet unclassified' stamp: 'sbw 6/10/2007 09:37'!
drawCounterClockwiseArrow
	| form penForm |
	form := Form extent: 450@450 depth: 1.
	form fillColor: Color white.
	penForm := Form extent: 1@1 depth: 1.
	penForm fillColor: Color black.
	self drawCounterClockwiseArrowHeadOn: form withPen: penForm.
	self drawCounterClockwiseArcsOn: form withPen: penForm.
	^form
! !

!LaserGameForms class methodsFor: 'as yet unclassified' stamp: 'PeterMeadows 10/21/2012 07:30'!
drawCounterClockwiseArrowHeadOn: form withPen: penForm
	| arrowPts index offset startPoint nextIndex endPoint line |
	arrowPts := {100@260. 40@150. 80@150. 80@141. 120@141. 120@150. 160@150}.
	index := 1.
	offset := 2@100.
	[index <= arrowPts size] whileTrue: [
		startPoint := arrowPts at: index.
		nextIndex := index = arrowPts size
			ifTrue: [1]
			ifFalse: [index + 1].
		endPoint := arrowPts at: nextIndex.
		startPoint := startPoint + offset.
		endPoint := endPoint + offset.
		line := Line from: startPoint to: endPoint withForm: penForm.
		line displayOn: form.
		index := index + 1].
	form floodFill2: Color black at: 100@255.
! !

!LaserGameForms class methodsFor: 'as yet unclassified' stamp: 'sbw 6/24/2007 21:56'!
drawCrossHair
	"LaserGameForms initializeCachedForms"
	| form pen startPoint endPoint line lineLength inset |
	lineLength := 10.
	form := Form extent: CellRenderer cellExtent depth: 32.
	form fillColor: Color transparent.
	pen := Form extent: 1@1 depth: 1.
	pen fillColor: Color black.
	inset := ((form width - lineLength) // 2)@((form height - lineLength) // 2).
	startPoint := (inset x)@(form height // 2).
	endPoint := (form width - (inset x))@(form height // 2).
	line := Line from: startPoint to: endPoint withForm: pen.
	line displayOn: form.
	startPoint := (form width // 2)@(inset y).
	endPoint := (form width // 2)@(form height - (inset y)).
	line := Line from: startPoint to: endPoint withForm: pen.
	line displayOn: form.
	^form
! !

!LaserGameForms class methodsFor: 'as yet unclassified' stamp: 'sbw 6/28/2007 19:00'!
drawLaserBeamForm
	^(Form
	extent: 368@196
	depth: 32
	fromArray: #( 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967270 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967262 4294967221 4294967221 4294967221 4294967221 4294967229 4294967262 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967262 4294967237 4294967221 4294967221 4294967254 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294967237 4294967221 4294967221 4294967229 4294967253 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967229 4294967221 4294967221 4294967221 4294967221 4294967237 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967254 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967282 4294967274 4294967270 4294967270 4294967270 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967237 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967282 4294967266 4294967245 4294967237 4294967237 4294967237 4294967258 4294967282 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294967262 4294967254 4294967254 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967254 4294967254 4294967254 4294967254 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967254 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294967253 4294967229 4294967221 4294967221 4294967221 4294967221 4294967229 4294967253 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967221 4294967221 4294967221 4294967221 4294967221 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967237 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967237 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967237 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294967262 4294967254 4294967254 4294967254 4294967254 4294967254 4294967254 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967229 4294967254 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967237 4294967221 4294967221 4294967221 4294967221 4294967229 4294967262 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294967237 4294967221 4294967221 4294967221 4294967253 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967237 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967229 4294967253 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967254 4294967262 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294967253 4294967229 4294967221 4294967237 4294967237 4294967237 4294967254 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967262 4294967221 4294967221 4294967221 4294967221 4294967229 4294967262 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967253 4294967229 4294967221 4294967221 4294967221 4294967221 4294967221 4294967253 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967237 4294967253 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967221 4294967229 4294967253 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294967262 4294967254 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294967253 4294967237 4294967237 4294967237 4294967237 4294967237 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294967270 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967270 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967253 4294967237 4294967237 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967225 4294967245 4294967274 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967262 4294967229 4294967221 4294967221 4294967221 4294967225 4294967245 4294967274 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967245 4294967237 4294967237 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294967270 4294967270 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967241 4294967270 4294967282 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967221 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967254 4294967254 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967221 4294967221 4294967221 4294967221 4294967221 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967221 4294967221 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967287 4294967287 4294967287 4294967287 4294967270 4294967221 4294967221 4294967221 4294967221 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967254 4294967221 4294967221 4294967237 4294967262 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294967262 4294967254 4294967254 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967262 4294967237 4294967221 4294967221 4294967254 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967262 4294967229 4294967221 4294967221 4294967221 4294967221 4294967237 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967254 4294967221 4294967221 4294967237 4294967262 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294967266 4294967254 4294967254 4294967266 4294967282 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967262 4294967229 4294967221 4294967221 4294967221 4294967221 4294967237 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967237 4294967221 4294967221 4294967221 4294967221 4294967229 4294967262 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294967253 4294967229 4294967221 4294967221 4294967237 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967229 4294967221 4294967221 4294967221 4294967221 4294967237 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294967253 4294967229 4294967221 4294967221 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967237 4294967221 4294967221 4294967221 4294967221 4294967229 4294967262 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294967253 4294967237 4294967221 4294967221 4294967237 4294967266 4294967282 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967221 4294967229 4294967262 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967254 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967254 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967221 4294967221 4294967221 4294967221 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967254 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967262 4294967229 4294967225 4294967221 4294967221 4294967225 4294967245 4294967274 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294967270 4294967270 4294967270 4294967274 4294967282 4294967287 4294967262 4294967229 4294967221 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967245 4294967229 4294967221 4294967221 4294967237 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294967262 4294967254 4294967254 4294967254 4294967254 4294967254 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967245 4294967229 4294967221 4294967221 4294967237 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294967270 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967254 4294967254 4294967262 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967254 4294967221 4294967221 4294967237 4294967262 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967237 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967221 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967221 4294967221 4294967221 4294967229 4294967253 4294967278 4294967287 4294967270 4294967237 4294967221 4294967221 4294967221 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967237 4294967221 4294967221 4294967237 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967254 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967254 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967254 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967245 4294967221 4294967221 4294967245 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967270 4294967237 4294967221 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967254 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967254 4294967254 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967029 4294967012 4294967245 4294966992 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967027 4294967027 4294967028 4294967030 4294967287 4294967287 4294967287 4294967287 4294967278 4294967253 4294967237 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967027 4294967026 4294967030 4294967287 4294967287 4294967278 4294967254 4294967229 4294967221 4294967221 4294967221 4294967225 4294967237 4294967266 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967029 4294966760 4294966736 4294967225 4294966975 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294966754 4294967006 4294966754 4294966763 4294967023 4294967027 4294967287 4294967287 4294967287 4294967278 4294967270 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294967270 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967030 4294967028 4294967026 4294967027 4294967030 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967029 4294966498 4294966239 4294967026 4294967287 4294967287 4294967287 4294967287 4294967270 4294967254 4294967254 4294967254 4294967262 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294966760 4294966745 4294966466 4294966967 4294967221 4294967221 4294967007 4294966760 4294967029 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967029 4294967023 4294966727 4294966977 4294966726 4294966737 4294966743 4294966502 4294967030 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967027 4294967027 4294967027 4294967027 4294967021 4294967019 4294967019 4294967019 4294967019 4294967019 4294967019 4294967019 4294967019 4294967019 4294967019 4294967019 4294967019 4294967020 4294967028 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967019 4294967019 4294967019 4294967019 4294967019 4294967019 4294967019 4294967023 4294967027 4294967027 4294967028 4294967028 4294967027 4294967027 4294967023 4294967019 4294967019 4294967019 4294967019 4294967019 4294967019 4294967019 4294967019 4294967019 4294967019 4294967019 4294967019 4294967019 4294967019 4294967019 4294967020 4294967026 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967030 4294967027 4294967027 4294967027 4294967027 4294967027 4294967027 4294967027 4294967027 4294967027 4294967027 4294967029 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967019 4294967019 4294967019 4294967019 4294967019 4294967019 4294967019 4294967019 4294967028 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967028 4294967023 4294967019 4294967019 4294967019 4294967019 4294967019 4294967019 4294967019 4294967016 4294966750 4294966743 4294966743 4294966486 4294966481 4294966480 4294966495 4294967024 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967017 4294966740 4294966492 4294967025 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967029 4294967028 4294967029 4294967287 4294966220 4294966716 4294966966 4294967221 4294967221 4294967221 4294966974 4294966220 4294966763 4294967030 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967029 4294966500 4294966220 4294966966 4294967221 4294967221 4294967221 4294967221 4294966217 4294966763 4294967030 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967029 4294967025 4294967023 4294967029 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967027 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294966743 4294966743 4294966743 4294966743 4294966469 4294966974 4294966974 4294966974 4294966974 4294966974 4294966974 4294966974 4294966974 4294966974 4294966974 4294966974 4294966974 4294966724 4294966502 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967023 4294966974 4294966974 4294966974 4294966974 4294966974 4294966974 4294966974 4294966731 4294966743 4294966743 4294966493 4294966497 4294966743 4294966743 4294966731 4294966974 4294966974 4294966974 4294966974 4294966974 4294966974 4294966974 4294966974 4294966974 4294966974 4294966974 4294966974 4294966974 4294966974 4294966974 4294966725 4294966754 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967023 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966758 4294967023 4294967023 4294967023 4294967023 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967030 4294967028 4294966990 4294966990 4294966990 4294966990 4294966990 4294966990 4294966990 4294966990 4294967020 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967030 4294967022 4294966748 4294966736 4294966990 4294966990 4294966990 4294966990 4294966990 4294966990 4294966732 4294966724 4294966974 4294966974 4294966717 4294966715 4294966720 4294966487 4294966766 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967030 4294967012 4294966985 4294966740 4294967024 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967025 4294967019 4294967025 4294967287 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966722 4294966995 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294966992 4294966714 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966722 4294967011 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294966745 4294966724 4294966974 4294967000 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294966994 4294966974 4294966974 4294966974 4294966974 4294966974 4294966974 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966966 4294966475 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294966974 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966967 4294966713 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966974 4294967007 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966720 4294966727 4294966727 4294966727 4294966727 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294966764 4294966484 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967025 4294966492 4294966722 4294966966 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966967 4294966472 4294966758 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967024 4294967000 4294966974 4294966990 4294967023 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967023 4294967008 4294967016 4294967287 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967241 4294967266 4294967270 4294967270 4294967027 4294967287 4294967019 4294967270 4294967270 4294967262 4294967237 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967237 4294967254 4294967266 4294967282 4294967287 4294967287 4294967287 4294967287 4294967287 4294967282 4294967266 4294967254 4294966974 4294967221 4294967221 4294967229 4294967245 4294967254 4294967000 4294967007 4294967254 4294967254 4294967245 4294967229 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966974 4294967007 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967019 4294967262 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966969 4294966739 4294967023 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967262 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966969 4294966982 4294966994 4294967254 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967019 4294967270 4294967270 4294967270 4294967270 4294967270 4294967270 4294967270 4294967270 4294967270 4294967270 4294967270 4294967270 4294967270 4294967000 4294967254 4294967254 4294967254 4294967254 4294967007 4294967027 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967006 4294967233 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966974 4294966760 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294966760 4294967254 4294967266 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967029 4294967020 4294967004 4294966722 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966977 4294967010 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967221 4294966977 4294967006 4294967027 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967019 4294966990 4294966969 4294967221 4294967254 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966977 4294967237 4294966969 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967225 4294967233 4294967237 4294966735 4294966233 4294966735 4294967237 4294967233 4294967225 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966967 4294966974 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966974 4294967249 4294967014 4294967027 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967030 4294967027 4294966764 4294966988 4294967229 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966720 4294966748 4294967025 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967030 4294967025 4294967013 4294967241 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294966739 4294967237 4294967237 4294967237 4294967237 4294967237 4294967237 4294967237 4294967237 4294967237 4294967237 4294967237 4294967237 4294967237 4294966967 4294967221 4294967221 4294967221 4294967221 4294966974 4294966759 4294967029 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967027 4294966732 4294967225 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966476 4294966765 4294967029 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967030 4294966760 4294966476 4294967221 4294967233 4294966997 4294967019 4294967023 4294967023 4294967029 4294967027 4294967023 4294967019 4294967007 4294966990 4294966975 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967225 4294967245 4294967013 4294967025 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967007 4294966736 4294966723 4294966725 4294966734 4294967011 4294967023 4294967024 4294967025 4294967025 4294967024 4294967023 4294967014 4294967249 4294967233 4294967225 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967225 4294967245 4294967014 4294967024 4294967027 4294967030 4294967287 4294967287 4294967287 4294967287 4294967287 4294967029 4294967025 4294966763 4294967005 4294966980 4294967221 4294967221 4294966969 4294966728 4294966749 4294967022 4294967030 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967030 4294967018 4294966739 4294966974 4294966966 4294967221 4294967225 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966714 4294966464 4294966714 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966974 4294966744 4294966765 4294967029 4294967287 4294967287 4294967287 4294967287 4294967027 4294966760 4294966488 4294966472 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966720 4294966230 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294966765 4294966488 4294966720 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966990 4294966764 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967027 4294966467 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966220 4294966500 4294967029 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967029 4294966500 4294966462 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966969 4294966232 4294966763 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967030 4294966768 4294966220 4294966969 4294967221 4294967221 4294966975 4294966736 4294966743 4294966743 4294966761 4294966755 4294966743 4294966736 4294966978 4294966968 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967225 4294966730 4294966496 4294967027 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967027 4294967023 4294966978 4294966969 4294966966 4294966966 4294966968 4294966729 4294966743 4294966489 4294966494 4294966495 4294966490 4294966743 4294966986 4294967225 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967225 4294966986 4294966490 4294966759 4294967028 4294967287 4294967287 4294967287 4294967287 4294967287 4294967023 4294966496 4294966481 4294966724 4294966968 4294967221 4294967221 4294966965 4294966969 4294966728 4294966494 4294966765 4294967028 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967027 4294966764 4294966745 4294966719 4294966966 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966969 4294966724 4294966732 4294966990 4294966490 4294966745 4294966990 4294966730 4294966721 4294966970 4294966966 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966966 4294966970 4294966990 4294966990 4294966763 4294967027 4294967027 4294967028 4294967028 4294967027 4294967027 4294966763 4294966484 4294966727 4294966716 4294966966 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966974 4294966482 4294967027 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967029 4294966760 4294966714 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966714 4294966473 4294966756 4294967025 4294967029 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967027 4294966764 4294966493 4294966464 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966714 4294966473 4294967011 4294967021 4294967029 4294967287 4294967287 4294967287 4294967287 4294967287 4294967029 4294967017 4294966748 4294966481 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966467 4294966974 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966967 4294966719 4294966484 4294967007 4294967023 4294967023 4294967026 4294967027 4294967024 4294967023 4294966755 4294966739 4294966727 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966966 4294966714 4294966459 4294966967 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966967 4294966727 4294966745 4294967007 4294967011 4294967011 4294967007 4294967007 4294966739 4294966719 4294966966 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966967 4294966462 4294966472 4294966746 4294967019 4294967023 4294967024 4294967025 4294967024 4294967023 4294967015 4294966739 4294966469 4294966717 4294966966 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966966 4294966969 4294966969 4294966720 4294966976 4294966969 4294966968 4294966966 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966969 4294966969 4294966988 4294966994 4294966999 4294966753 4294966753 4294966994 4294966994 4294966988 4294966717 4294966967 4294966965 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966713 4294966732 4294967026 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294966745 4294966725 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966966 4294966975 4294966985 4294967000 4294967021 4294967287 4294967287 4294967287 4294967287 4294967287 4294967021 4294966997 4294966723 4294966716 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966966 4294966972 4294966982 4294966991 4294966994 4294966999 4294966502 4294966994 4294966994 4294966991 4294966978 4294966969 4294966967 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966967 4294966969 4294966982 4294966982 4294966986 4294966732 4294966727 4294966982 4294966717 4294966967 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966967 4294966972 4294966974 4294966724 4294966724 4294966974 4294966974 4294966970 4294966966 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966966 4294966721 4294966737 4294966743 4294966492 4294966495 4294966490 4294966743 4294966730 4294966969 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966969 4294966722 4294966722 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967002 4294967012 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967282 4294967270 4294967254 4294966974 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967229 4294967245 4294967254 4294967002 4294967007 4294967254 4294967254 4294967245 4294967229 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966969 4294966727 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294967253 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967225 4294967229 4294967229 4294966977 4294966974 4294967229 4294967227 4294967223 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967215 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967213 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967215 4294967205 4294967200 4294967200 4294967195 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967192 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967218 4294967210 4294967197 4294967185 4294967180 4294967180 4294967180 4294967187 4294967197 4294967200 4294967200 4294967210 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967215 4294967205 4294967200 4294967190 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967205 4294967215 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967215 4294967205 4294967200 4294967200 4294967200 4294967200 4294967200 4294967196 4294967190 4294967185 4294967181 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967185 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967187 4294967182 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967218 4294967215 4294967215 4294967215 4294967208 4294967205 4294967205 4294967205 4294967205 4294967205 4294967205 4294967205 4294967205 4294967205 4294967205 4294967205 4294967205 4294967205 4294967210 4294967215 4294967215 4294967215 4294967215 4294967215 4294967215 4294967215 4294967215 4294967215 4294967215 4294967215 4294967215 4294967215 4294967215 4294967215 4294967215 4294967215 4294967215 4294967215 4294967215 4294967215 4294967215 4294967218 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967218 4294967215 4294967215 4294967210 4294967205 4294967203 4294967200 4294967200 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967185 4294967195 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967195 4294967185 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967218 4294967213 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967215 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967215 4294967210 4294967210 4294967210 4294967210 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967210 4294967215 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967210 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967205 4294967215 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967210 4294967200 4294967200 4294967195 4294967190 4294967190 4294967190 4294967182 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967185 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967195 4294967200 4294967200 4294967210 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967210 4294967200 4294967195 4294967190 4294967190 4294967185 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967215 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967215 4294967215 4294967212 4294967210 4294967205 4294967195 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967200 4294967210 4294967210 4294967213 4294967215 4294967215 4294967215 4294967215 4294967215 4294967215 4294967221 4294967221 4294967221 4294967221 4294967219 4294967215 4294967201 4294967190 4294967190 4294967190 4294967190 4294967210 4294967210 4294967213 4294967215 4294967215 4294967215 4294967215 4294967210 4294967210 4294967213 4294967215 4294967215 4294967215 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967218 4294967214 4294967212 4294967210 4294967210 4294967210 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967210 4294967213 4294967215 4294967215 4294967215 4294967215 4294967215 4294967218 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967218 4294967215 4294967214 4294967212 4294967200 4294967190 4294967185 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967182 4294967187 4294967190 4294967190 4294967200 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967200 4294967190 4294967190 4294967190 4294967185 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967185 4294967190 4294967190 4294967200 4294967212 4294967214 4294967215 4294967215 4294967218 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967218 4294967215 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967200 4294967190 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967200 4294967200 4294967200 4294967200 4294967195 4294967185 4294967180 4294967180 4294967180 4294967180 4294967180 4294967190 4294967190 4294967192 4294967195 4294967195 4294967195 4294967195 4294967190 4294967190 4294967192 4294967195 4294967195 4294967195 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967202 4294967194 4294967191 4294967190 4294967190 4294967190 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967190 4294967192 4294967195 4294967195 4294967195 4294967195 4294967195 4294967202 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967202 4294967195 4294967194 4294967191 4294967185 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967185 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967185 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967185 4294967191 4294967194 4294967195 4294967195 4294967202 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967202 4294967195 4294967195 4294967195 4294967195 4294967195 4294967195 4294967192 4294967190 4294967190 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294966930 4294966680 4294966680 4294966680 4294966680 4294966680 4294966680 4294966680 4294966930 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967185 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967185 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294966930 4294966430 4294966180 4294966180 4294965930 4294965680 4294965680 4294965680 4294965680 4294965680 4294965680 4294965680 4294966180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294966180 4294965181 4294965181 4294965181 4294965181 4294965181 4294965181 4294965181 4294965181 4294965181 4294965181 4294965181 4294965181 4294965181 4294965430 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294966927 4294966680 4294966177 4294966180 4294966180 4294966680 4294967180 4294967180 4294967180 4294967180 4294967180 4294966930 4294966680 4294966680 4294966680 4294966427 4294966180 4294965677 4294965680 4294965680 4294965680 4294965680 4294965680 4294965680 4294965680 4294966180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967182 4294967185 4294967185 4294967185 4294967185 4294967185 4294967185 4294967185 4294967185 4294967185 4294967185 4294967185 4294967185 4294967185 4294967185 4294967185 4294967185 4294967185 4294967182 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967182 4294967185 4294967186 4294967186 4294967181 4294967180 4294967180 4294967180 4294967180 4294967181 4294967183 4294967185 4294967185 4294967183 4294967181 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967184 4294967188 4294967188 4294967186 4294967183 4294967181 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294966924 4294966927 4294966929 4294966930 4294966930 4294966927 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294966924 4294966927 4294966929 4294966930 4294966930 4294966930 4294966930 4294966930 4294966930 4294966930 4294966927 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967190 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967185 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967187 4294967182 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967182 4294967187 4294967190 4294967190 4294967200 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967200 4294967190 4294967190 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967182 4294967185 4294967185 4294967185 4294967185 4294967185 4294967185 4294967185 4294967183 4294967181 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967181 4294967191 4294967200 4294967203 4294967201 4294967189 4294967185 4294967185 4294967185 4294967185 4294967188 4294967196 4294967200 4294967200 4294967196 4294967188 4294967185 4294967185 4294967182 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967182 4294967186 4294967196 4294967207 4294967207 4294967202 4294967196 4294967188 4294967184 4294967182 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967195 4294967200 4294967200 4294967200 4294967200 4294967210 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967210 4294967200 4294967200 4294967190 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967195 4294967200 4294967190 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967185 4294967195 4294967200 4294967200 4294967200 4294967200 4294967200 4294967210 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967200 4294967190 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967185 4294967195 4294967210 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967210 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967190 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967200 4294967221 4294967221 4294967200 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967190 4294967210 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967200 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967190 4294967205 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967210 4294967190 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967190 4294967200 4294967190 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967200 4294967200 4294967215 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967210 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967215 4294967221 4294967210 4294967200 4294967200 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967195 4294967205 4294967215 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967210 4294967200 4294967200 4294967200 4294967200 4294967200 4294967195 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967195 4294967200 4294967205 4294967215 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967200 4294967200 4294967200 4294967200 4294967210 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967215 4294967205 4294967200 4294967200 4294967195 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967190 4294967195 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967210 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967210 4294967200 4294967200 4294967200 4294967200 4294967200 4294967200 4294967210 4294967215 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967215 4294967205 4294967200 4294967190 4294967180 4294967180 4294967180 4294967185 4294967200 4294967215 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967210 4294967190 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967180 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967215 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967215 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967215 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967210 4294967215 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966966 4294966971 4294966724 4294966729 4294966730 4294966740 4294966745 4294966735 4294966729 4294966469 4294966718 4294966968 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966965 4294966966 4294966966 4294966965 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966972 4294966733 4294966491 4294966753 4294966755 4294967019 4294967023 4294966759 4294966753 4294966492 4294966485 4294966979 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966968 4294966463 4294966463 4294966968 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966967 4294966973 4294966975 4294967225 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967225 4294966979 4294967001 4294967024 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967266 4294967237 4294967225 4294967221 4294967221 4294967221 4294967221 4294967223 4294967231 4294967245 4294967254 4294967002 4294966755 4294966755 4294967002 4294967254 4294967241 4294966972 4294966968 4294966965 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967237 4294967237 4294967237 4294967237 4294967237 4294967237 4294967237 4294967237 4294967237 4294967237 4294967237 4294967237 4294967237 4294967237 4294967237 4294967237 4294967237 4294966979 4294966973 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967237 4294967254 4294967002 4294967015 4294967018 4294967262 4294967254 4294966990 4294966975 4294966967 4294967221 4294967221 4294967221 4294967245 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294967245 4294967221 4294967221 4294967221 4294967225 4294967241 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967027 4294967002 4294966973 4294967221 4294967221 4294967221 4294967221 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966974 4294967254 4294967254 4294967254 4294967270 4294967270 4294967270 4294967270 4294967270 4294967270 4294967270 4294967270 4294967270 4294967270 4294967270 4294967270 4294967270 4294967270 4294967270 4294967270 4294967270 4294967012 4294967006 4294967254 4294967254 4294967237 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967229 4294967249 4294967266 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967027 4294967018 4294967005 4294966729 4294966969 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294966986 4294966971 4294966980 4294967002 4294967020 4294967284 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967024 4294967003 4294966980 4294966967 4294967221 4294967221 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967027 4294967027 4294967027 4294967027 4294966763 4294966755 4294966755 4294966990 4294966730 4294966967 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966971 4294966974 4294966974 4294966974 4294966974 4294966974 4294966974 4294966469 4294966485 4294966500 4294966766 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967027 4294966761 4294966491 4294966475 4294966721 4294966971 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966713 4294966968 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966966 4294966968 4294966720 4294966982 4294966982 4294966985 4294966985 4294966982 4294966982 4294966721 4294966968 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966965 4294966968 4294966969 4294966969 4294966976 4294966972 4294966969 4294966969 4294966966 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966966 4294966715 4294966994 4294967021 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967026 4294966755 4294966737 4294967009 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294966758 4294966479 4294966742 4294967021 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967022 4294966744 4294966729 4294966988 4294966994 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967029 4294967027 4294967027 4294967019 4294966758 4294966492 4294966469 4294966974 4294966974 4294966969 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966967 4294966974 4294966974 4294966974 4294966731 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966758 4294967019 4294967019 4294967019 4294967019 4294967019 4294967019 4294967021 4294967025 4294967029 4294967030 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967030 4294967027 4294967023 4294967020 4294966758 4294966743 4294966743 4294966743 4294966721 4294966974 4294966974 4294966974 4294966974 4294966974 4294966974 4294966974 4294966974 4294966472 4294966484 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966735 4294966727 4294966727 4294966727 4294966727 4294966722 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966974 4294966727 4294966727 4294966483 4294966736 4294966727 4294966727 4294966974 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966969 4294966728 4294966745 4294966760 4294967023 4294967023 4294967025 4294967025 4294967023 4294967023 4294966761 4294966745 4294966464 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966714 4294966470 4294966745 4294967007 4294967007 4294967015 4294967011 4294967007 4294966748 4294966477 4294966727 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966966 4294966717 4294966481 4294966762 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967029 4294967027 4294967029 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967027 4294966765 4294966766 4294967028 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967029 4294967026 4294967023 4294967027 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967029 4294967025 4294966494 4294966743 4294966743 4294966986 4294966972 4294966967 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967225 4294967229 4294967229 4294966724 4294966743 4294966743 4294966743 4294966755 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967029 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967029 4294967023 4294967023 4294967023 4294966491 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966743 4294966496 4294966764 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294966761 4294966743 4294966743 4294966743 4294966481 4294967229 4294967229 4294967227 4294967223 4294967221 4294967221 4294967221 4294967221 4294967221 4294967225 4294966986 4294966755 4294967023 4294967023 4294967027 4294967026 4294967023 4294967023 4294966755 4294966743 4294966467 4294966967 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967225 4294966992 4294966763 4294967029 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967029 4294966500 4294966986 4294967223 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967223 4294966974 4294966484 4294966762 4294967029 4294967287 4294967287 4294967287 4294967287 4294967287 4294967030 4294967025 4294967023 4294966986 4294967223 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966973 4294966482 4294966760 4294967028 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967027 4294967007 4294966727 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966727 4294967254 4294967254 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967024 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967023 4294967026 4294967030 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967029 4294967023 4294967023 4294967023 4294966763 4294967262 4294967262 4294967255 4294967243 4294967221 4294967221 4294967221 4294967221 4294967225 4294967245 4294967015 4294967027 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967027 4294967023 4294966749 4294966728 4294966967 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967241 4294967016 4294967029 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967027 4294967014 4294967231 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967235 4294967002 4294967019 4294967029 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967014 4294967239 4294967225 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966976 4294966748 4294967025 4294967030 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967007 4294967254 4294967254 4294967254 4294967254 4294967254 4294967254 4294967254 4294967254 4294967254 4294966992 4294966980 4294966974 4294966983 4294967254 4294967254 4294967254 4294967262 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294966760 4294966727 4294967221 4294966990 4294967023 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967261 4294967233 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966977 4294967006 4294967027 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967262 4294967254 4294967254 4294967262 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967024 4294966754 4294966747 4294966757 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294966768 4294966493 4294966497 4294967027 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967017 4294966733 4294966972 4294966969 4294966969 4294966969 4294966969 4294966967 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966727 4294966760 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294966974 4294967007 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967229 4294967221 4294967221 4294967229 4294967253 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967030 4294967028 4294967027 4294967028 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294967270 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967030 4294966768 4294966768 4294967030 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967029 4294966758 4294966739 4294966990 4294966990 4294966990 4294966990 4294966990 4294966990 4294966990 4294966990 4294966990 4294966990 4294966990 4294966990 4294966990 4294966990 4294966990 4294966990 4294966990 4294966990 4294966990 4294966990 4294966990 4294966990 4294966990 4294966990 4294966489 4294966765 4294967253 4294967237 4294967237 4294967253 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967021 4294966755 4294966755 4294966755 4294966755 4294966755 4294966755 4294966755 4294966755 4294966755 4294966755 4294966755 4294966763 4294967020 4294967270 4294967270 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294967270 4294967270 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294967254 4294967237 4294967245 4294967266 4294967282 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294967270 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967030 4294967030 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967027 4294967021 4294967019 4294967019 4294967019 4294967019 4294967019 4294967019 4294967019 4294967019 4294967019 4294967019 4294967019 4294967019 4294967019 4294967019 4294967019 4294967019 4294967019 4294967019 4294967019 4294967019 4294967019 4294967019 4294967019 4294967019 4294967022 4294967011 4294967229 4294967221 4294967221 4294967229 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967029 4294967027 4294967027 4294967027 4294967027 4294967027 4294967027 4294967027 4294967027 4294967027 4294967027 4294967027 4294967029 4294967253 4294967237 4294967237 4294967253 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294967253 4294967237 4294967237 4294967237 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294967254 4294967229 4294967221 4294967225 4294967241 4294967266 4294967282 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967237 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967254 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967237 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967221 4294967221 4294967221 4294967221 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967262 4294967229 4294967221 4294967221 4294967221 4294967225 4294967245 4294967274 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967237 4294967221 4294967221 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967221 4294967221 4294967221 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967221 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967254 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967254 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967221 4294967221 4294967221 4294967221 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967237 4294967221 4294967221 4294967237 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967237 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967221 4294967221 4294967221 4294967221 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967221 4294967229 4294967254 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967262 4294967229 4294967221 4294967229 4294967254 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967254 4294967254 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967237 4294967221 4294967221 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967221 4294967221 4294967221 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967254 4294967262 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967221 4294967221 4294967221 4294967229 4294967262 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294967270 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967254 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967221 4294967221 4294967221 4294967221 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967237 4294967221 4294967221 4294967221 4294967221 4294967229 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967237 4294967221 4294967221 4294967221 4294967221 4294967229 4294967262 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967262 4294967229 4294967221 4294967221 4294967221 4294967229 4294967262 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294967253 4294967237 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967237 4294967237 4294967253 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294967237 4294967237 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967253 4294967237 4294967237 4294967253 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967221 4294967221 4294967221 4294967229 4294967262 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967221 4294967221 4294967221 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294967270 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294967237 4294967221 4294967221 4294967221 4294967229 4294967253 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967270 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967262 4294967229 4294967221 4294967221 4294967221 4294967229 4294967262 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967229 4294967221 4294967221 4294967229 4294967253 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967245 4294967237 4294967245 4294967266 4294967282 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967221 4294967221 4294967221 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967237 4294967221 4294967221 4294967221 4294967221 4294967229 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967254 4294967262 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967282 4294967274 4294967270 4294967274 4294967282 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967254 4294967254 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967221 4294967221 4294967221 4294967221 4294967221 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967254 4294967254 4294967254 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294967262 4294967237 4294967221 4294967221 4294967221 4294967254 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967237 4294967237 4294967237 4294967245 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967221 4294967221 4294967221 4294967221 4294967254 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967254 4294967254 4294967262 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967245 4294967237 4294967237 4294967245 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967237 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967221 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967270 4294967270 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967237 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967237 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294967237 4294967221 4294967221 4294967229 4294967253 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294967270 4294967270 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967262 4294967229 4294967221 4294967221 4294967221 4294967225 4294967245 4294967274 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967262 4294967229 4294967221 4294967221 4294967221 4294967221 4294967221 4294967262 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967254 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967237 4294967221 4294967221 4294967221 4294967221 4294967245 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294967254 4294967229 4294967221 4294967225 4294967241 4294967266 4294967282 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294967262 4294967237 4294967221 4294967221 4294967221 4294967254 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967245 4294967221 4294967221 4294967221 4294967245 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967221 4294967221 4294967221 4294967221 4294967254 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967221 4294967221 4294967237 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967254 4294967262 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967254 4294967254 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967254 4294967254 4294967254 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967254 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967221 4294967229 4294967254 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294967245 4294967221 4294967221 4294967245 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967254 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967237 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967221 4294967221 4294967221 4294967229 4294967254 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294967254 4294967229 4294967221 4294967221 4294967229 4294967254 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967237 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967221 4294967221 4294967221 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967221 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967221 4294967221 4294967221 4294967221 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967270 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967229 4294967221 4294967221 4294967221 4294967221 4294967237 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967237 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967221 4294967221 4294967221 4294967229 4294967253 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294967253 4294967229 4294967221 4294967221 4294967229 4294967253 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967237 4294967221 4294967221 4294967221 4294967221 4294967229 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967253 4294967229 4294967221 4294967221 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967237 4294967253 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294967254 4294967237 4294967245 4294967266 4294967282 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967282 4294967258 4294967237 4294967237 4294967258 4294967282 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294967253 4294967237 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967270 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294967270 4294967274 4294967282 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294967270 4294967270 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967254 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967254 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967254 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967254 4294967221 4294967221 4294967221 4294967221 4294967221 4294967221 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967237 4294967221 4294967221 4294967229 4294967253 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294967253 4294967229 4294967221 4294967221 4294967237 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967295 4294967295 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967270 4294967254 4294967254 4294967262 4294967278 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967278 4294967262 4294967254 4294967254 4294967270 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967295 4294967295 4294967295 4294967295 4294967295 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967287 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295)
	offset: 0@0)! !

!LaserGameForms class methodsFor: 'as yet unclassified' stamp: 'sbw 6/29/2007 17:56'!
drawSplatterLaserBeamMask
    ^(Form
	extent: 736@196
	depth: 1
	fromArray: #( 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 917504 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 28672 0 0 2031616 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 63488 0 0 4161536 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 130048 0 0 4161536 0 64512 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4128768 0 130048 0 0 4161536 0 64512 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4128768 0 130048 0 0 917504 0 64512 0 0 0 0 0 0 63488 0 2031616 0 0 0 0 0 0 4128768 0 28672 0 0 0 0 64512 0 0 0 0 0 0 129024 0 2064384 0 0 0 0 0 0 4128768 0 0 0 0 0 0 63488 0 31 2147483648 0 469762048 0 523776 0 8380416 0 56 0 1 4160749568 0 2031616 0 0 0 0 0 0 0 0 63 3221225472 0 2113929216 2080374784 523776 0 8380416 62 126 0 3 4227858432 0 0 0 0 0 57344 0 0 0 0 63 3758096384 0 2113929216 4261543680 523776 0 8380416 16744575 126 0 7 4227858432 0 0 0 0 458752 260096 0 260096 0 0 63 3758096384 0 2113929216 4261937088 252181504 0 4186352 67100799 126 0 7 4227858432 0 0 2080768 0 2080768 260096 0 260096 0 0 63 3758096384 0 1040187392 4262461376 528728064 0 246264 67104895 124 0 7 4227858432 0 0 2080768 0 2080768 260096 0 260096 0 0 63 3221225472 14680064 469762048 2081423296 1069547520 0 1020 67104830 56 1792 3 4227858432 0 0 2080768 0 2080768 57344 0 126976 0 14680064 0 0 32505856 0 2014314368 1069547520 0 1020 33550366 0 3968 0 0 1792 0 1015808 0 458752 0 245760 1044480 0 66600448 0 0 66584576 0 253952 528482304 3947520 504 507904 0 8128 0 0 8134592 0 1044480 245760 0 0 516096 2095104 0 66617088 4261412864 520158208 66584576 16646144 2031616 251658240 8289792 240 63488 32512 8128 4129016 127 16654272 0 2095104 516096 0 0 516096 2095104 0 66617088 4261412864 1065417728 66584576 16646144 4161536 0 16776960 0 130048 32512 8128 4129276 127 16654272 0 2095104 516096 0 0 1879564288 2095104 3670016 32538368 4261412864 1065417728 14680064 16646144 4177920 0 2097151806 0 261120 32512 1792 4129276 127 16650112 7168 2095104 516110 0 1 4228374528 1044480 8257536 14695936 4261412864 1065417728 0 16646144 4177920 0 4286578431 0 261120 32512 0 4129276 127 8128256 32256 1044480 516159 2147483648 1 4228104192 0 8257536 0 939524096 520122368 0 3670016 2064384 1 4282285311 2147483648 129024 7168 0 917752 28 0 32256 0 245823 2147483648 1 4227858432 0 8257536 0 0 234881024 0 0 983040 1 4278190335 2147483648 61440 0 0 112 0 0 32256 0 63 2147483648 469762048 4160749568 0 8126464 0 0 0 0 0 0 1 4278190335 2147483648 0 0 0 0 0 0 15872 0 31 56 1006633208 1879048192 0 3670016 0 0 0 0 0 0 48 2113929342 201326592 0 0 0 0 0 0 7168 0 14 520093756 4278190588 0 2147352576 2139226111 0 0 0 0 32640 127 4286578800 0 234881535 4261412864 33423360 0 0 0 0 4294935038 32766 0 1065353471 4286579710 262655 4294901760 4294967295 2147516415 2147483648 0 0 32704 255 4290773104 270336 234882047 4278190080 66977792 0 0 1 4294836225 4294967295 65535 4286586880 2143289855 4292874239 2033663 4294901760 4294967295 2147516415 2147483648 0 0 131008 255 4290773112 946176 503317503 4278190080 67076096 0 0 1 4294836225 4294967295 65535 4292933632 4293920767 4294770687 3229614079 4294950915 4294967295 3221258239 4286578751 4294705155 4294950912 2013790176 511 4290773240 2095104 520094719 4286578688 134209566 262143 3221241855 4227858943 4294836227 4294967295 3221487615 4294966787 4294918143 4294967295 4294967295 4294959111 4294967295 3221291007 4286578751 4294836227 4294959104 4282384368 16654335 4293919742 4193280 2143293439 4294475520 268434687 524287 3221258239 4227858943 4294901763 4294967295 3758620671 4294967295 4294967295 4294967295 4294967295 4294965279 4294967295 3758358527 4290773055 4294901767 4294963200 4294967288 33554431 4294709247 8388096 4293935103 4294967168 536870911 1048575 3758161919 4227859455 4294950919 4294967295 4162846719 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4228907007 4290773119 4294934559 4294966279 4294967295 2415919103 4294967295 3825205191 4294967295 4294967281 4294967295 3762290687 4160880639 4261413887 4294963263 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4292870399 4294963327 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4262461439 4278192127 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294706175 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4290789375 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294840319 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4293951487 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294705407 4294967295 4278206463 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294443135 2151676929 4261421055 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 67108863 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967294 66060351 2095104 4227862464 2147483647 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967232 4194303 4294967295 4294967295 4294963200 524287 4294967295 4294967295 4294967295 4294967295 4294967288 14680094 2095104 2013267712 536870911 4294967295 4294967295 4294967295 4294967295 4294959104 1048575 4294967295 4294967295 4294966272 524287 4294967295 4294967295 4294934528 131071 4294967295 4294967295 4294964223 4294967295 4294967280 12 270336 805306368 268435455 4294967295 4291821567 4294967295 4294967295 4294934528 131071 4294967295 4294967295 4294959104 65535 4294967295 4294967295 4286578688 16383 4294967295 4282384383 4294901823 4294836735 4294967264 0 0 0 134217727 4286611455 4227923967 4294966527 4294967295 4294705152 511 4294967295 4294967295 4294901760 2047 4294967292 0 0 1020 1023 4161273855 4294836255 4294705407 4294967232 0 0 0 67108863 4278206463 4160782335 4294959135 4290772992 1069547520 0 0 1073741823 4292870144 0 268434944 0 0 0 3 3758161919 4294705167 4293918847 4294967232 0 0 0 67108863 4261416959 4026548223 4294901767 3221225472 0 0 0 8388592 0 63488 114688 0 0 0 0 3221291007 4294443015 4292870144 0 0 0 0 0 2047 3758104575 4294901763 0 0 0 0 229376 2031616 129024 0 0 1835008 0 0 32767 4294934535 4294705152 251658240 520093696 0 248 240 16383 3758227455 4294836224 0 0 14336 0 0 2064384 129024 0 0 4063232 0 58720256 16383 4294950912 4063232 528482304 1065353216 0 508 504 31744 262143 4294705152 448 0 31744 0 0 2064384 129024 0 0 8323072 0 130023424 3584 1032192 8257536 1069547520 1069547520 0 1020 1020 32256 258048 7340032 992 0 65024 0 0 2064384 63488 0 0 8323072 32505856 266340288 16256 1032192 8257536 1069547520 1069547520 0 1020 1020 32256 258048 33292288 65013744 3968 65024 0 0 2031616 939524096 58720256 1879048192 8323072 66584576 266342368 16256 491520 8257536 1069547520 528482335 2147483649 4160750072 1020 32256 122880 33292288 133171184 8128 65024 14 448 28 2080374784 130023424 4160749568 4063232 66584576 130027488 16256 491520 4063232 528482304 251658303 2147483649 4227858672 504 31744 122880 33292288 133170144 8128 31744 31 992 62 4227858432 266338305 4227858432 1835008 66584576 58724320 16256 0 0 0 63 2147483649 4227858432 0 0 0 33292288 133169600 8128 14336 63 2147485680 63 4227858432 266338305 4227858432 0 32521984 1984 16256 3968 0 0 63 2147483649 4227858432 0 0 32505856 33292288 65011712 16519040 0 63 2147485680 63 2080374784 130023424 4160749568 0 14712704 896 16256 8064 0 0 31 0 4160749568 0 0 33030144 33292288 29360128 33425152 0 31 992 62 0 0 0 0 32640 0 3584 8064 0 0 251658254 0 1879048432 0 0 33030144 7340032 0 33423360 0 0 0 0 0 1006632960 0 0 32640 260046848 0 8064 1966080 0 528482304 0 504 0 30720 33030144 0 496 33423360 0 0 60 0 0 4278190080 0 0 16128 534773760 3968 3968 4128768 0 1069547520 0 1020 0 64512 32505856 32505856 2040 16515072 0 0 255 0 0 4278190080 0 0 7680 534773760 8128 3840 4128768 0 1069547520 0 1020 0 64512 15728640 66584576 2040 7864320 0 0 255 0 0 4278190080 0 14 0 534773760 8128 0 4128768 0 1065353216 0 508 0 64512 0 66584576 2040 0 1879048192 0 255 0 0 4278190080 0 63 2147483648 534773760 8128 0 4063232 0 251658240 0 240 0 31744 0 66584576 2040 1 4227858432 0 255 0 0 1006632960 0 63 2147483648 260046848 7344000 0 31744 4032 2113929216 0 126 66060288 4063232 0 32509440 496 1 4227858432 0 60 0 0 0 56 63 2147483648 0 16254720 0 64512 8160 4278190080 0 255 133693440 4128768 0 14688000 0 1 4227858432 469762048 0 0 0 0 252 31 0 0 16515072 0 64512 8160 4278190080 0 255 133693440 4128768 0 16128 0 0 4160749568 1056964608 0 0 0 0 252 14 0 0 16515072 0 64512 8160 4278190080 0 255 133693440 4128768 0 16128 0 0 1879048192 1056964608 0 0 0 0 252 0 0 0 16515072 0 31744 3968 1006632960 0 60 32505856 4063232 0 16128 0 0 0 1056964608 0 0 0 0 124 0 0 0 16252928 0 14336 1792 1006632960 0 60 14680064 1835008 0 7936 0 0 0 1040187392 0 0 0 458752 0 469762048 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 56 0 57344 0 0 1015808 0 1040187392 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 124 0 126976 0 0 2080768 0 2130706432 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 254 0 260096 0 0 2080768 0 2130706432 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 254 0 260096 0 0 2080768 0 2130706432 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 254 0 260096 0 0 1015808 0 1040187392 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 124 0 126976 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0)
	offset: 0@0)! !

!LaserGameForms class methodsFor: 'as yet unclassified' stamp: 'sbw 6/2/2007 12:25'!
eastArrow
	CachedForms isNil ifTrue: [self initializeCachedForms].
	^CachedForms at: #east! !

!LaserGameForms class methodsFor: 'as yet unclassified' stamp: 'sbw 6/2/2007 12:16'!
eastArrowPoints
	^{0@80. 150@80. 150@0. 260@100. 150@200. 150@120. 0@120}! !

!LaserGameForms class methodsFor: 'as yet unclassified' stamp: 'sbw 6/29/2007 17:39'!
extractLaserBeamMaskForms
	"LaserGameForms extractLaserBeamMaskForms"

	| beamForm newExtent splatterForm centerForm color splatterMask centerMask |
	self initializeCachedForms.
	beamForm := LaserGameForms laserBeam.
	newExtent := beamForm extent * (2@1).
	splatterForm := Form extent: newExtent depth: beamForm depth.
	centerForm := Form extent: newExtent depth: beamForm depth.
	beamForm displayOn: splatterForm at: 0@0.
	beamForm displayOn: centerForm at: 0@0.
	(beamForm flipBy: #horizontal centerAt: 0@0)
		displayOn: splatterForm at: (beamForm width@0);
		displayOn: centerForm at: (beamForm width@0).
	color := splatterForm colorAt: 10@60.
	splatterForm replaceColor: color withColor: Color white.
	centerForm replaceColor: color withColor: Color white.
	splatterMask := (splatterForm makeBWForm: Color white) reverse.
	color := beamForm colorAt: 10@90.
	centerForm replaceColor: color withColor: Color black.
	centerMask := centerForm makeBWForm: Color black.
	splatterForm displayAt: 10@0.
	splatterMask displayAt: 10@200.
	centerMask displayAt: 10@400.
	color := beamForm colorAt: 10@80.
	splatterMask
		displayOn: Display
		at: 10@560
		clippingBox: Display boundingBox
		rule: Form oldPaint
		fillColor: color.
	centerMask
		displayOn: Display
		at: 10@560
		clippingBox: Display boundingBox
		rule: Form oldPaint
		fillColor: (Color r: 0.909 g: 1.0 b: 0.27)! !

!LaserGameForms class methodsFor: 'as yet unclassified' stamp: 'sbw 6/24/2007 21:49'!
initialize
	super initialize.
	LaserGameForms initializeCachedForms! !

!LaserGameForms class methodsFor: 'as yet unclassified' stamp: 'sbw 6/29/2007 19:50'!
initializeCachedForms
	"LaserGameForms initializeCachedForms"
	| form |
	CachedForms := Dictionary new.
	form := self arrowFormFromPointsArray: self northArrowPoints.
	CachedForms at: #north put: form.
	form := self arrowFormFromPointsArray: self eastArrowPoints.
	CachedForms at: #east put: form.
	form := self arrowFormFromPointsArray: self southArrowPoints.
	CachedForms at: #south put: form.
	form := self arrowFormFromPointsArray: self westArrowPoints.
	CachedForms at: #west put: form.
	form := self drawCounterClockwiseArrow.
	CachedForms at: #counterClockwise put: form.
	form := self drawClockwiseArrow.
	CachedForms at: #clockwise put: form.
	form := self drawCrossHair.
	CachedForms at: #crossHair put: form.
	form := self drawLaserBeamForm.
	CachedForms at: #laserBeam put: form.
	form := self drawCenterLaserBeamMask.
	CachedForms at: #centerBeamMask put: form.
	form := self drawSplatterLaserBeamMask.
	CachedForms at: #splatterBeamMask put: form.
	! !

!LaserGameForms class methodsFor: 'as yet unclassified' stamp: 'sbw 6/28/2007 19:09'!
laserBeam
	CachedForms isNil ifTrue: [self initializeCachedForms].
	^CachedForms at: #laserBeam
! !

!LaserGameForms class methodsFor: 'as yet unclassified' stamp: 'sbw 6/2/2007 12:25'!
northArrow
	CachedForms isNil ifTrue: [self initializeCachedForms].
	^CachedForms at: #north! !

!LaserGameForms class methodsFor: 'as yet unclassified' stamp: 'sbw 6/2/2007 12:17'!
northArrowPoints
	^{100@0. 200@110. 120@110. 120@260. 80@260. 80@110. 0@110}! !

!LaserGameForms class methodsFor: 'as yet unclassified' stamp: 'sbw 6/2/2007 12:25'!
southArrow
	CachedForms isNil ifTrue: [self initializeCachedForms].
	^CachedForms at: #south! !

!LaserGameForms class methodsFor: 'as yet unclassified' stamp: 'sbw 6/2/2007 12:17'!
southArrowPoints
	^{100@260. 0@150. 80@150. 80@0. 120@0. 120@150. 200@150}! !

!LaserGameForms class methodsFor: 'as yet unclassified' stamp: 'sbw 6/29/2007 19:50'!
splatterBeamMask
	CachedForms isNil ifTrue: [self initializeCachedForms].
	^CachedForms at: #splatterBeamMask! !

!LaserGameForms class methodsFor: 'as yet unclassified' stamp: 'sbw 6/2/2007 12:25'!
westArrow
	CachedForms isNil ifTrue: [self initializeCachedForms].
	^CachedForms at: #west! !

!LaserGameForms class methodsFor: 'as yet unclassified' stamp: 'sbw 6/2/2007 12:16'!
westArrowPoints
	^{260@80. 110@80. 110@0. 0@100. 110@200. 110@120. 260@120}! !

Object subclass: #LaserPathElement
	instanceVariableNames: 'cell entrySide'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Laser-Game-Model'!

!LaserPathElement class methodsFor: 'as yet unclassified' stamp: 'sbw 5/21/2007 20:55'!
cell: aCell entrySide: aSymbol
	| model |
	model := self basicNew.
	model
		cell: aCell;
		entrySide: aSymbol.
	model initialize.
	^model! !

!LaserPathElement methodsFor: 'as yet unclassified' stamp: 'sbw 5/21/2007 21:22'!
activateCell
	self cell laserEntersFrom: self entrySide! !

!LaserPathElement methodsFor: 'accessing' stamp: 'sbw 5/20/2007 21:17'!
cell
	"Answer the value of cell"

	^ cell! !

!LaserPathElement methodsFor: 'accessing' stamp: 'sbw 5/20/2007 21:17'!
cell: anObject
	"Set the value of cell"

	cell := anObject! !

!LaserPathElement methodsFor: 'as yet unclassified' stamp: 'sbw 5/28/2007 14:48'!
clearCell
	self cell clearCell! !

!LaserPathElement methodsFor: 'accessing' stamp: 'sbw 5/20/2007 21:17'!
entrySide
	"Answer the value of entrySide"

	^ entrySide! !

!LaserPathElement methodsFor: 'accessing' stamp: 'sbw 5/20/2007 21:17'!
entrySide: anObject
	"Set the value of entrySide"

	entrySide := anObject! !

!LaserPathElement methodsFor: 'as yet unclassified' stamp: 'sbw 5/22/2007 23:38'!
nextElementIn: aGrid
	| loc dirSym direction vector newLoc nextCell |
	loc := self cell gridLocation.
	dirSym := self cell exitSideFor: self entrySide.
	dirSym isNil ifTrue: [^nil].
	direction := GridDirection directionFor: dirSym.
	vector := direction vector.
	newLoc := loc + vector.
	nextCell := aGrid at: newLoc.
	^nextCell isNil
		ifTrue: [nil]
		ifFalse: [self class cell: nextCell entrySide: direction adjacentInversionSymbol]! !

!LaserPathElement methodsFor: 'printing' stamp: 'sbw 6/14/2007 20:42'!
printOn: aStream
	super printOn: aStream.
	aStream
		cr;
		nextPut: $(..
	self cell printOn: aStream.
	aStream
		cr;
		nextPutAll: 'entrySide = ', self entrySide asString;
		nextPut: $)! !

!Object methodsFor: '*Laser-Game-Model' stamp: 'sbw 6/7/2007 20:06'!
revisit: aString
	"Does nothing"! !

Object subclass: #ReverseLaserGameAction
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Laser-Game-Model'!

!ReverseLaserGameAction class methodsFor: 'accessing' stamp: 'sbw 6/30/2007 19:05'!
reverseActionClassFor: aSymbol
	^self subclasses detect: [:cls | cls actionSymbol = aSymbol]! !

!ReverseLaserGameAction class methodsFor: 'accessing' stamp: 'sbw 6/30/2007 19:15'!
reverseActionSymbolFor: aSymbol
	| cls |
	cls := self reverseActionClassFor: aSymbol.
	^cls reverseActionSymbol! !

ReverseLaserGameAction subclass: #ReversePushCellEastLaserGameAction
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Laser-Game-Model'!

!ReversePushCellEastLaserGameAction class methodsFor: 'accessing' stamp: 'sbw 6/30/2007 19:18'!
actionSymbol
	^#east! !

!ReversePushCellEastLaserGameAction class methodsFor: 'accessing' stamp: 'sbw 6/30/2007 19:12'!
reverseActionSymbol
	^#pushCellWestFromLocation:! !

ReverseLaserGameAction subclass: #ReversePushCellNorthLaserGameAction
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Laser-Game-Model'!

!ReversePushCellNorthLaserGameAction class methodsFor: 'accessing' stamp: 'sbw 6/30/2007 19:18'!
actionSymbol
	^#north! !

!ReversePushCellNorthLaserGameAction class methodsFor: 'accessing' stamp: 'sbw 6/30/2007 19:13'!
reverseActionSymbol
	^#pushCellSouthFromLocation:! !

ReverseLaserGameAction subclass: #ReversePushCellSouthLaserGameAction
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Laser-Game-Model'!

!ReversePushCellSouthLaserGameAction class methodsFor: 'accessing' stamp: 'sbw 6/30/2007 19:18'!
actionSymbol
	^#south! !

!ReversePushCellSouthLaserGameAction class methodsFor: 'accessing' stamp: 'sbw 6/30/2007 19:13'!
reverseActionSymbol
	^#pushCellNorthFromLocation:! !

ReverseLaserGameAction subclass: #ReversePushCellWestLaserGameAction
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Laser-Game-Model'!

!ReversePushCellWestLaserGameAction class methodsFor: 'accessing' stamp: 'sbw 6/30/2007 19:18'!
actionSymbol
	^#west! !

!ReversePushCellWestLaserGameAction class methodsFor: 'accessing' stamp: 'sbw 6/30/2007 19:13'!
reverseActionSymbol
	^#pushCellEastFromLocation:! !

ReverseLaserGameAction subclass: #ReverseRotateClockwiseLaserGameAction
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Laser-Game-Model'!

!ReverseRotateClockwiseLaserGameAction class methodsFor: 'accessing' stamp: 'sbw 6/30/2007 19:19'!
actionSymbol
	^#clockwise! !

!ReverseRotateClockwiseLaserGameAction class methodsFor: 'accessing' stamp: 'sbw 6/30/2007 19:14'!
reverseActionSymbol
	^#rotateCellCounterClockwiseAt:! !

ReverseLaserGameAction subclass: #ReverseRotateCounterClockwiseLaserGameAction
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Laser-Game-Model'!

!ReverseRotateCounterClockwiseLaserGameAction class methodsFor: 'accessing' stamp: 'sbw 6/30/2007 19:19'!
actionSymbol
	^#counterClockwise! !

!ReverseRotateCounterClockwiseLaserGameAction class methodsFor: 'accessing' stamp: 'sbw 6/30/2007 19:14'!
reverseActionSymbol
	^#rotateCellClockwiseAt:! !
LedDigitMorph initialize!
LaserGameForms initialize!
LedCharacterMorph initialize!
